#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -*- Python -*-

"""
 @file AdditionalDataDBControl.py
 @brief 画像付加データのＤＢへの登録や、データの読み出しなどを行う
 @date $Date$

 @author 株式会社 東日本計算センター

 New BSD

"""


# =====================================
import csv                    # //標準
import datetime                # //標準
import json                    # //標準
import MySQLdb                # //MySQL
import os                    # //標準
import time
import io
# ========== 共通 ==========
import VersatileOverheadSystem as imp_Versatile
import CommonPara as imp_CommPara
# =====================================

import sys
import time
sys.path.append(".")

# Import RTM module
import RTC
import OpenRTM_aist

import AdditinalDataDBControl_idl

# Import Service implementation class
# <rtc-template block="service_impl">
from AdditinalDataDBControl_idl_example import *

# </rtc-template>

# Import Service stub modules
# <rtc-template block="consumer_import">
# </rtc-template>


# This module's spesification
# <rtc-template block="module_spec">
additionaldatadbcontrol_spec = ["implementation_id", "AdditionalDataDBControl", 
         "type_name",         "AdditionalDataDBControl", 
         "description",       "画像付加データのＤＢへの登録や、データの読み出しなどを行う", 
         "version",           "1.0.0", 
         "vendor",            "EAC", 
         "category",          "Category", 
         "activity_type",     "STATIC", 
         "max_instance",      "1", 
         "language",          "Python", 
         "lang_type",         "SCRIPT",
         "conf.default.confAlignmentSeq", "DESC",
         "conf.default.confSecond", "0",
         "conf.__widget__.confAlignmentSeq", "text",
         "conf.__widget__.confSecond", "spin.1",
         "conf.__constraints__.confAlignmentSeq", "(ASC,DESC)",
         "conf.__constraints__.confSecond", "0<=x<=10",
         ""]
# </rtc-template>

##
# @class AdditionalDataDBControl
# @brief 画像付加データのＤＢへの登録や、データの読み出しなどを行う
# 
# 別紙"機能仕様書_画像付加データDB制御RTC"参照
# 
# 別紙"機能仕様書_画像付加データDB制御RTC"参照
# 
# 別紙"機能仕様書_画像付加データDB制御RTC"参照
# 
# 別紙"機能仕様書_画像付加データDB制御RTC"参照
# 
# 
class AdditionalDataDBControl(OpenRTM_aist.DataFlowComponentBase):

    ##
    # @brief constructor
    # @param manager Maneger Object
    # 
    def __init__(self, manager):
        OpenRTM_aist.DataFlowComponentBase.__init__(self, manager)

        self._d_outCoordAdditionalData = RTC.TimedStringSeq(RTC.Time(0,0),[])
        """
        座標指定画像付加データをJson形式で提供する。
         - Type: RTC::TimedStringSeq
        """
        self._outCoordAdditionalDataOut = OpenRTM_aist.OutPort("outCoordAdditionalData", self._d_outCoordAdditionalData)
        self._d_outDroneShootingPlanList = RTC.TimedStringSeq(RTC.Time(0,0),[])
        """
        画像付加データDB内のドローン撮影計画リストデータをJyson形式で提供する
        　※100件分のリストを提供
         - Type: RTC::TimedStringSeq
         - Frequency: 座標指定画像付加データ取得要求時
         - Operation Cycle: 座標指定画像付加データ取得要求時
        """
        self._outDroneShootingPlanListOut = OpenRTM_aist.OutPort("outDroneShootingPlanList", self._d_outDroneShootingPlanList)
        self._d_outCrawlerShootingPlanList = RTC.TimedStringSeq(RTC.Time(0,0),[])
        """
        画像付加デーＤＢ内の災害対応ロボットが撮影した画像の撮影リストをJson形式で提
        供する。
         - Type: RTC::TimedStringSeq

        """
        self._outCrawlerShootingPlanListOut = OpenRTM_aist.OutPort("outCrawlerShootingPlanList", self._d_outCrawlerShootingPlanList)
        self._d_outTimeAdditinalData = RTC.TimedStringSeq(RTC.Time(0,0),[])
        """
        時間指定画像付加データ
        画像付加データDB内から撮影日時が一番古い画像付加データをJson形式で提供する。
         - Type: RTC::TimedStringSeq
        """
        self._outTimeAdditinalDataOut = OpenRTM_aist.OutPort("outTimeAdditinalData", self._d_outTimeAdditinalData)

        """
        画像DB要求制御
        """
        self._AdditionalDBReqServPort = OpenRTM_aist.CorbaPort("AdditionalDBReqServ")
        """
        画像付加データDBステータス
        """
        self._AdditionalDBStsServPort = OpenRTM_aist.CorbaPort("AdditionalDBStsServ")

        """
        画像付加データDB対する登録要求の設定、取得を行う。
         - Argument:      別紙"機能仕様書_画像付加データDB制御RTC"参照
         - Return Value:  別紙"機能仕様書_画像付加データDB制御RTC"参照
        """
        self._AddDBReqRegistAddDataProv = AddDBReqRegistAddData_i()
        """
        撮影計画リスト作成要求、設定、取得を行う
         - Argument:      別紙"機能仕様書_画像付加データDB制御RTC"参照
         - Return Value:  別紙"機能仕様書_画像付加データDB制御RTC"参照
        """
        self._AddDBReqMakeShootingPlanListProv = AddDBReqMakeShootingPlanList_i()
        """
        撮影計画リスト取得要求の設定、取得を行う。
         - Argument:      別紙"機能仕様書_画像付加データDB制御RTC"参照
         - Return Value:  別紙"機能仕様書_画像付加データDB制御RTC"参照
        """
        self._AddDBReqGetShootingPlanListProv = AddDBReqGetShootingPlanList_i()
        """
        座標指定画像付加データ取得要求の設定、取得を行う。
         - Argument:      別紙"機能仕様書_画像付加データDB制御RTC"参照
         - Return Value:  別紙"機能仕様書_画像付加データDB制御RTC"参照
        """
        self._CoordinateDataGetProv = CoordinateDataGet_i()
        """
        撮影時刻順画像付加データ取得要求の設定、取得を行う。
        """
        self._ShootingTimeDateGetProv = ShootingTimeDateGet_i()
        """
        画像付加データＤＢ制御コンポーネントの状態通知の設定、取得を行う。
         - Argument:      別紙"機能仕様書_画像付加データDB制御RTC"参照
         - Return Value:  別紙"機能仕様書_画像付加データDB制御RTC"参照
        """
        self._AddDBNoticeProv = AddDBNotice_i()

        # initialize of configuration-data.
        # <rtc-template block="init_conf_param">
        """
        計画リストの並び順を設定する。
         - Name: confAlignmentSeq confAlignmentSeq
         - DefaultValue: DESC
         - Unit: 並び順
         - Range: (ASC,DESC)
        """
        self._confAlignmentSeq = ['DESC']
        """
        画像撮影時間の間隔を指定する。
         - Name: confSecond confSecond
         - DefaultValue: 0
         - Unit: 秒間
         - Range: 0<=x<=10
        """
        self._confSecond = [0]

        # </rtc-template>

    ##
    # 画像付加データDB制御RTCの初期化処理
    #
    # The initialize action (on CREATED->ALIVE transition)
    # formaer rtc_init_entry() 
    # 
    # @return RTC::ReturnCode_t
    # 
    #
    def onInitialize(self):
        print "[adddb_debug]onInitialize"

        # Bind variables and configuration variable
        self.bindParameter("confAlignmentSeq", self._confAlignmentSeq, "DESC")
        self.bindParameter("confSecond", self._confSecond, "0")

        # Set InPort buffers
        
        # Set OutPort buffers
        self.addOutPort("outCoordAdditionalData",self._outCoordAdditionalDataOut)
        self.addOutPort("outDroneShootingPlanList",self._outDroneShootingPlanListOut)
        self.addOutPort("outCrawlerShootingPlanList",self._outCrawlerShootingPlanListOut)
        self.addOutPort("outTimeAdditinalData",self._outTimeAdditinalDataOut)
        
        # Set service provider to Ports
        self._AdditionalDBReqServPort.registerProvider("AddDBReqRegistAddData", "AdditionalDBReqServ::AddDBReqRegistAddData", self._AddDBReqRegistAddDataProv)
        self._AdditionalDBReqServPort.registerProvider("AddDBReqMakeShootingPlanList", "AdditionalDBReqServ::AddDBReqMakeShootingPlanList", self._AddDBReqMakeShootingPlanListProv)
        self._AdditionalDBReqServPort.registerProvider("AddDBReqGetShootingPlanList", "AdditionalDBReqServ::AddDBReqGetShootingPlanList", self._AddDBReqGetShootingPlanListProv)
        self._AdditionalDBReqServPort.registerProvider("CoordinateDataGet", "AdditionalDBReqServ::CoordinateDataGet", self._CoordinateDataGetProv)
        self._AdditionalDBReqServPort.registerProvider("ShootingTimeDateGet", "AdditionalDBReqServ::ShootingTimeDateGet", self._ShootingTimeDateGetProv)
        self._AdditionalDBStsServPort.registerProvider("AddDBNotice", "AdditionalDBStsServ::AddDBNotice", self._AddDBNoticeProv)
        
        # Set service consumers to Ports

        # Set CORBA Service Ports
        self.addPort(self._AdditionalDBReqServPort)
        self.addPort(self._AdditionalDBStsServPort)

        # ===== 変数初期化 =====
        self.versatiInit()

        return RTC.RTC_OK

        ##
        # 画像付加データDB制御RTの終了処理
        # 
        # The finalize action (on ALIVE->END transition)
        # formaer rtc_exiting_entry()
        # 
        # @return RTC::ReturnCode_t

        # 
    def onFinalize(self):
        print "[adddb_debug]onFinalize"

        return RTC.RTC_OK

    #    ##
    #    #
    #    # The startup action when ExecutionContext startup
    #    # former rtc_starting_entry()
    #    # 
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onStartup(self, ec_id):
    #
    #    return RTC.RTC_OK

    #    ##
    #    #
    #    # The shutdown action when ExecutionContext stop
    #    # former rtc_stopping_entry()
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onShutdown(self, ec_id):
    #
    #    return RTC.RTC_OK

        ##
        # 画像付加データDB制御RTCの開始処理
        #
        # The activated action (Active state entry action)
        # former rtc_active_entry()
        #
        # @param ec_id target ExecutionContext Id
        # 
        # @return RTC::ReturnCode_t
        #
        #
    def onActivated(self, ec_id):
        print "[adddb_debug]onActivated"

        # ===== DB接続チェック =====
        ret, connector = self.dbConnectCheck() 
        if ret:
            pass
        else:
            # //接続NG
            print "[adddb_error]" ,u"DB接続NGです確認して下さい。"
            return RTC.RTC_ERROR

        return RTC.RTC_OK

        ##
        # 画像付加データDB制御RTの停止処理
        #
        # The deactivated action (Active state exit action)
        # former rtc_active_exit()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onDeactivated(self, ec_id):
        print "[adddb_debug]onDeactivated"

        # ===== 変数初期化 =====
        self.versatiInit()

        # ==== DB接続チェック =====
        ret, connector = self.dbConnectCheck() 
        if ret:
            connector.close()
            pass

        else:
            # //接続NG
            print "[adddb_error]",u"DB接続解除NGです確認して下さい。"
            return RTC.RTC_ERROR

        # ==== logファイルクローズ
        #self.F_LOG.close()

        return RTC.RTC_OK

        ##
        # 画像付加データDB制御RTCを行う周期処理
        #
        # The execution action that is invoked periodically
        # former rtc_active_do()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onExecute(self, ec_id):

        # ===== 処理状態 =====
        if (self.m_Proc_sts == self.PROC_STS_IDLE):

            # ========== 要求チェック ==========
            if self.requestCheck():
                # ===== 処理実行 =====
                if self.procExc():
                    pass
                else:
                    # ===== 内部モードをエラー状態にする =====
                    print "[adddb_error]","procExc NG" 
                    return RTC.RTC_ERROR

        return RTC.RTC_OK

        ##
        # 画像付加データDB制御RTのエラー遷移処理
        #
        # The aborting action when main logic error occurred.
        # former rtc_aborting_entry()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onAborting(self, ec_id):
        print "[adddb_debug]onAborting"

        return RTC.RTC_OK

        ##
        # 画像付加データDB制御RTのエラー処理
        #
        # The error action in ERROR state
        # former rtc_error_do()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onError(self, ec_id):
        print "[adddb_debug]onError"

        return RTC.RTC_OK

        ##
        # 画像付加データDB制御RTのReset処理
        #
        # The reset action that is invoked resetting
        # This is same but different the former rtc_init_entry()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onReset(self, ec_id):
        print "[adddb_debug]onReset"
        self.versatiInit()

        return RTC.RTC_OK

    #    ##
    #    #
    #    # The state update action that is invoked after onExecute() action
    #    # no corresponding operation exists in OpenRTm-aist-0.2.0
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #

    #    #
    #def onStateUpdate(self, ec_id):
    #
    #    return RTC.RTC_OK

    #    ##
    #    #
    #    # The action that is invoked when execution context's rate is changed
    #    # no corresponding operation exists in OpenRTm-aist-0.2.0
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onRateChanged(self, ec_id):
    #
    #    return RTC.RTC_OK

# *****************************************************************************
#  サブルーチン
# *****************************************************************************


# ========== IDL 変数定義 ==========
    # ===== DB登録要求用 =====
    m_Param_sFoldderPath = imp_Versatile.FOLDER_PATH_INIT   # ファイルパス
    m_Param_ulRobotCategory = 0                             # ロボットカテゴリー
    # ===== 撮影計画リスト作成要求用 =====
    m_MakeList_ulRobotCategory = 0                          # ロボットカテゴリー
    # ===== 座標指定データ取得要求用 =====
    m_Coord_ulRobotCategory = 0                             # ロボットカテゴリー
    m_Coord_ulGroupId = 0                                   # グループＩＤ
    m_Coord_dStartLatitude = 0                              # 始点緯度
    m_Coord_dStartLongitude = 0                             # 開始経度
    m_Coord_dEndLatitude = 0                                # 終点緯度
    m_Coord_dEndLongitude = 0                               # 終点経度
    # ===== 撮影時刻指定データ取得要求用 =====
    m_Time_ulRobotCategory = 0                              # ロボットカテゴリー
    m_Time_ulGroupId = 0                                    # グループＩＤ
    m_Time_ulImageAcq = imp_Versatile.SHOOTING_IMAGE_ACQ_STOP    # 撮影時刻 画像取得区分
    m_Time_ulReq= 0                                         # 画像取得 要求区分

# ===== 内部処理ステータス  =====
    # ===== 内部処理状態 =====
    PROC_STS_IDLE = 0                                       # // 待機中
    PROC_STS_RUN = 1                                        # // 処理中
    PROC_STS_ERROR = 2                                      # // エラー状態
    m_Proc_sts = PROC_STS_IDLE
    UTF8_BOM = bytearray([0xEF,0XBB,0XBF])                  # // BOMコード
# =========== プロセスID ==========
    m_Proc_ID = 0                                           # // 初期値

    PROC_ID_procAddDBReqRegistAdd = 1                       # // 座標指定画像付加データ取得処理
    PROC_ID_procCoordinateDataGet =2                        # // 座標指定画像付加データ取得処理
    PROC_ID_procShootingTimeDateGet = 3                     # // 撮影時刻順画像付加データ取得処理
    PROC_ID_procAddDBReqMakeShootingPlanList = 4            # // 撮影計画リスト作成処理
    PROC_ID_procAddDBReqGetShootingPlanList = 5             # // 撮影計画リスト取得処理

# ===============================================
#    CSV関連
# ===============================================
# ========== CSVファイル項目名 ==========
    csvItem = []
    csvItem.append(u"ファイル名")
    csvItem.append(u"フォルダパス")
    csvItem.append(u"サイズ幅")
    csvItem.append(u"サイズ高さ")
    csvItem.append(u"ロボット識別子")
    csvItem.append(u"カメラNo")
    csvItem.append(u"緯度")
    csvItem.append(u"経度")
    csvItem.append(u"高さ")
    csvItem.append(u"方角")
    csvItem.append(u"ピッチ角")
    csvItem.append(u"ロール角")
    csvItem.append(u"年月日")
    csvItem.append(u"時間")
    csvItem.append(u"撮影計画名")

    # =====csvファイル拡張子 ===== 
    CSV_FILE_EXTENSION  = (".csv")
# ===============================================
#    DB関連
# ===============================================
    DB_HOST = "localhost"
    DB_DBNM = "image_added"
    DB_USER = "root"
    DB_PASSWD = ""
    DB_CHRRSET = "utf8"

# ===============================================
#    テーブル関連
# ===============================================
    MT01 = "robot_category"
    TB01 = "shooting_plan"
    TB02 = "shooting_plan_detail"

    MT01_ITEM_01 = "no"
    MT01_ITEM_02 = "robot_identifier"
    MT01_ITEM_03 = "roboto_catgory"
    MT01_ITEM_04 = "robot_name"
    MT01_ITEM_05 = "control_no"

    TB01_ITEM_01 = "group_id"
    TB01_ITEM_02 = "shooting_date"
    TB01_ITEM_03 = "shooting_plan_name"
    TB01_ITEM_04 = "robot_identifier"
    TB01_ITEN_05 = "robot_category"

    TB02_ITEM_01 = "image_id"
    TB02_ITEM_02 = "group_id"
    TB02_ITEM_03 = "file_name"
    TB02_ITEM_04 = "folder_path"
    TB02_ITEM_05 = "image_width"
    TB02_ITEM_06 = "image_height"
    TB02_ITEM_07 = "robot_identifier"
    TB02_ITEM_08 = "robot_camera_no"
    TB02_ITEM_09 = "position_latitude"
    TB02_ITEM_10 = "position_longitude"
    TB02_ITEM_11 = "position_height"
    TB02_ITEM_12 = "slope_direction"
    TB02_ITEM_13 = "slope_pitch"
    TB02_ITEM_14 = "slope_roll"
    TB02_ITEM_15 = "shooting_date"
    TB02_ITEM_16 = "shooting_time"
    TB02_ITEM_17 = "shooting_section_no"
    TB02_ITEM_18 = "shooting_plan_name"

# ===============================================
#    計画リスト登録用 sql
# ===============================================
    SQL_GROUP_ID = 0
#===============================================
#    ロボットカテゴリー
# ===============================================
    ROBOT_CATEGORY = []
    ROBOT_CATEGORY.append(u"")
    ROBOT_CATEGORY.append(u"drone")
    ROBOT_CATEGORY.append(u"crawler")
    ROBOT_CATEGORY.append(u"gorone")

    # ===== カメラ台数 =====
    CAMERA_NUMBER = 4
# ===============================================
#    計画リスト作成用
# ===============================================
    PLAN_LIST = ""

# ===============================================
#    検証用　ログ
# ===============================================
    F_LOG = ""
    DT = datetime.datetime.today()
    TSTR = DT.strftime('%Y%m%d_%H%M%S')
    F_LOG_FILE = "c:/workspace/log/" + TSTR + r"_log.txt"


# =============================================================================
#  処　理：変数初期化処理
#
# =============================================================================
    def versatiInit(self):
        # ===== キー要求パラメータ初期化 =====
        self.m_Param_sFoldderPath = imp_Versatile.FOLDER_PATH_INIT
        self.m_MakeList_ulRobotCategory = imp_Versatile.ROBOT_CATEGORY_INIT
        self.m_Coord_ulRobotCategory = imp_Versatile.ROBOT_CATEGORY_INIT
        self.m_Coord_ulGroupId = 0
        self.m_Coord_dStartLatitude = 0
        self.m_Coord_dStartLongitude = 0
        self.m_Coord_dEndLatitude = 0
        self.m_Coord_dEndLongitude = 0
        self.m_Time_ulRobotCategory = imp_Versatile.ROBOT_CATEGORY_INIT
        self.m_Time_ulGroupId = 0
        self.m_Time_ulImageAcq = imp_Versatile.SHOOTING_IMAGE_ACQ_STOP
        self.m_Time_ulReq= imp_Versatile.SERV_REQ_CLEAR

        self.m_Proc_sts = self.PROC_STS_IDLE

        # ===== IDL パラメータクリア =====
        self._AddDBReqRegistAddDataProv.clrAddDBReqRegistAddData()
        self._AddDBReqMakeShootingPlanListProv.clrAddDBReqMakeShootingPlanList()
        self._CoordinateDataGetProv.clrCoordinateDataGet()
        self._ShootingTimeDateGetProv.clrShootingTimeDateGet()
        self._AddDBNoticeProv.clrAddDBNotice()


# ============================================================================
#  処　理：日付取得
#  引　数：なし
#  戻り値：現在の日時
# ============================================================================
    def DateTimeGet(self):

        return(datetime.datetime.now().strftime("%Y/%m/%d %H:%M:%S"))    

# =============================================================================
#  処  理：要求チェック
#  戻り値：要求あり(True)/要求無なし(False)
# =============================================================================
    def requestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 画像付加データDB登録要求 =====
        if self.AddDBRegistReqCheck():
            # // 処理ＩＤセット
            self.m_Proc_Id = self.PROC_ID_procAddDBReqRegistAdd
            ret = True
        # ===== 座標指定画像付加データ取得要求 =====
        elif self.CoordDataGetReqCheck():
            # // 処理ＩＤセット
            self.m_Proc_Id = self.PROC_ID_procCoordinateDataGet
            ret = True
        # ===== 撮影時刻順画像付加データ取得要求 =====
        elif self.ShootingTimeGetReqCheck():
            # // 処理ＩＤセット
            self.m_Proc_Id = self.PROC_ID_procShootingTimeDateGet
            ret = True
        # ===== 撮影計画リスト作成要求 =====
        elif self.MakeShootingPlanListReqCheck():
            # 処理ＩＤセット
            self.m_Proc_Id = self.PROC_ID_procAddDBReqMakeShootingPlanList
            ret = True

        # ===== 戻り値 =====        
        return ret        

# *****************************************************************************
# ========== 変化チェック処理 ========= 
# *****************************************************************************

# ============================================================================
#  処　理：画像付加データDB登録要求 変化チェック
#  戻り値：変化あり(True)/変化なし(False)
# ============================================================================
    def AddDBRegistReqCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== パラメータ =====
        wsFoldderPath = imp_Versatile.FOLDER_PATH_INIT

        # ===== 要求確認 =====
        wsFoldderPath = self._AddDBReqRegistAddDataProv.GetAddDBReqRegistAddData()

        # ===== 変化なしチェック =====
        if wsFoldderPath == imp_Versatile.FOLDER_PATH_INIT:
            # //初期値のまま変化なし
            ret =  False
        elif wsFoldderPath != self.m_Param_sFoldderPath:
            # ===== 変化チェック =====
            # //変化あり
            ret = True
            self.m_Param_sFoldderPath = wsFoldderPath
            print "[adddb_debug]GetAddDBReqRegistAddData(),Param1 = %s " % wsFoldderPath
        # ===== 戻り値 =====
        return ret

# ============================================================================
#  処　理：座標指定画像付加データ要求 変化チェック
#  戻り値：変化あり(True)/変化なし(False)
# ============================================================================
    def CoordDataGetReqCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 作業用パラメータ =====
        wulRobotCategory = imp_Versatile.ROBOT_CATEGORY_INIT
        wulGroupId = 0
        wdStartLatitude = 0
        wdStartLongitude = 0
        wdEndLatitude = 0
        wdEndLongitude = 0    

        # ===== 要求確認 =====
        wulRobotCategory, wulGroupId, wdStartLatitude, wdStartLongitude, wdEndLatitude, wdEndLongitude = self._CoordinateDataGetProv.GetCoordinateDataGet()
        # ===== 変化チェック =====
        if (wulRobotCategory == imp_Versatile.ROBOT_CATEGORY_INIT and 
            wulGroupId == 0 and  
            wdStartLatitude == 0 and
            wdEndLatitude == 0 and 
            wdStartLongitude == 0 and 
            wdEndLongitude == 0):
            # // 初期値のまま変化なし 
            ret = False
        else:
            print "[adddb_debug]GetCoordinateDataGet(),Param1 = %d,Param2 = %d,Param3 = %f,Param4 = %f,Param5 = %f,Param6 = %f"%(wulRobotCategory, wulGroupId, wdStartLatitude, wdStartLongitude, wdEndLatitude, wdEndLongitude)
            self.m_Coord_ulRobotCategory = wulRobotCategory
            self.m_Coord_ulGroupId = wulGroupId
            self.m_Coord_dStartLatitude = wdStartLatitude
            self.m_Coord_dStartLongitude = wdStartLongitude
            self.m_Coord_dEndLatitude = wdEndLatitude
            self.m_Coord_dEndLongitude = wdEndLongitude
            # ====== クリア ======
            self._CoordinateDataGetProv.clrCoordinateDataGet()
            ret = True

        # ===== 戻り値 =====
        return ret

# ============================================================================
#  処　理：撮影時刻順画像付加データ取得要求 変化チェック
#  戻り値：変化あり(True)/変化なし(False)
# ============================================================================
    def ShootingTimeGetReqCheck(self):
        # ===== 戻り値 =====
        ret = False
        # ===== 作業用パラメータ クリア =====
        wulRobotCategory = imp_Versatile.ROBOT_CATEGORY_INIT
        wulGroupId = 0
        wulImageAcq = imp_Versatile.SHOOTING_IMAGE_ACQ_STOP
        wulReq = imp_Versatile.SERV_REQ_CLEAR

        # ===== 要求確認 =====
        wulRobotCategory, wulGroupId, wulImageAcq, wulReq = self._ShootingTimeDateGetProv.GetShootingTimeDateGet()

        # ===== 変化なしチェック =====
        if (wulRobotCategory == imp_Versatile.ROBOT_CATEGORY_INIT 
            and wulGroupId == 0 
            and wulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_STOP 
            and wulReq == 0):
            # //初期値のまま変化なし
            ret =  False

        else:
            print "[adddb_debug]GetShootingTimeDateGet(),Param1 = %d,Param2 = %d,Param3 = %d,Param4 = %d "%(wulRobotCategory, wulGroupId, wulImageAcq, wulReq)
            self.m_Time_ulRobotCategory = wulRobotCategory
            self.m_Time_ulGroupId = wulGroupId
            self.m_Time_ulImageAcq = wulImageAcq
            self.m_Time_ulReq = wulReq
            # ====== クリア ======
            self._ShootingTimeDateGetProv.clrShootingTimeDateGet()
            ret =  True

        return ret

# ============================================================================
#  処　理：撮影計画リスト作成要求 変化チェック
#  戻り値：変化あり(True)/変化なし(False)
# ============================================================================
    def MakeShootingPlanListReqCheck(self):
        # ===== 戻り値 =====
        ret = False
        # ===== 作業用パラメータ クリア =====
        wulRobotCategory = imp_Versatile.ROBOT_CATEGORY_INIT

        # ===== 要求確認 =====
        wulRobotCategory = self._AddDBReqMakeShootingPlanListProv.GetAddDBReqMakeShootingPlanList()

        # ===== 変化なしチェック =====
        if wulRobotCategory == imp_Versatile.ROBOT_CATEGORY_INIT:
            # ===== 初期値のまま変化なし =====
            ret = False
        elif (wulRobotCategory != self.m_MakeList_ulRobotCategory):
            # ===== 変化チェック =====
            print "[adddb_debug]GetAddDBReqMakeShootingPlanList(),Param1 = %d "% wulRobotCategory
            ret = True
            # 変化あり
            self.m_MakeList_ulRobotCategory = wulRobotCategory

        # ===== 戻り値 =====
        return ret

# ============================================================================
#  処　理：撮影計画リスト取得要求 変化チェック
#  戻り値：変化あり(True)/変化なし(False)
# ============================================================================
    def getShootingPlanListCheck(self):
        # ===== 戻り値 =====
        ret = False
        # ===== 作業用パラメータ クリア =====
        wulListReq =  imp_Versatile.SERV_REQ_CLEAR

        # ===== 要求確認 =====
        wulListReq = self._AddDBReqGetShootingPlanListProv.GetAddDBReqGetShootingPlanList()

        # ===== 変化なしチェック =====
        if (wulListReq == imp_Versatile.SERV_REQ_CLEAR):
            # //初期値のまま変化なし
            ret = False
        else:
            print "[adddb_debug]GetAddDBReqGetShootingPlanList(),Param1 = %d "% wulListReq
            self._AddDBReqGetShootingPlanListProv.clrAddDBReqGetShootingPlanList()
            ret = True

        # ===== 戻り値 =====
        return ret


# ****************************************************************************
# ========== 処理 ==========
# ****************************************************************************

# ============================================================================
#  処　理：処理実行
#  戻り値：変化あり(True)/変化なし(False)
# ============================================================================
    def procExc(self):
        # ===== 戻り値 =====
        ret = False

        if self.m_Proc_Id == self.PROC_ID_procAddDBReqRegistAdd:
            # ===== 画像付加データDB登録 処理 =====
            ret = self.procAddDBReqRegistAdd()
        elif self.m_Proc_Id == self.PROC_ID_procCoordinateDataGet:
            # ===== 座標指定画像付加データ取得 処理 =====
            ret = self.procCoordinateDataGet()
        elif self.m_Proc_Id == self.PROC_ID_procShootingTimeDateGet:
            # ===== 撮影時刻順画像付加データ取得 処理 =====
            ret = self.procShootingTimeDateGet()
        elif self.m_Proc_Id == self.PROC_ID_procAddDBReqMakeShootingPlanList:
            #===== 撮影計画リスト作成 処理 =====
            ret = self.procAddDBReqMakeShootingPlanList()
        else:
            print "[adddb_error]","wModuleID",u"プロセスIDエラー", self.m_Proc_Id 

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：画像付加データDB登録 処理 
#  戻り値：成功(True)/失敗(False)
# ============================================================================
    def procAddDBReqRegistAdd(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 処理状態セット =====
        self.m_Proc_sts = self.PROC_STS_RUN

        # ===== CSVファイル存在チェック =====
        if self.csvCheck(self.m_Param_sFoldderPath):

            # ===== CSVファイル整合性チェック =====
            if self.csvIntegrityCheck(self.m_Param_sFoldderPath):

                # ===== CSV登録処理 =====
                if self.dbRegistDatail(self.m_Param_sFoldderPath):
                    # ===== 計画リスト作成・取得 ====
                    # ===== 撮影計画リスト作成 Drone =====
                    ret, jsonString ,listCnt = self.makeShootingPlanList(imp_Versatile.ROBOT_CATEGORY_DRONE)
                    if ret:
                        if listCnt > 0:
                            # ===== json → 配列にセット =====
                            jsonrd = json.loads(jsonString)
                            dataBuffer=[]            
                            for row in jsonrd:
                                value = str(row)
                                dataBuffer.append(value)

                            # ===== データポート　セット =====
                            self._d_outDroneShootingPlanList.data = dataBuffer
                            self._outDroneShootingPlanListOut.write()

                        # ===== 戻り値セット =====
                        ret = True

                    # ===== 撮影計画リスト作成 Crawler =====
                    ret, jsonString ,listCnt = self.makeShootingPlanList(imp_Versatile.ROBOT_CATEGORY_CRAWLER)

                    if ret:
                        if listCnt > 0:
                            # ===== json → 配列にセット =====
                            jsonrd = json.loads(jsonString)
                            dataBuffer=[]            
                            for row in jsonrd:
                                value = str(row)
                                dataBuffer.append(value)

                            # ===== データポート　セット =====
                            self._d_outCrawlerShootingPlanList.data = dataBuffer
                            self._outCrawlerShootingPlanListOut.write()

                        # ===== 戻り値セット =====
                        ret = True

        # ===== 終了処理 =====
        if ret:
            # ===== 処理OK ===== 
            # // DB　完了通知セット
            print u"[adddb_debug]procAddDBReqRegistAdd OK"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_REGIST_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            # // DB　完了通知セット
            print u"[adddb_debug]procAddDBReqRegistAdd NG"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_REGIST_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self.m_Proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：撮影計画リスト作成 処理
#  戻り値：成功(True)/失敗(False)
# ============================================================================
    def procAddDBReqMakeShootingPlanList(self):
        # ===== 戻り値 =====        
        ret = False

        # ===== 処理状態セット =====
        self.m_Proc_sts = self.PROC_STS_RUN

        # ===== 撮影計画リスト作成 =====
        ret, jsonString ,listCnt = self.makeShootingPlanList(self.m_MakeList_ulRobotCategory)

        if ret:
            if listCnt > 0:
                # ===== json → 配列にセット =====
                jsonrd = json.loads(jsonString)
                dataBuffer=[]            
                for row in jsonrd:
                    value =    str(row)
                    dataBuffer.append(value)

                # ===== データポート　セット =====
                if self.m_MakeList_ulRobotCategory == 1:
                    self._d_outDroneShootingPlanList.data = dataBuffer
                    self._outDroneShootingPlanListOut.write()
                elif self.m_MakeList_ulRobotCategory == 2:
                    self._d_outCrawlerShootingPlanList.data = dataBuffer
                    self._outCrawlerShootingPlanListOut.write()

            # ===== 戻り値セット =====
            ret = True

        # ===== 終了処理 =====
        if ret:
            # ===== 処理OK =====
            # // DB　完了通知セット
            print u"[adddb_debug]procAddDBReqMakeShootingPlanList OK"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_SHOOT_LIST_MAKE_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            # // DB　完了通知セット
            print u"[adddb_debug]procAddDBReqMakeShootingPlanList NG"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_SHOOT_LIST_MAKE_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self.m_Proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：撮影計画リスト取得 処理
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def procAddDBReqGetShootingPlanList(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 処理状態セット =====
        self.m_Proc_sts = self.PROC_STS_RUN

        # ===== 撮影計画リスト取得 =====
        jsonString = self.PLAN_LIST

        # ===== 取得件数セット =====
        listCnt = len(self.PLAN_LIST)

        # ===== json → 配列にセット =====
        jsonrd = json.loads(jsonString)
        dataBuffer=[]            
        for row in jsonrd:
            value =    str(row)
            dataBuffer.append(value) 

        # ===== 取得件数セット =====    
        listCnt = len(dataBuffer)

        # ===== データポート　セット =====
        self._d_outDroneShootingPlanList.data = dataBuffer
        self._outDroneShootingPlanListOut.write()

        # ===== 戻り値セット =====
        ret = True            

        # ===== 終了処理 =====        
        if ret:
            # ===== 処理OK =====
            # // DB　完了通知セット
            print u"[adddb_debug]procAddDBReqGetShootingPlanList OK"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_SHOOT_LIST_GET_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            # // DB　完了通知セット
            print u"[adddb_debug]procAddDBReqGetShootingPlanList NG"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_SHOOT_LIST_GET_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self.m_Proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret    


# ============================================================================
#  処　理：座標指定画像付加データ取得 処理
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def procCoordinateDataGet(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 処理状態セット =====
        self.m_Proc_sts = self.PROC_STS_RUN

        # ===== 座標指定画像付加データ取得 =====
        jsonString = ""
        ret, jsonString, listCnt = self.coordinateDataGet(self.m_Coord_ulRobotCategory
                                                , self.m_Coord_ulGroupId
                                                , self.m_Coord_dStartLatitude
                                                , self.m_Coord_dStartLongitude
                                                , self.m_Coord_dEndLatitude 
                                                , self.m_Coord_dEndLongitude) 
        if ret:
            if listCnt > 0:
                # ===== json → 配列にセット =====
                jsonrd = json.loads(jsonString)
                dataBuffer=[]            
                for row in jsonrd:
                    value =    str(row)
                    dataBuffer.append(value) 

                # ===== データポートにセット =====
                for row in jsonString:
                    self._d_outCoordAdditionalData.data = dataBuffer
                    self._outCoordAdditionalDataOut.write()

            # ===== 戻り値セット =====
            ret = True

        # ===== 終了処理 =====
        if ret:
            # ===== 処理OK =====
            # // DB　完了通知セット
            print u"[adddb_debug]procCoordinateDataGet OK"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_COORD_GET_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            # // DB　完了通知セット
            print u"[adddb_debug]procCoordinateDataGet NG"
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_COORD_GET_ERROR, 0)


        # ===== 処理状態をIDLEに設定 =====
        self.m_Proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：撮影時刻順画像付加データ取得 処理
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def procShootingTimeDateGet(self):
        ret = False

        # ===== 処理状態セット =====
        self.m_Proc_sts = self.PROC_STS_RUN

        # ===== 撮影時刻順画像付加データ取得 =====
        jsonString = ""
        ret, jsonString, listCnt = self.shootingTimeDateGet(self.m_Time_ulRobotCategory
                                                            , self.m_Time_ulGroupId
                                                            , self.m_Time_ulImageAcq
                                                            , self.m_Time_ulReq)
        if ret:
            if listCnt > 0: 
                # ===== json → 配列にセット =====
                jsonrd = json.loads(jsonString)
                dataBuffer=[]            
                for row in jsonrd:
                    value =    str(row)
                    dataBuffer.append(value) 

                # ===== データポートにセット =====
                self._d_outTimeAdditinalData.data = dataBuffer
                self._outTimeAdditinalDataOut.write()

            # ===== 戻り値セット =====
            ret = True

        # ===== 終了処理 =====
        if ret:
            # ===== 処理OK =====
            # // DB　完了通知セット
            print u"[adddb_debug]procShootingTimeDateGet OK" 
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_SHOOT_TIME_GET_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            # // DB　完了通知セット
            print u"[adddb_debug]procShootingTimeDateGet NG" 
            self._AddDBNoticeProv.usSetAddDBNotice(imp_Versatile.ADD_DB_NOTICE_SHOOT_TIME_GET_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self.m_Proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：DB接続チェック
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def dbConnectCheck(self):
        # ===== 戻り値 =====
        ret = False
        connector = None

        try:
            # ===== DB接続 =====
            # connector = MySQLdb.connect(host="localhost", db="*****", user="*****", passwd="*****", charset="utf8")
            connector = MySQLdb.connect(host="localhost", db="image_added", user="root", charset="utf8")

            # ==== 戻り値 =====
            if connector == None:
                ret = False
            else:
                ret = True

        except Exception as e:
            # ===== 例外処理 =====
            print "[adddb_error]", "Exception" , "dbConnectCheck", e.args

            # ===== 戻り値 ====
            ret = False
            connector = None

        finally:
            # ===== 終了処理 =====

            # ==== 戻り値 =====
            return(ret, connector)

# ============================================================================
#  処　理：CSVファイルコードチェック
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def csvCodeCheck(self,csvfile):
        # ===== 戻り値 =====
        ret = False
        binaryfile = None
        encd = None

        try:
            # ===== タブ文字としてみなされるためエスケープ =====
            Rcsvfile = csvfile.replace('\t', '\\t')

            # ===== utf-8 csvファイル読込み =====
            # utf-8 utf-8 bom 以外は　UnicodeDecodeErrorへ
            with io.open(Rcsvfile, "rt", encoding="utf_8_sig") as f:
                fil = f.readlines()

                f.close()

            #===== utf-8 判定 =====
            utf8_file = open(Rcsvfile, "r")
            utf8_read = utf8_file.read()
            if utf8_read.startswith(self.UTF8_BOM):
                print "[adddb_error]", Rcsvfile, u"[utf-8]のデータではありません"
                ret = False
            else:
                ret = True

            utf8_file.close()

        except UnicodeDecodeError:
            print u"[adddb_error]", Rcsvfile, u"[utf-8]のデータではありません"
            print u"[adddb_error]", u"Exception" , u"csvCodeCheck NG", csvfile, encd, e.args
            print (sys.exc_info())
            # ===== 戻り値 =====
            ret = False            

        except Exception as e:             
            # ===== 例外処理 =====
            print u"[adddb_error]", u"Exception" , u"csvCodeCheck NG", Rcsvfile, encd, e.args
            print (sys.exc_info())

            # ===== 戻り値 =====
            ret = False

        finally:
            # ===== 終了処理 =====    

            # ===== 戻り値 =====
            return ret


# ============================================================================
#  処　理：CSVファイル存在チェック
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def csvCheck(self,sFolderPath):
        # ===== 戻り値 =====
        ret = False
        registFiles = ""

        try:
            # ===== フォルダチェック =====
            if os.path.exists(sFolderPath):
                registFiles = os.listdir(sFolderPath)
                cnt = len(registFiles)
                print u"[adddb_messege]",u"--フォルダ内ファイル件数チェック 件数=", cnt
                ret = (cnt > 0)
            else:
                print u"[adddb_error]",sFolderPath, u"-指定したフォルダが見つかりません-"

        except Exception as e:
            # ===== 例外処理 =====
            print u"[adddb_error]", u"Exception" , u"csvCheck NG", e.args

            # ===== 戻り値 =====
            ret = False

        finally: 
            # ===== 終了処理 =====

            # ===== 戻り値 =====
            return ret


# ============================================================================
#  処　理：CSVファイル整合性チェック
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def csvIntegrityCheck(self,sFolderPath):
        ret = False
        registFiles = ""
        csvList = []
        try:

            # ===== フォルダ内（サブフォルダ）ファイル件数チェック
            wk = os.walk(sFolderPath)
            for items in wk:
                if (len(items[2]) != 0):
                    for file in items[2]:
                        relPath = os.path.join(items[0],file)
                        csvList.append(os.path.abspath(relPath))    

            cnt = len(csvList)

            # ===== フォルダ内　件数確認 =====
            if (cnt == 0):
                print u"[adddb_error]",sFolderPath,u"フォルダにCSVファイルがありません"
                # ===== finallyへ =====
                return

            # ===== 取得したCSVリストを繰り返す =====
            for csvfile in csvList:
                csvfile.replace('\t', '\\t')
                # ===== ファイル拡張子 判定 =====
                if self.CSV_FILE_EXTENSION in csvfile:
                    print u"csv"
                else:
                    print u"[adddb_error]", csvfile,u"[error][ファイル名]拡張子が正しくありません"
                    # // forを抜ける
                    break

                # ===== 空ファイルチェック =====
                lines_cnt = sum(1 for line in open(csvfile))
                if (lines_cnt == 0):
                    print "[adddb_error]", csvfile,u"ファイルにデータがありません"
                    # // forを抜ける
                    break

                # ===== CSVファイルコードチェック（utf-8以外はエラー） =====
                ret = self.csvCodeCheck(csvfile)
                if not ret:
                    # // CSVファイルコードチェック[False]の場合forを抜ける
                    break

                # ===== CSVファイル オープン =====
                csvOpen = open(csvfile, "r" )

                # ===== CSVファイル読み込み =====
                csvReader = csv.reader(csvOpen)

                # ===== ヘッダを含まない(先頭行) =====
                #next(csvReader, None)

                # ===== CSVファイル不整合チェック =====
                ret = self.csvDataMismatchCheck(csvReader,csvfile)
                if not ret:
                    # // CSVファイル不整合チェック[False]の場合はforを抜ける
                    break

                # ===== csvファイルクローズ =====
                csvOpen.close()        

            # ===== 戻り値 =====
            if ret:
                ret = True

        except Exception as e:
            # ===== 例外処理 =====
            print u"[adddb_error]", u"Exception" , sys._getframe().f_code.co_name, e.args

            # ===== 戻り値セット =====
            ret = False

        finally: 
            # ===== 終了処理 =====

            # ===== 戻り値 =====
            return ret    


# ============================================================================
#  処　理：[計画リスト]件数確認
#  戻り値：戻り値：件数
# ============================================================================
    def planlistNumberChek(self,connect):
        cursor = connect.cursor()
        # ===== [計画リスト]件数確認 =====        
        sql = ""
        sql = " select count(*) as cnt from shooting_plan"
        cursor.execute(sql)
        # ===== 結果をセット配列化(1件のみ取得) =====
        result = cursor.fetchone()

        # ==== 戻り値 =====
        return  result[0]

# ============================================================================
#  処　理：CSVファイルDB登録
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def dbRegistDatail(self,sFolderPath):
        ret = False
        dbsts = False
        connector = None
        registFiles = ""
        csvList = []

        try:
            # ===== db接続オブジェクト =====
            ret, connector = self.dbConnectCheck() 
            if (ret and connector != None):
                # ===== 接続OK =====
                dbsts = True

            else:
                # ===== 接続NG　finally =====
                return

            # ===== カーソール設定　=====
            connect = connector

            # ===== フォルダ内（サブフォルダ）ファイル件数チェック
            wk = os.walk(sFolderPath)
            for items in wk:
                if (len(items[2]) != 0):
                    for file in items[2]:
                        relPath = os.path.join(items[0],file)
                        csvList.append(os.path.abspath(relPath))

            # =================================================================
            # ===== 指定したフォルダ内のcsvファイルがなくなるまで繰り返す =====
            #==================================================================
            for csvfile in csvList:
                # ===== 文字列置換 =====
                csvfile.replace('\t', '\\t')
                # ===== CSVデータ件数 =====
                #csvDtCnt = sum(1 for line in open(csvfile, "r"))
                if (1 <= sum(1 for line in open(csvfile, "r"))):
                    # ===== CSVファイル オープン =====
                    csvOpen = open(csvfile, "r")

                    # ===== CSVファイル読み込み =====
                    csvReader = csv.reader(csvOpen)
                    # ===== ヘッダを含む場合に使用する：先頭行を含まない =====
                    #next(csvReader, None)

                    # ===== DB登録 計画リスト明細 =====
                    ret = False
                    ret = self.dbRegistShoothingPlanDetaile(connect, csvReader)

                    # ===== csvファイルクローズ =====
                    csvOpen.close()

                    # ===== 戻り値 =====
                    if not ret:
                        # // Falseなら Forを抜ける
                        break
                else:
                    # ===== データ件数がない場合 =====
                    print u"[adddb_error]",csvfile,u"ファイルにデータがありません"
                    break

        except Exception as e:
            # ========== 例外処理 ==========
            print u"[adddb_error]", u"Exception" , sys._getframe().f_code.co_name, e.args

            # ===== 戻り値 =====
            ret = False

        finally:
            # ========== 終了処理 ==========
            if dbsts:
                # // DB関連クローズ,
                connector.close()            

            # ===== 戻り値 =====
            return ret

# ============================================================================
#  処　理：DB登録 計画リスト,計画リスト明細
#  引  数：[cursor] ,[csvReader]
#  戻り値：戻り値：成功(True)/失敗(False)
#  備　考：DB接続は呼びだし元で対応するため、接続正常時が前提
# ============================================================================
    def dbRegistShoothingPlanDetaile(self, connect, csvReader):
        ret = False

        try:
            # ===== カーソール設定　=====
            cursor0 = connect.cursor()
            cursor1 = connect.cursor()
            cursor2 = connect.cursor()
            cursor3 = connect.cursor()
            cursor4 = connect.cursor()

            # ===== CSVファイルの1件目のデータを取得 =====
            wGroup_Id = 0

            wFile_Name = ""
            wFolder_Path = ""
            wImage_Width = 0
            wImage_Heigth = 0
            wRobot_Identifier = ""
            wRobot_Camera_No = 0
            wPosition_Latitude = 0
            wPosition_Longitude = 0
            wPosition_Height = 0
            wSlope_Direction = 0
            wSlope_Pitch = 0
            wSlope_Roll = 0
            wShooting_Date = ""
            wShooting_Time = ""
            wShooting_Plan_Name = ""    

            for row in csvReader:
                #===== 先頭行取得 =====
                wFile_Name = row[0]
                wFolder_Path = row[1]
                wImage_Width = row[2]
                wImage_Heigth = row[3]
                wRobot_Identifier = row[4]
                wRobot_Camera_No = row[5]
                wPosition_Latitude = row[6]
                wPosition_Longitude = row[7]
                wPosition_Height = row[8]
                wSlope_Direction = row[9]
                wSlope_Pitch = row[10]
                wSlope_Roll = row[11]
                wShooting_Date = row[12]
                wShooting_Time = row[13]
                wShooting_Plan_Name = row[14]

                break

            # ========== １件目のロボット識別子からロボットカテゴリーを取得 ==========
            # ===== SQL文生成 =====
            sql = ""
            sql = sql + " select category from robot_category "
            sql = sql + " where robot_identifier = '%s' " 

            # ===== sql実行 =====
            cursor0.execute(sql %(wRobot_Identifier))

            # ===== 結果をセット配列化 (1件のみ取得)=====
            result = cursor0.fetchone()

            # ===== グループカテゴリー 取得 =====
            if result[0] == None:
                print "[adddb_error]", u"[robot_category]テ－ブルにロボットカテゴリが存在しません" ,wRobot_Identifier
                return
            else:
                # ===== ロボットカテゴリーセット =====
                self.m_Param_ulRobotCategory= result[0]

            # ========== [計画リスト]テーブルより[撮影計画名][撮影日]で取得 ==========
            # ===== SQL文生成 =====
            sql = ""
            sql = sql + " select group_id, shooting_plan_name, shooting_Date from shooting_plan"
            sql = sql + " where shooting_plan_name = '%s' and shooting_Date = '%s' "  

            # ===== sql実行 =====
            cursor1.execute(sql %(wShooting_Plan_Name, wShooting_Date))

            # ===== 結果をセット配列化 =====
            result1 = cursor1.fetchall()

            # ===== グループID取得 =====
            # ===== 計画リスト　上記SQLより取得　件数確認 =====
            if cursor1.rowcount == 0:
                # // 上記データ件数が0件の場合：「計画リスト」「計画リスト詳細」テーブルに登録
                # ===== SQL文生成 =====                
                sql = ""
                sql = sql + " select max(group_id) + 1  as cnt from shooting_plan "

                # ===== sql実行 「計画リスト」グループIDの取得 =====
                cursor2.execute(sql)

                # ===== 結果をセット配列化 (1件のみ取得)=====
                result2 = cursor2.fetchone()

                # ===== グループID 取得 =====
                if result2[0] == None:
                    wGroup_Id = 1
                else:
                    wGroup_Id = result2[0]

                # =================================================================
                # ===== 「計画リスト」テーブル登録
                #==================================================================

                # ===== [計画リスト]件数確認 =====
                planCnt = self.planlistNumberChek(connect)

                # ===== 計画リストDB追加 SQL文生成 =====
                sql = ""
                sql = sql + "insert into shooting_plan"
                sql = sql + " (group_id ,shooting_date ,shooting_plan_name, robot_identifier)"
                sql = sql + "  values(%s, %s, %s, %s) "

                # ===== 計画リストDB追加 =====
                cursor3.execute(sql ,(wGroup_Id, wShooting_Date, wShooting_Plan_Name, wRobot_Identifier))


            else:
                # ===== メッセージ表示 =====
                print u"[adddb_error]",u"計画リストに登録済です",unicode(wShooting_Plan_Name,"utf-8")

                # ===== グループIDがすでに登録されているとき グループID取得=====
                for row in result1:
                    wGroup_Id = row[0]
                    wShooting_Plan_Name = row[1]
                    wShooting_Date = row[2]
                    break

            # =================================================================
            # ===== 「計画リスト詳細」テーブル登録
            #==================================================================    

            # ===== 1件目データ登録 =====
            #===== sql文生成 =====
            sql = ""
            sql = sql + "insert into shooting_plan_detail"
            sql = sql + " (" 
            sql = sql + "  group_id"
            sql = sql + " ,file_name"
            sql = sql + " ,folder_path"
            sql = sql + " ,image_width"
            sql = sql + " ,image_height"
            sql = sql + " ,robot_identifier"
            sql = sql + " ,robot_camera_no"
            sql = sql + " ,position_latitude"
            sql = sql + " ,position_longitude"
            sql = sql + " ,position_height"
            sql = sql + " ,slope_direction"
            sql = sql + " ,slope_pitch"
            sql = sql + " ,slope_roll"
            sql = sql + " ,shooting_date"
            sql = sql + " ,shooting_time"
            sql = sql + " ,shooting_plan_name"
            sql = sql + " ) "
            sql = sql + u" values(%s, %s, %s, %s, %s, %s, %s, %s, %s, %s"
            sql = sql + u", %s, %s, %s, %s, %s, %s)"    

            # ===== 「計画リスト詳細」テーブルDB登録 =====                
            cursor4.execute(sql ,(wGroup_Id, wFile_Name, wFolder_Path, wImage_Width, wImage_Heigth,wRobot_Identifier,wRobot_Camera_No,
                                wPosition_Latitude, wPosition_Longitude, wPosition_Height, wSlope_Direction, wSlope_Pitch,
                                wSlope_Roll, wShooting_Date, wShooting_Time, wShooting_Plan_Name))

            # ===== csvファイルのデータがなくなるまで繰り返す 2件目以降 =====

            for row in csvReader:
                #===== sql文生成 =====
                sql = ""
                sql = sql + "insert into shooting_plan_detail"
                sql = sql + " (" 
                sql = sql + "  group_id"
                sql = sql + " ,file_name"
                sql = sql + " ,folder_path"
                sql = sql + " ,image_width"
                sql = sql + " ,image_height"
                sql = sql + " ,robot_identifier"
                sql = sql + " ,robot_camera_no"
                sql = sql + " ,position_latitude"
                sql = sql + " ,position_longitude"
                sql = sql + " ,position_height"
                sql = sql + " ,slope_direction"
                sql = sql + " ,slope_pitch"
                sql = sql + " ,slope_roll"
                sql = sql + " ,shooting_date"
                sql = sql + " ,shooting_time"
                sql = sql + " ,shooting_plan_name"
                sql = sql + " ) "
                sql = sql + u" values(%s, %s, %s, %s, %s, %s, %s, %s, %s, %s"
                sql = sql + u", %s, %s, %s, %s, %s, %s)"    

                # ===== 「計画リスト詳細」テーブルDB登録 =====
                cursor4.execute(sql ,(wGroup_Id,row[0],row[1],row[2],row[3],row[4],row[5],row[6],row[7],row[8],row[9],row[10]
                                ,row[11],row[12],row[13],unicode(row[14],"utf-8")))

            # ===== 戻り値 =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print u"[adddb_error]", u"Exception" , sys._getframe().f_code.co_name, e.args

            # ===== ロールバック =======
            connect.rollback()

            # ===== 戻り値セット =====
            ret = False

        else:
            # ========== 正常処理 ==========
            ret, connector = self.dbConnectCheck()
            if (ret and connector != None):            
                # ===== コミット =======
                connect.commit()

                # ===== カーソルクローズ =====
                cursor0.close()
                cursor1.close()
                cursor2.close()
                cursor3.close()
                cursor4.close()

        finally:
            # ========== 終了処理 ==========
            if ret:
                print "[adddb_debug]dbRegistShoothingPlanDetaile OK"
            else:
                print "[adddb_debug]dbRegistShoothingPlanDetaile NG"

            # ===== 戻り値 =====
            return ret        


# ============================================================================
#  処　理：CSVファイル不整合チェック
#  引  数：csvReader
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def csvDataMismatchCheck(self, csvReader, csvfile):
        ret = False
        sItemNm = u""
        sItem = u""
        iDcnt = 0

        try:

            for row in csvReader:
                #===== CSV列数チェック =====
                if len(row) != 15:
                    print u"[adddb_error]CSV列数チェック NG"
                    sItemNm = u"CSVフォーマ不正です"
                    sItem = csvfile
                    break

                # ===== ファイル名 =====
                str0 =row[0].decode("UTF-8")
                sItemNm = self.csvItem[0]
                sItem = str0
                if (len(str0.encode("shift_jis"))) >= 1 and (len(str0.encode("shift_jis")) <= imp_Versatile.CSV_FILE_NAME_LENGH):
                    pass
                else:
                    print u"[adddb_error]ファイル名=",len(str0.encode("shift_jis"))
                    break

                # ===== フォルダパス =====
                str1 =row[1].decode("UTF-8")
                sItemNm = self.csvItem[1]
                sItem = str1
                if (len(str1.encode("shift_jis"))) >= 1 and (len(str1.encode("shift_jis")) <= imp_Versatile.CSV_FOLDER_PATH_LENGTH):
                    pass
                else:
                    print u"[adddb_error]フォルダパス=",len(str1.encode("shift_jis"))
                    break

                # ===== ザイズ幅 =====
                sItemNm = self.csvItem[2]
                sItem = row[2]
#                if (int(row[2]) > 0 and int(row[2]) <= imp_Versatile.CSV_IMAGE_WIDTH_MAX):
                if (int(row[2]) > 0):
                    pass
                else:
                    print u"[adddb_error]ザイズ幅=",len(str(row[2]))
                    break

                # ===== サイズ高さ =====
                sItemNm = self.csvItem[3]
                sItem = row[3]
#                if (int(row[3]) > 0 and int(row[3]) <= imp_Versatile.CSV_IMAGE_HEIGHT_MAX):
                if (int(row[3]) > 0):
                    pass
                else:
                    print u"[adddb_error]サイズ高さ =",len(str(row[3]))
                    break

                # ===== ロボット識別子 =====
                sItemNm = self.csvItem[4]
                sItem = row[4]
                if (len(str(row[4])) >= 1 and len(str(row[4])) <= imp_Versatile.CSV_ROBOT_IDENTIFIER_LENGH):
                    pass
                else:
                    print u"[adddb_error]ロボット識別子 文字数=",len(str(row[4]))
                    break

                # ===== カメラID =====
                sItemNm = self.csvItem[5]
                sItem = row[5]
                if (int(row[5]) > 0 and int(row[5]) <= imp_Versatile.CSV_CAMERA_NO_MAX):
                    pass
                else:
                    print u"[adddb_error]カメラID=",len(str(row[5]))
                    break

                # ===== 緯度 =====
                sItemNm = self.csvItem[6]
                sItem = row[6]
                if (row[6].replace(".","").isdigit()) and (float(row[6]) > 0):
                    pass
                else:
                    print u"[adddb_error]緯度=",len(str(row[6]))
                    break

                # ===== 経度 =====
                sItemNm = self.csvItem[7]
                sItem = row[7]
                if (row[7].replace(".","").isdigit()) and (float(row[7]) > 0):
                    pass
                else:
                    print u"[adddb_error]経度=",len(str(row[7]))
                    break

                # ===== 高さ =====
                sItemNm = self.csvItem[8]
                sItem = row[8]
                if (row[8].replace(".","").isdigit()):
                    pass
                else:
                    print u"[adddb_error]高さ=",len(str(row[8]))
                    break

                # ===== 方向 =====
                sItemNm = self.csvItem[9]
                sItem = row[9]
                if (int(row[9]) >= imp_Versatile.CSV_ROBOT_DIRECTION_MIN and int(row[9]) <= imp_Versatile.CSV_ROBOT_DIRECTION_MAX):
                    pass
                else:
                    print u"[adddb_error]方向=",len(str(row[9]))
                    break

                # ===== ピッチ角 =====
                sItemNm = self.csvItem[10]
                sItem = row[10]
                if (int(row[10]) >= imp_Versatile.CSV_ROBOT_PITCH_MIN and int(row[10]) <= imp_Versatile.CSV_ROBOT_PITCH_MAX):
                    pass
                else:
                    print u"[adddb_error]ピッチ角=",len(str(row[10]))
                    break

                # ===== ロール角 =====
                sItemNm = self.csvItem[11]
                sItem = row[11]
                if (int(row[11]) >= imp_Versatile.CSV_ROBOT_ROLL_MIN and int(row[11]) <= imp_Versatile.CSV_ROBOT_ROLL_MAX):
                    pass
                else:
                    print u"[adddb_error]ロール角=",len(str(row[11]))
                    break

                # ===== 年月日・時間 =====
                sItemNm = self.csvItem[12] + " " + self.csvItem[13]
                sItem = row[12] + " " + row[13]

                wDate = row[12]
                wYear = int(wDate[0:4])
                wMonth = int(wDate[4:6])
                wDay = int(wDate[6:8])

                wTime = row[13]
                wHour = int(wTime[0:2])
                wMinute = int(wTime[2:4])
                wSecond = int(wTime[4:6])
                wMicrocecond = int(wTime[6:12])

                # // 日付時間が不正の場合はExceptionへ遷移します。
                wDatetime = datetime.datetime(wYear,wMonth,wDay, wHour,wMinute,wSecond,wMicrocecond)

                # ===== 撮影計画名 =====
                str14 =row[14].decode("UTF-8")
                sItemNm = self.csvItem[14]
                sItem = str14

                if (len(str14.encode("shift_jis")) > 0) and (len(str14.encode("shift_jis")) <= imp_Versatile.CSV_SHOOTING_PLAN_NAME_LENGH):
                    # ===== 戻り値セット =====
                    ret = True

                else:
                    print u"[adddb_error]撮影計画名 文字数=",len(str14.encode("shift_jis"))
                    break

                iDcnt =iDcnt + 1

        except Exception as e:
            # ========== 例外処理 ==========
            print "[adddb_error]", u"Exception" , sys._getframe().f_code.co_name, e.args
            ret = False

        finally:
            # ========== 終了処理 ==========
            if ret:
                print "[adddb_debug]",u"csvDataMismatchCheck OK"
            else:
                print "[adddb_error]",u"csvDataMismatchCheck NG",csvfile
                print "[adddb_error]",u"csvDataMismatchCheck NG",sItemNm,sItem

            # ===== 戻り値 =====    
            return ret


# ============================================================================
#  処　理：撮影計画リスト作成
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def makeShootingPlanList(self, ulRobotCategory):
        ret = False
        db_sts = False
        connector = None
        jsonString = ""
        dCnt = 0

        try:
            # ===== db接続チェク =====
            ret, connector = self.dbConnectCheck()
            if (ret and connector != None):
                db_sts = True
            else:
                db_sts = False
                return

            # ===== カーソール設定　=====
            cursor = connector.cursor()

            # ====== 計画リスト並び順 =====            
            if (self._confAlignmentSeq[0] == ""): 
                s_AlignmentSeq = "desc"
            else: 
                s_AlignmentSeq = self._confAlignmentSeq[0]

            # ===== sql文生成 =====
            sql = ""
            sql = sql + " select DISTINCT t1.* from shooting_plan t1"
            sql = sql + " inner join robot_category t2 "
            sql = sql + " on t1.robot_identifier = t2.robot_identifier "
            sql = sql + " where t2.category = '%s' "
            sql = sql + " order by t1.shooting_date %s ,t1.shooting_plan_name asc limit %s"

            # ===== sql実行 =====
            print self.ROBOT_CATEGORY[ulRobotCategory]

            cursor.execute(sql %(self.ROBOT_CATEGORY[ulRobotCategory], 
                                s_AlignmentSeq, 
                                imp_Versatile.PLAN_LIST_NUM_MAX))
            # ===== データ件数 =====
            dCnt = cursor.rowcount

            # ===== 結果をセット配列化 =====
            result = cursor.fetchall()

            # ===== 取得データ json =====
            jsonList = []
            for row in result:
                jsonList.append({"group_id" : row[0], "date" : row[1], "plan_name" : row[2], "robot_identifier" : row[3] })

            # ===== json変換 =====
            # #// jsonは文字、数値のみ（日付型は変換が必要）
            jsonString = json.dumps(jsonList, sort_keys = False,indent = 4)

            # ===== 戻り値セット =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[adddb_error]", u"Exception" , sys._getframe().f_code.co_name, e.args

            # ===== 戻り値セット =====
            ret = False
            jsonString = ""

        finally:
            # ========== 終了処理 ==========
            # ===== DB関連クローズ ===== 
            ret, connector = self.dbConnectCheck()
            if db_sts:
                cursor.close()
                connector.close()

            # ===== 戻り値 =====
            return (ret, jsonString, dCnt)


# ============================================================================
#  処　理：座標指定画像付加データ取得
#  引　数：ロボットカテゴリー：グループID：始点緯度：始点経度：終点緯度：終点経度
#  戻り値：戻り値：成功(True)/失敗(False)
# ============================================================================
    def coordinateDataGet(self, ulRobotCategory, ulGroupId, dStartLatitude, dStartLongitude, dEndLatitude, dEndLongitude):
        ret = False
        db_sts = False
        connector = None
        jsonString= ""    
        dCnt = 0

        try:
            # ===== db接続チェク =====
            ret, connector = self.dbConnectCheck()
            if (ret and connector != None):
                db_sts = True
            else:
                db_sts = False
                return

            # ===== カーソール設定　=====
            cursor = connector.cursor()

            sql = ""
            sql = sql + " select DISTINCT t1.* from shooting_plan_detail t1"
            sql = sql + " inner join robot_category t2"
            sql = sql + " on t1.robot_identifier = t2.robot_identifier"
            sql = sql + " where t2.category = '%s' " 
            sql = sql + " and t1.group_id = %s "
            sql = sql + " and t1.position_latitude >= %s " 
            sql = sql + " and t1.position_latitude <= %s " 
            sql = sql + " and t1.position_longitude >= %s"
            sql = sql + " and t1.position_longitude <= %s"
            sql = sql + " limit %s"

            # ===== sql実行 =====
            cursor.execute(sql %(self.ROBOT_CATEGORY[ulRobotCategory]
                                ,ulGroupId
                                ,dStartLatitude
                                ,dEndLatitude 
                                ,dStartLongitude
                                ,dEndLongitude
                                ,imp_Versatile.COORDINATE_DATA_MAX))
            # ===== データ件数 =====
            dCnt = cursor.rowcount

            # ===== 結果をセット配列化 =====
            result = cursor.fetchall()

            # ===== 取得データ =====
            jsonList = []

            for row in result:
                jsonList.append({"shooting_id" : row[0]
                                , "group_id" : row[1]
                                , imp_Versatile.IMGADDDB_FILE_NAME : row[2]
                                , imp_Versatile.IMGADDDB_FOLDER_PATH : row[3]
                                , imp_Versatile.IMGADDDB_IMAGE_WIDTH : row[4]
                                , imp_Versatile.IMGADDDB_IMAGE_HEIGHT : row[5]
                                , imp_Versatile.IMGADDDB_ROBOT_IDENTIFIER : row[6]
                                , imp_Versatile.IMGADDDB_CAMERA_NO : row[7]
                                , imp_Versatile.IMGADDDB_LATITUDE : row[8]
                                , imp_Versatile.IMGADDDB_LONGITUDE : row[9]
                                , imp_Versatile.IMGADDDB_ALTITUDE : row[10]
                                , imp_Versatile.IMGADDDB_DIRECTION : row[11]
                                , imp_Versatile.IMGADDDB_PITCH : row[12]
                                , imp_Versatile.IMGADDDB_ROLL : row[13]
                                , "shooting_date" : row[14]
                                , "shooting_time" : row[15]
                                , imp_Versatile.IMGADDDB_SHOOTING_PLAN_NAME : row[16]
                                   })

            # ===== json変換 =====
            # #// jsonは文字、数値のみ（日付型は変換が必要）
            jsonString = json.dumps(jsonList, sort_keys = False,indent = 4, ensure_ascii=False)

            # ===== 戻り値 =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print u"[adddb_error]", u"Exception" , sys._getframe().f_code.co_name, e.args

            # ===== 戻り値 =====
            ret = False
            jsonString = ""
            dCnt = 0

        finally:
            # ========== 終了処理 ==========
            # ===== DB関連クローズ =====
            ret, connector = self.dbConnectCheck()
            if (ret and connector != None):
                cursor.close()
                connector.close()

            # ===== 戻り値 =====
            return (ret, jsonString, dCnt)


# ============================================================================
#  処　理：撮影時刻順画像付加データ取得
#  引　数：ロボットカテゴリー/グループID
#  戻り値：成功(True)/失敗(False)：jsonデータ：取得データ件数
# ============================================================================
    def shootingTimeDateGet(self, ulRobotCategory, ulGroupId ,ulImageAcq, ulReq):
        ret = False
        db_sts = False
        connector = None
        jsonString= ""
        dCnt = 0
        wNo = 0
        wFirstTime = ""
        WLastTime = ""

        try:
            # ===== db接続チェク =====
            ret, connector = self.dbConnectCheck()
            if (ret and connector != None):
                db_sts = True
            else:
                db_sts = False
                return

            # ===== カーソール設定　=====
            cursor = connector.cursor()

            # =========================
            #     １件目データ取得
            # =========================
            if ((ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_START) or 
                (imp_CommPara.SHOOTING_TIME_LAST_DATE == "") or 
                (imp_CommPara.SHOOTING_TIME_LAST_TIME == "")):
                # ===== START =====
                wNo = self.shootingTimeDateGetStart(ulRobotCategory, ulGroupId, ulImageAcq, ulReq, connector)

            elif (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_UP) or (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_DOWN):
                # ===== UP　DOWN =====
                wNo = self.shootingTimeDateGetUpDown(ulRobotCategory, ulGroupId, ulImageAcq, connector)

            # ===== 取得件数が無いときのメッセージ =====
            if (wNo == 0) and (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_UP):
                ret = False
                print u"[adddb_messege]次のデータがありません"
                return 
            elif (wNo == 0) and (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_DOWN):
                ret = False
                print u"[adddb_messege]前のデータがありません"
                return 

            # ===================================
            #     sql文生成 上記sql実行後のデータを元に抽出 
            # =================================== 
            # ===== sql文生成　上記sql実行後のデータを元に抽出 =====
            sql = ""
            sql = sql + " select t1.* "
            sql = sql + " from shooting_plan_detail t1 "
            sql = sql + " inner join robot_category t2 "
            sql = sql + " on t1.robot_identifier = t2.robot_identifier "
            sql = sql + " where t2.category = '%s' " 
            sql = sql + " and t1.group_id = %s "
            sql = sql + " and t1.image_id >= %s "
            sql = sql + " limit %s"

            # ===============================
            #    sql実行 
            # ===============================
            cursor.execute(sql %(self.ROBOT_CATEGORY[ulRobotCategory], ulGroupId, wNo ,self.CAMERA_NUMBER))

            print "confSecond=",self._confSecond[0]
            print "ImageAcq",ulImageAcq,"ROBOT_CATEGORY=",self.ROBOT_CATEGORY[ulRobotCategory],"GroupId=",ulGroupId, "wNo=",wNo

            # ===== 取得件数が無いときのメッセージ =====
            if (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_UP and cursor.rowcount == 0):
                print u"[adddb_messege]次のデータがありません"
            elif (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_DOWN and cursor.rowcount == 0):
                print u"[adddb_messege]前のデータがありません"

            # ====== 画像取得区分  [STOP]以外 =====
            if (ulImageAcq != imp_Versatile.SHOOTING_IMAGE_ACQ_STOP):

                # ===== 結果をセット配列化 =====
                result = cursor.fetchall()

                # ===== データ件数 ===== 
                dCnt = cursor.rowcount

                # ===== 取得データ 作成 =====
                jsonList = []
                for row in result:
                    jsonList.append({"shooting_id" : row[0]
                                , imp_Versatile.IMGADDDB_FILE_NAME : row[2]
                                , imp_Versatile.IMGADDDB_FOLDER_PATH : row[3]
                                , imp_Versatile.IMGADDDB_IMAGE_WIDTH : row[4]
                                , imp_Versatile.IMGADDDB_IMAGE_HEIGHT : row[5]
                                , imp_Versatile.IMGADDDB_ROBOT_IDENTIFIER : row[6]
                                , imp_Versatile.IMGADDDB_CAMERA_NO : row[7]
                                , imp_Versatile.IMGADDDB_LATITUDE : row[8]
                                , imp_Versatile.IMGADDDB_LONGITUDE : row[9]
                                , imp_Versatile.IMGADDDB_ALTITUDE : row[10]
                                , imp_Versatile.IMGADDDB_DIRECTION : row[11]
                                , imp_Versatile.IMGADDDB_PITCH : row[12]
                                , imp_Versatile.IMGADDDB_ROLL : row[13]
                                    , "shooting_date" : row[14] 
                                    , "shooting_time" : row[15] 
                                , imp_Versatile.IMGADDDB_SHOOTING_PLAN_NAME : row[16]
                                    })

                    # ===== 撮影時刻→前回時刻に退避 =====
                    if row[7] == 1:
                        imp_CommPara.SHOOTING_TIME_FIRST_DATE = row[14]
                        imp_CommPara.SHOOTING_TIME_FIRST_TIME = row[15] 
                    elif row[7] == 4:
                        imp_CommPara.SHOOTING_TIME_LAST_DATE = row[14]
                        imp_CommPara.SHOOTING_TIME_LAST_TIME = row[15] 

                # ===== json変換 =====
                # jsonは文字、数値のみ（日付型は変換が必要）
                jsonString = json.dumps(jsonList, sort_keys = False,indent = 4)

            else:
                # ===== 前回取得　撮影日、撮影時間　クリア =====
                imp_CommPara.SHOOTING_TIME_FIRST_DATE = ""
                imp_CommPara.SHOOTING_TIME_FIRST_TIME = ""
                imp_CommPara.SHOOTING_TIME_LAST_DATE = ""
                imp_CommPara.SHOOTING_TIME_LAST_TIME = ""

            # ===== 戻り値セット =====
            ret = True

        except Exception as e:
            # ===== 例外処理 =====
            print "[adddb_error]", u"Exception" , sys._getframe().f_code.co_name, e.args

            # ===== 戻り値 =====
            ret = False
            jsonString = ""
            dCnt = 0

        finally:
            # ========== 終了処理 ==========
            # ===== DB関連クローズ ======
            ret, connector = self.dbConnectCheck()
            if (ret and connector != None):
                cursor.close()
                connector.close()

            # ===== 戻り値 =====
            return (ret, jsonString, dCnt)

# ============================================================================
#    日付変換    
# ============================================================================
    def shootingTimeDateGetDate(self, ulImageAcq):
        # ===== 検索用日付 =====
        if (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_UP) or (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_DOWN):
            if ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_UP:
                wDate = imp_CommPara.SHOOTING_TIME_LAST_DATE 
                wTime = imp_CommPara.SHOOTING_TIME_LAST_TIME.ljust(12,'0')
            elif ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_DOWN:
                wDate = imp_CommPara.SHOOTING_TIME_FIRST_DATE 
                wTime = imp_CommPara.SHOOTING_TIME_FIRST_TIME.ljust(12,'0')
            # ===== 日付時間設定 =====
            wYear = int(wDate[0:4])
            wMonth = int(wDate[4:6])
            wDay = int(wDate[6:8])

            #wTime = imp_CommPara.SHOOTING_TIME_LAST_TIME.ljust(12,'0')
            wHour = int(wTime[0:2])
            wMinute = int(wTime[2:4])
            wSecond = int(wTime[4:6])
            wMicrocecond = int(wTime[6:12])

            # ===== 日付時間が不正の場合はExceptionへ遷移します。=====
            wDatetime = datetime.datetime(wYear,wMonth,wDay, wHour,wMinute,wSecond,wMicrocecond)

            wNextDate = ""
            if (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_UP):
                wNextDate = wDatetime + datetime.timedelta(seconds = self._confSecond[0])

            if (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_DOWN):
                wNextDate = wDatetime - datetime.timedelta(seconds = self._confSecond[0])

            print "shootingTimeDateGetDate wNextDate", wNextDate
            # ===== 日付時刻→文字列 =====
            wStrDate = wNextDate.strftime("%Y%m%d")
            wStrTime = wNextDate.strftime("%H%M%S%f")

        return (wStrDate, wStrTime)


# ============================================================================
#     sql文生成<１件目> START
# ============================================================================
    def shootingTimeDateGetStart(self, ulRobotCategory, ulGroupId ,ulImageAcq, ulReq, connector):
        # ===== [START]　又は[UP],[DOWN]で前回日付と前回時間が""の場合 カメラＮｏ１のデータを取得（日付・時間の古いデータ） =====

        # ===== SQL文生成 =====
        sql = ""
        sql = sql + " select DISTINCT t1.* "
        sql = sql + " from shooting_plan_detail t1 "
        sql = sql + " inner join robot_category t2"
        sql = sql + " on t1.robot_identifier = t2.robot_identifier"
        sql = sql + " where t2.category = '%s' " 
        sql = sql + " and t1.group_id = %s "
        sql = sql + " and t1.robot_camera_no = '1' "
        sql = sql + " ORDER BY t1.shooting_date,t1.shooting_time,t1.robot_camera_no "
        sql = sql + " limit 1 " 

        # ===== カーソール設定　=====
        cursor = connector.cursor()

        # ===== SQL実行 =====
        cursor.execute(sql %(self.ROBOT_CATEGORY[ulRobotCategory], ulGroupId))

        # ===== 結果をセット配列化 (1件のみ取得)=====
        result = cursor.fetchone()

        # ===== No取得 =====
        if cursor.rowcount == 0:
            wNo = 0
        else:
            wNo = result[0]

        print "shootingTimeDateGetStart=", ulGroupId,wNo
        # ===== カーソールクローズ　=====
        cursor.close()

        return (wNo)


# ============================================================================
#     sql文生成<１件目> UP/DOWN
# ============================================================================
    def shootingTimeDateGetUpDown(self, ulRobotCategory, ulGroupId ,ulImageAcq, connector):
        # ===== 前回日付取得 =====
        wStrDate, wStrTime = self.shootingTimeDateGetDate(ulImageAcq)

        wSqlParam1 = ""
        wSqlParam2 = ""
        wSqlParam3 = ""
        if (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_UP) :
            wSqlParam1 = " and t1.shooting_date >= "
            wSqlParam2 = " and RPAD(t1.shooting_time,12,'0') >= "
            wSqlParam3 = " "
        elif (ulImageAcq == imp_Versatile.SHOOTING_IMAGE_ACQ_DOWN):
            wSqlParam1 = " and t1.shooting_date <= " 
            wSqlParam2 = " and RPAD(t1.shooting_time,12,'0') < "
            wSqlParam3 = " ORDER BY t1.shooting_time DESC "

        # ===== SQL文生成 =====
        sql = ""
        sql = sql + " select DISTINCT t1.* "
        sql = sql + " from shooting_plan_detail t1 "
        sql = sql + " inner join robot_category t2 "
        sql = sql + " on t1.robot_identifier = t2.robot_identifier"
        sql = sql + " where t2.category = '%s' " 
        sql = sql + " and t1.group_id = %s "
        sql = sql + " and t1.robot_camera_no = '1' "
        sql = sql + wSqlParam1 + "'%s'"
        sql = sql + wSqlParam2 + "'%s'"
        sql = sql + wSqlParam3 + " "
        sql = sql + " limit 1 " 

        # ===== カーソール設定　=====
        cursor = connector.cursor()

        # ===== SQL実行 =====
        cursor.execute(sql %(self.ROBOT_CATEGORY[ulRobotCategory], ulGroupId, wStrDate, wStrTime))

        # ===== 結果をセット配列化 (1件のみ取得)=====
        result = cursor.fetchone()

        # ===== No取得 =====
        if cursor.rowcount == 0:
            wNo = 0
        else:
            wNo = result[0]

        print "shootingTimeDateGetUpDown=", ulGroupId, wStrDate, wStrTime,wNo
        # ===== カーソールクローズ　=====
        cursor.close()

        return wNo


def AdditionalDataDBControlInit(manager):
    profile = OpenRTM_aist.Properties(defaults_str=additionaldatadbcontrol_spec)
    manager.registerFactory(profile,
                            AdditionalDataDBControl,
                            OpenRTM_aist.Delete)


def MyModuleInit(manager):
    AdditionalDataDBControlInit(manager)

    # Create a component
    comp = manager.createComponent("AdditionalDataDBControl")


def main():
    mgr = OpenRTM_aist.Manager.init(sys.argv)
    mgr.setModuleInitProc(MyModuleInit)
    mgr.activateManager()
    mgr.runManager()

if __name__ == "__main__":
    main()

