#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -*- Python -*-
from time import sleep
from _ctypes import alignment

"""
 @file TwoDRobotInfoMonitorGui.py
 @brief 本モジュールはユーザーが操作するキーや、画像やセンサー表示などのビューアを制御する。
 @date $Date$

 @author East Japan Accounting Center Co.,Ltd.
 
 (c)2017 The University of Aizu
 This software is released under the New BSD License.

"""
import sys
import math
import time
import datetime
import re
# ===================================================================
import json
import os
import cv2
import numpy as np
from math import modf
import ast
# gui
from PyQt4 import QtCore, QtGui
from PyQt4.QtCore import Qt,QObject, pyqtSignal, QPoint
from PyQt4.QtGui import QApplication, QWidget, QPainter, QPen, QImage, QFontMetricsF, QColor, QGraphicsItem

# uidesign
from TwoDRobotInfoMonitorGuiDesign import Ui_MainWindow
# constant
import VersatileOverheadSystem as SystemMacro
# ===================================================================

sys.path.append(".")

# Import RTM module
import RTC
import OpenRTM_aist

import TwoDRobotInfoMonitorGui_idl
import VersatileOverheadManager_idl

# Import Service implementation class
# <rtc-template block="service_impl">
from TwoDRobotInfoMonitorGui_idl_example import *

# </rtc-template>

# Import Service stub modules
# <rtc-template block="consumer_import">
import VersatileGuiReqServ, VersatileGuiReqServ__POA
import VersatileGuiReqServ, VersatileGuiReqServ__POA
import VersatileGuiReqServ, VersatileGuiReqServ__POA
import VersatileGuiReqServ, VersatileGuiReqServ__POA
import VersatileGuiReqServ, VersatileGuiReqServ__POA
import VersatileGuiReqServ, VersatileGuiReqServ__POA
import VersatileGuiReqServ, VersatileGuiReqServ__POA
import TwoDRobotMoniGuiReqServ, TwoDRobotMoniGuiReqServ__POA
import VersatileMgrStsServ, VersatileMgrStsServ__POA
import VersatileMgrStsServ, VersatileMgrStsServ__POA


# </rtc-template>


# This module's spesification
# <rtc-template block="module_spec">
twodrobotinfomonitorgui_spec = ["implementation_id", "TwoDRobotInfoMonitorGui", 
         "type_name",         "TwoDRobotInfoMonitorGui", 
         "description",       "本モジュールはユーザーが操作するキーや、画像やセンサー表示などのビューアを制御する。", 
         "version",           "0.1", 
         "vendor",            "EAC", 
         "category",          "GUI", 
         "activity_type",     "STATIC", 
         "max_instance",      "1", 
         "language",          "Python", 
         "lang_type",         "SCRIPT",
         "conf.default.01_GPSDispCycle", "1",
         "conf.default.02_EnryuMarkSize", "S",
         "conf.default.03_SpiderMarkSize", "S",
         "conf.default.04_GoroneMarkSize", "S",
         "conf.default.05_DroneMarkSize", "S",
         "conf.default.06_Enryu_Correct_Lat", "0.000000",
         "conf.default.07_Enryu_Correct_Lon", "0.000000",
         "conf.default.08_Spider_Correct_Lat", "0.000000",
         "conf.default.09_Spider_Correct_Lon", "0.000000",
         "conf.default.10_Gorone_Correct_Lat", "0.000000",
         "conf.default.11_Gorone_Correct_Lon", "0.000000",
         "conf.default.12_Drone_Correct_Lat", "0.000000",
         "conf.default.13_Drone_Correct_Lon", "0.000000",
         "conf.__widget__.01_GPSDispCycle", "spin.1",
         "conf.__widget__.02_EnryuMarkSize", "radio",
         "conf.__widget__.03_SpiderMarkSize", "radio",
         "conf.__widget__.04_GoroneMarkSize", "radio",
         "conf.__widget__.05_DroneMarkSize", "radio",
         "conf.__widget__.06_Enryu_Correct_Lat", "spin.0.000001",
         "conf.__widget__.07_Enryu_Correct_Lon", "spin.0.000001",
         "conf.__widget__.08_Spider_Correct_Lat", "spin.0.000001",
         "conf.__widget__.09_Spider_Correct_Lon", "spin.0.000001",
         "conf.__widget__.10_Gorone_Correct_Lat", "spin.0.000001",
         "conf.__widget__.11_Gorone_Correct_Lon", "spin.0.000001",
         "conf.__widget__.12_Drone_Correct_Lat", "spin.0.000001",
         "conf.__widget__.13_Drone_Correct_Lon", "spin.0.000001",
         "conf.__constraints__.01_GPSDispCycle", "1<=x<=10",
         "conf.__constraints__.02_EnryuMarkSize", "(S,M,L)",
         "conf.__constraints__.03_SpiderMarkSize", "(S,M,L)",
         "conf.__constraints__.04_GoroneMarkSize", "(S,M,L)",
         "conf.__constraints__.05_DroneMarkSize", "(S,M,L)",
         "conf.__constraints__.06_Enryu_Correct_Lat", "-0.999999<=x<=0.999999",
         "conf.__constraints__.07_Enryu_Correct_Lon", "-0.999999<=x<=0.999999",
         "conf.__constraints__.08_Spider_Correct_Lat", "-0.999999<=x<=0.999999",
         "conf.__constraints__.09_Spider_Correct_Lon", "-0.999999<=x<=0.999999",
         "conf.__constraints__.10_Gorone_Correct_Lat", "-0.999999<=x<=0.999999",
         "conf.__constraints__.11_Gorone_Correct_Lon", "-0.999999<=x<=0.999999",
         "conf.__constraints__.12_Drone_Correct_Lat", "-0.999999<=x<=0.999999",
         "conf.__constraints__.13_Drone_Correct_Lon", "-0.999999<=x<=0.999999",
         ""]
# </rtc-template>

##
# @class TwoDRobotInfoMonitorGui
# @brief 本モジュールはユーザーが操作するキーや、画像やセンサー表示などのビューアを制御する。
# 
# 別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
# 
# 別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
# 
# 別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
# 
# 別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
# 
# 
class TwoDRobotInfoMonitorGui(OpenRTM_aist.DataFlowComponentBase):
    
    ##
    # @brief constructor
    # @param manager Maneger Object
    # 
    def __init__(self, manager):
        OpenRTM_aist.DataFlowComponentBase.__init__(self, manager)

        self._d_inDroneShootingPlanList = RTC.TimedStringSeq(RTC.Time(0,0),[])
        """
        ドローンの撮影計画リストをJson形式で取得する
         - Type: RTC::TimedStringSeq
         - Number: MAX100件
         - Semantics: -
         - Unit: -
         - Frequency: GUI画面起動時、DB登録要求時
         - Operation Cycle: GUI画面起動時、DB登録要求時
        """
        self._inDroneShootingPlanListIn = OpenRTM_aist.InPort("inDroneShootingPlanList", self._d_inDroneShootingPlanList)
        self._d_inCrawlerShootingPlanList = RTC.TimedStringSeq(RTC.Time(0,0),[])
        """
        災害対応ロボットの撮影計画リストをJson形式で取得する
         - Type: RTC::TimedStringSeq
         - Number: MAX100件
         - Semantics: -
         - Unit: -
         - Frequency: GUI画面起動時、DB登録要求時
         - Operation Cycle: GUI画面起動時、DB登録要求時
        """
        self._inCrawlerShootingPlanListIn = OpenRTM_aist.InPort("inCrawlerShootingPlanList", self._d_inCrawlerShootingPlanList)
        self._d_inSynthesisPlanList = RTC.TimedStringSeq(RTC.Time(0,0),[])
        """
        合成計画リストをJson形式で取得する
         - Type: RTC::TimedStringSeq
         - Number: MAX100件
         - Semantics: -
         - Unit: -
         - Frequency: GUI画面起動時、DB登録要求時
         - Operation Cycle: GUI画面起動時、DB登録要求時
        """
        self._inSynthesisPlanListIn = OpenRTM_aist.InPort("inSynthesisPlanList", self._d_inSynthesisPlanList)
        self._d_inMapImageStartGpsData = RTC.GPSData(RTC.Time(0,0), RTC.GPSTime(0,0), 0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0, RTC.GPS_FIX_NONE)
        """
        写真地図の起点座標データを取得する
         - Type: RTC::GPSData
         - Number: 1
         - Semantics: -
         - Unit: -
         - Frequency: 写真地図表示更新時
         - Operation Cycle: 写真地図表示更新時
        """
        self._inMapImageStartGpsDataIn = OpenRTM_aist.InPort("inMapImageStartGpsData", self._d_inMapImageStartGpsData)
        self._d_inMapImageEndGpsData = RTC.GPSData(RTC.Time(0,0), RTC.GPSTime(0,0), 0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0, RTC.GPS_FIX_NONE)
        """
        写真地図の終点座標データを取得する
         - Type: RTC::GPSData
         - Number: 1
         - Semantics: -
         - Unit: -
         - Frequency: 写真地図表示更新時
         - Operation Cycle: 写真地図表示更新時
        """
        self._inMapImageEndGpsDataIn = OpenRTM_aist.InPort("inMapImageEndGpsData", self._d_inMapImageEndGpsData)
        self._d_inMapImageData = RTC.CameraImage(RTC.Time(0,0),0,0,0,"",0.0,"")
        """
        写真地図画像データを取得する
         - Type: RTC::CameraImage
         - Number: 1
         - Semantics: -
         - Unit: -
         - Frequency: 写真地図表示更新時
         - Operation Cycle: 写真地図表示更新時
        """
        self._inMapImageDataIn = OpenRTM_aist.InPort("inMapImageData", self._d_inMapImageData)
        self._d_inRobotGpsData = RTC.TimedString(RTC.Time(0,0), "")
        """
        複数台のロボットGPSデータをJson形式でまとめて取得する
         - Type: RTC::TimedString
         - Number: 1
         - Semantics: -
         - Unit: -
         - Frequency: ロボットGPSデータ管理コンポーネントに依存
         - Operation Cycle: ロボットGPSデータ管理コンポーネントに依存
        """
        self._inRobotGpsDataIn = OpenRTM_aist.InPort("inRobotGpsData", self._d_inRobotGpsData)
        self._d_inRobotSensorData = RTC.TimedString(RTC.Time(0,0), "")
        """
        ロボットセンサデータをJson形式で取得する
         - Type: RTC::TimedString
         - Number: 1
         - Semantics: -
         - Unit: -
         - Frequency: ロボットセンサデータ管理コンポーネントに依存
         - Operation Cycle: ロボットセンサデータ管理コンポーネントに依存
        """
        self._inRobotSensorDataIn = OpenRTM_aist.InPort("inRobotSensorData", self._d_inRobotSensorData)

        """
        h28年度GUIのKey押下状態を通知するインターフェース
        Interface: 画像付加データ登録キーや、写真地図表示更新キーなどの押下状態を通知
                   する
        """
        self._VersatileGuiReqServPort = OpenRTM_aist.CorbaPort("VersatileGuiReqServ")
        """
        h29年度GUIのKey押下状態を通知するインターフェース
        Interface: ロボットセンサ情報表示更新キーなどの押下状態を通知する
        """
        self._TwoDRobotMoniGuiReqServPort = OpenRTM_aist.CorbaPort("TwoDRobotMoniGuiReqServ")
        """
        システム状態管理関連のインターフェース
        Interface: システム状態や動作完了通知を提供する
        """
        self._VersatileMgrStsServPort = OpenRTM_aist.CorbaPort("VersatileMgrStsServ")

        """
        画像付加データ登録キーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqDBRegistKeyProv = GuiReqDBRegistKey_i()
        """
        合成計画リスト削除キーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqSynthesisPlanListDelKeyProv = GuiReqSynthesisPlanListDelKey_i()
        """
        タイル生成キーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqTileGenerationKeyProv = GuiReqTileGenerationKey_i()
        """
        写真地図表示更新キーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqDisplayUpdateKeyProv = GuiReqDisplayUpdateKey_i()
        """
        十字キーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqArrowKeyProv = GuiReqArrowKey_i()
        """
        ズームレベル設定キーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqZoomKeyProv = GuiReqZoomKey_i()
        """
        地図切り替えキーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqMapChangeKeyProv = GuiReqMapChangeKey_i()
        """
        ロボットセンサ情報表示更新キーの押下状態を通知する
         - Argument:      別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Return Value:  別紙"機能仕様書_2Dロボット情報モニタシステムGUIRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._GuiReqMonitorUpdateKeyProv = GuiReqSensorInfoUpdateKey_i()
        

        """
        マネージャコンポーネントのステータスを通知する
         - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC"参照
         - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._VersatileMgrStsCons = OpenRTM_aist.CorbaConsumer(interfaceType=VersatileMgrStsServ.VersatileMgrSts)
        """
        マネージャコンポーネントの完了通知を通知する
         - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC"参照
         - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC"参照
         - Exception:     -
         - PreCondition:  -
         - PostCondition: -
        """
        self._VersatileMgrCompNoticeCons = OpenRTM_aist.CorbaConsumer(interfaceType=VersatileMgrStsServ.VersatileMgrCompNotice)

        # initialize of configuration-data.
        # <rtc-template block="init_conf_param">
        """
        ロボットのGSP表示更新周期を調整する
         - Name: 01_GPSDispCycle 01_GPSDispCycle
         - DefaultValue: 1
         - Unit: sec
         - Range: 1<=x<=10
         - Constraint: -
        """
        self._01_GPSDispCycle = [1]
        """
        援竜用GPSマーク表示のサイズを調整する
         - Name: 02_EnryuMarkSize 02_EnryuMarkSize
         - DefaultValue: S
         - Unit: -
         - Range: (S,M,L)
         - Constraint: -
        """
        self._02_EnryuMarkSize = ['S']
        """
        スパイダー用GPSマーク表示のサイズを調整する
         - Name: 03_SpiderMarkSize 03_SpiderMarkSize
         - DefaultValue: S
         - Unit: -
         - Range: (S,M,L)
         - Constraint: -
        """
        self._03_SpiderMarkSize = ['S']
        """
        ゴローン用GPSマーク表示のサイズを調整する
         - Name: 04_GoroneMarkSize 04_GoroneMarkSize
         - DefaultValue: S
         - Unit: -
         - Range: (S,M,L)
         - Constraint: -
        """
        self._04_GoroneMarkSize = ['S']
        """
        ドローン用GPSマーク表示のサイズを調整する
         - Name: 05_DroneMarkSize 05_DroneMarkSize
         - DefaultValue: S
         - Unit: -
         - Range: (S,M,L)
         - Constraint: -
        """
        self._05_DroneMarkSize = ['S']
        """
        援竜 GPS表示位置(緯度)を補正する
         - Name: 06_Enryu_Correct_Lat 06_Enryu_Correct_Lat
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._06_Enryu_Correct_Lat = [0.000000]
        """
        援竜 GPS表示位置(経度)を補正する
         - Name: 07_Enryu_Correct_Lon 07_Enryu_Correct_Lon
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._07_Enryu_Correct_Lon = [0.000000]
        """
        スパイダー GPS表示位置(緯度)を補正する
         - Name: 08_Spider_Correct_Lat 08_Spider_Correct_Lat
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._08_Spider_Correct_Lat = [0.000000]
        """
        スパイダー GPS表示位置(経度)を補正する
         - Name: 09_Spider_Correct_Lon 09_Spider_Correct_Lon
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._09_Spider_Correct_Lon = [0.000000]
        """
        ゴローン GPS表示位置(緯度)を補正する
         - Name: 10_Gorone_Correct_Lat 10_Gorone_Correct_Lat
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._10_Gorone_Correct_Lat = [0.000000]
        """
        ゴローン GPS表示位置(経度)を補正する
         - Name: 11_Gorone_Correct_Lon 11_Gorone_Correct_Lon
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._11_Gorone_Correct_Lon = [0.000000]
        """
        ドローン GPS表示位置(緯度)を補正する
         - Name: 12_Drone_Correct_Lat 12_Drone_Correct_Lat
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._12_Drone_Correct_Lat = [0.000000]
        """
        ドローン GPS表示位置(経度)を補正する
         - Name: 13_Drone_Correct_Lon 13_Drone_Correct_Lon
         - DefaultValue: 0.000000
         - Unit: -
         - Range: -0.999999<=x<=0.999999
         - Constraint: -
        """
        self._13_Drone_Correct_Lon = [0.000000]
        
        # </rtc-template>


         
    ##
    # 2Dロボット情報モニタシステムGUIの初期化処理
    #
    # The initialize action (on CREATED->ALIVE transition)
    # formaer rtc_init_entry() 
    # 
    # @return RTC::ReturnCode_t
    # 
    # @pre -
    # @post -
    #
    def onInitialize(self):
        print "[debug]onInitialize"

        # Bind variables and configuration variable
        self.bindParameter("01_GPSDispCycle", self._01_GPSDispCycle, "1")
        self.bindParameter("02_EnryuMarkSize", self._02_EnryuMarkSize, "S")
        self.bindParameter("03_SpiderMarkSize", self._03_SpiderMarkSize, "S")
        self.bindParameter("04_GoroneMarkSize", self._04_GoroneMarkSize, "S")
        self.bindParameter("05_DroneMarkSize", self._05_DroneMarkSize, "S")
        self.bindParameter("06_Enryu_Correct_Lat", self._06_Enryu_Correct_Lat, "0.000000")
        self.bindParameter("07_Enryu_Correct_Lon", self._07_Enryu_Correct_Lon, "0.000000")
        self.bindParameter("08_Spider_Correct_Lat", self._08_Spider_Correct_Lat, "0.000000")
        self.bindParameter("09_Spider_Correct_Lon", self._09_Spider_Correct_Lon, "0.000000")
        self.bindParameter("10_Gorone_Correct_Lat", self._10_Gorone_Correct_Lat, "0.000000")
        self.bindParameter("11_Gorone_Correct_Lon", self._11_Gorone_Correct_Lon, "0.000000")
        self.bindParameter("12_Drone_Correct_Lat", self._12_Drone_Correct_Lat, "0.000000")
        self.bindParameter("13_Drone_Correct_Lon", self._13_Drone_Correct_Lon, "0.000000")
        
        # Set InPort buffers
        self.addInPort("inDroneShootingPlanList",self._inDroneShootingPlanListIn)
        self.addInPort("inCrawlerShootingPlanList",self._inCrawlerShootingPlanListIn)
        self.addInPort("inSynthesisPlanList",self._inSynthesisPlanListIn)
        self.addInPort("inMapImageStartGpsData",self._inMapImageStartGpsDataIn)
        self.addInPort("inMapImageEndGpsData",self._inMapImageEndGpsDataIn)
        self.addInPort("inMapImageData",self._inMapImageDataIn)
        self.addInPort("inRobotGpsData",self._inRobotGpsDataIn)
        self.addInPort("inRobotSensorData",self._inRobotSensorDataIn)
        
        # Set OutPort buffers
        
        # Set service provider to Ports
        self._VersatileGuiReqServPort.registerProvider("GuiReqDBRegistKey", "VersatileGuiReqServ::GuiReqDBRegistKey", self._GuiReqDBRegistKeyProv)
        self._VersatileGuiReqServPort.registerProvider("GuiReqSynthesisPlanListDelKey", "VersatileGuiReqServ::GuiReqSynthesisPlanListDelKey", self._GuiReqSynthesisPlanListDelKeyProv)
        self._VersatileGuiReqServPort.registerProvider("GuiReqTileGenerationKey", "VersatileGuiReqServ::GuiReqTileGenerationKey", self._GuiReqTileGenerationKeyProv)
        self._VersatileGuiReqServPort.registerProvider("GuiReqDisplayUpdateKey", "VersatileGuiReqServ::GuiReqDisplayUpdateKey", self._GuiReqDisplayUpdateKeyProv)
        self._VersatileGuiReqServPort.registerProvider("GuiReqArrowKey", "VersatileGuiReqServ::GuiReqArrowKey", self._GuiReqArrowKeyProv)
        self._VersatileGuiReqServPort.registerProvider("GuiReqZoomKey", "VersatileGuiReqServ::GuiReqZoomKey", self._GuiReqZoomKeyProv)
        self._VersatileGuiReqServPort.registerProvider("GuiReqMapChangeKey", "VersatileGuiReqServ::GuiReqMapChangeKey", self._GuiReqMapChangeKeyProv)
        self._TwoDRobotMoniGuiReqServPort.registerProvider("GuiReqSensorInfoUpdateKey", "TwoDRobotMoniGuiReqServ::GuiReqSensorInfoUpdateKey", self._GuiReqMonitorUpdateKeyProv)
        
        # Set service consumers to Ports
        self._VersatileMgrStsServPort.registerConsumer("VersatileMgrSts", "VersatileMgrStsServ::VersatileMgrSts", self._VersatileMgrStsCons)
        self._VersatileMgrStsServPort.registerConsumer("VersatileMgrCompNotice", "VersatileMgrStsServ::VersatileMgrCompNotice", self._VersatileMgrCompNoticeCons)
        
        # Set CORBA Service Ports
        self.addPort(self._VersatileGuiReqServPort)
        self.addPort(self._TwoDRobotMoniGuiReqServPort)
        self.addPort(self._VersatileMgrStsServPort)
        

        # ===== 変数、パラメータ初期化 =====
        self.variable_Init()
        # ===== 全リスト取得 =====
        #self._proc_id = self.PROC_ID_ALL_LIST_READ

        return RTC.RTC_OK
    
        ##
        # 2Dロボット情報モニタシステムGUIの終了処理
        # 
        # The finalize action (on ALIVE->END transition)
        # formaer rtc_exiting_entry()
        # 
        # @return RTC::ReturnCode_t
    
        # @pre -
        # @post -
        # 
    def onFinalize(self):
        print "[debug]onFinalize"

        return RTC.RTC_OK
    
    #    ##
    #    #
    #    # The startup action when ExecutionContext startup
    #    # former rtc_starting_entry()
    #    # 
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onStartup(self, ec_id):
    #
    #    return RTC.RTC_OK
    
    #    ##
    #    #
    #    # The shutdown action when ExecutionContext stop
    #    # former rtc_stopping_entry()
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onShutdown(self, ec_id):
    #
    #    return RTC.RTC_OK
    
        ##
        # 2Dロボット情報モニタシステムGUIの開始処理
        #
        # The activated action (Active state entry action)
        # former rtc_active_entry()
        #
        # @param ec_id target ExecutionContext Id
        # 
        # @return RTC::ReturnCode_t
        #
        # @pre -
        # @post -
        #
    def onActivated(self, ec_id):
        print "[debug]onActivated"

        """データポート初期化 
           同期ズレでゴミデータが残るためこのタイミングで空にする"""
        while(self._inRobotGpsDataIn.isEmpty() == False):
            if(self._inRobotGpsDataIn.isNew()):
                _str_gpsdata = self._inRobotGpsDataIn.read()

        while(self._inRobotSensorDataIn.isEmpty() == False):
            if(self._inRobotSensorDataIn.isNew()):
                _str_sensordata = self._inRobotSensorDataIn.read()

        return RTC.RTC_OK
    
        ##
        # 2Dロボット情報モニタシステムGUIの停止処理
        #
        # The deactivated action (Active state exit action)
        # former rtc_active_exit()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        # @pre -
        # @post -
        #
    def onDeactivated(self, ec_id):
        print "[debug]onDeactivated"

        # ===== 変数初期化 =====
        self.variable_Init()

        # ===== 画面初期化 =====
        g_form.connect_and_emit_Deactivated()
        g_form.show()
    
        return RTC.RTC_OK
    
        ##
        # 2Dロボット情報モニタシステムGUIの周期処理
        #
        # The execution action that is invoked periodically
        # former rtc_active_do()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        # @pre -
        # @post -
        #
    def onExecute(self, ec_id):
        ret = self.RTN_VALUE_NONE

        if (self._proc_sts == self.PROC_STS_IDLE):
            ret = self.SendRequest()
            if (ret == self.RTN_VALUE_NONE):
                # 要求がない場合、GPSなどの周期更新を行う
                self._disp_update_req = self.DISPUPD_REQ_CYCLE

        elif (self._proc_sts == self.PROC_STS_RUN):
            ret = self.procExe()
            if (ret == self.RTN_VALUE_ERROR):
                return RTC.RTC_ERROR

        # データポート読み込み
        if (self._img_width > 0) and (self._img_height > 0):
            self.GetDPort_MapStartGps()
            self.GetDPort_MapEndGps()
            self.GetDPort_RobotGps()
            self.GetDPort_SensorInfo()

        # 画面更新
        g_form.connect_and_emit_trigger()
        g_form.show()
        cv2.waitKey(10)

        # ガードタイマー時間計測
        _st_time = self._proc_st_time
        _ed_time = datetime.datetime.now()

        if self._proc_st_time != 0 :
            _proc_time = _ed_time - _st_time
            if _proc_time.total_seconds() > self.PROC_TIMESET:
                # ガードタイマタイムアウト
                print "[error]No-response guard timer timed out!!"
                return RTC.RTC_ERROR

        return RTC.RTC_OK
    
        ##
        # 2Dロボット情報モニタシステムGUIのエラー遷移処理
        #
        # The aborting action when main logic error occurred.
        # former rtc_aborting_entry()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        # @pre -
        # @post -
        #
    def onAborting(self, ec_id):
        print "[debug]onAborting"

        return RTC.RTC_OK
    
    #    ##
    #    #
    #    # The error action in ERROR state
    #    # former rtc_error_do()
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onError(self, ec_id):
    #
    #    return RTC.RTC_OK
    
    #    ##
    #    #
    #    # The reset action that is invoked resetting
    #    # This is same but different the former rtc_init_entry()
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onReset(self, ec_id):
    #
    #    return RTC.RTC_OK
    
    #    ##
    #    #
    #    # The state update action that is invoked after onExecute() action
    #    # no corresponding operation exists in OpenRTm-aist-0.2.0
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #

    #    #
    #def onStateUpdate(self, ec_id):
    #
    #    return RTC.RTC_OK
    
    #    ##
    #    #
    #    # The action that is invoked when execution context's rate is changed
    #    # no corresponding operation exists in OpenRTm-aist-0.2.0
    #    #
    #    # @param ec_id target ExecutionContext Id
    #    #
    #    # @return RTC::ReturnCode_t
    #    #
    #    #
    #def onRateChanged(self, ec_id):
    #
    #    return RTC.RTC_OK
    

# =============================================================================
#    定数 定義
# =============================================================================
# 内部処理状態
    PROC_STS_IDLE = 0                               # 待機中
    PROC_STS_RUN = 1                                # 処理中
    PROC_STS_ERROR = 2                              # エラー状態
# 戻り値
    RTN_VALUE_SUCCESS = 0                           # 成功
    RTN_VALUE_ERROR = 1                             # 失敗
    RTN_VALUE_NONE = 2                              # 無し
# プロセスID
    PROC_ID_IDLE = 0                                # 待機中
    PROC_ID_ALL_LIST_READ = 1                       # 全リスト読み込み
    PROC_ID_DB_REGIST = 2                           # 撮影計画リストDB登録
    PROC_ID_TILE_SPLIT_DISP = 3                     # タイル生成確認画面
    PROC_ID_TILE_SPLIT_DISP_ERASE = 4               # タイル生成確認画面消去
    PROC_ID_TILE_GENERATE = 5                       # タイル生成
    PROC_ID_SYNTHE_LIST_DEL = 6                     # 合成計画リスト削除処理
    PROC_ID_IMAGE_UPDATE = 7                        # 画面更新要求
    PROC_ID_MAIN_SCROLL = 8                         # メイン地図画面スクロール
    PROC_ID_MAIN_ZOOMCHG = 9                        # メインズーム切替
    PROC_ID_MAIN_MAPCHG = 10                        # メイン地図切り替
    PROC_ID_SENSOR_ROBOT_SELECT = 11                # センサ情報表示ロボット選択
    PROC_ID_TOUCH_GUARD_OFF = 12                    # ガード除去
# 表示更新要求
    DISPUPD_REQ_NON = 0                             # 要求なし
    DISPUPD_REQ_ALL_LIST = 1                        # 全リスト更新要求
    DISPUPD_REQ_SHOOT_LIST = 2                      # 撮影計画リスト更新要求
    DISPUPD_REQ_SYNTH_LIST = 3                      # 合成計画リスト更新要求
    DISPUPD_REQ_MAIN_SCREEN = 4                     # メイン画面表示更新要求
    DISPUPD_REQ_CYCLE = 5                           # 周期更新要求
    DISPUPD_REQ_TOUCH_GUARD_OFF = 6                 # タッチガード解除要求

# ステータス表示エリアに表示する文言
    MSG_ALL_LIST_READ_SUCCESS    = "[info]All list loading succeeded!!"
    MSG_ALL_LIST_READ_ERROR      = "[error]All list loading failded!!"
    MSG_DATA_REGIST_IN_DB        = "[info]Data registration in DB!!"
    MSG_DB_REGIST_SUCCESS        = "[info]DB registration succeeded!!"
    MSG_DB_REGIST_ERROR          = "[error]DB registration failed!!"
    MSG_TILE_SPLIT_IN_PEAPAR     = "[info]Preparing the screen confirming tile division!!"
    MSG_TILE_SPLIT_DISP_SUCCESS  = "[info]Tile split confirmation screen display succeeded!!"
    MSG_TILE_SPLIT_DISP_ERROR    = "[error]Tile split confirmation screen display failded!!"
    MSG_SPLIT_DISP_ERASE_SUCCESS = "[info]Tile division confirmation screen delete succeeded!!"
    MSG_SPLIT_DISP_ERASE_ERROR   = "[error]Tile division confirmation screen delete failded!!"
    MSG_TILE_GENERATE_SUCCESS    = "[info]Tile generation succeeded!!"
    MSG_TILE_GENERATING          = "[info] Tile generating!!"
    MSG_TILE_GENERATE_ERROR      = "[error]Tile generation failded!!"
    MSG_SYNTHE_LIST_DELETING     = "[info]Synthesis plan list deleting!!"
    MSG_SYNTHE_LIST_DEL_SUCCESS  = "[info]Synthesis plan list delete succeeded!!"
    MSG_SYNTHE_LIST_DEL_ERROR    = "[error]Synthesis plan list delete failded!!"
    MSG_DISPLAY_PERPAR           = "[info]Display preparing !!"
    MSG_DISPLAY_SUCCESS          = "[info]Display succeeded!!"
    MSG_DISPLAY_ERROR            = "[error]Display failded!!"
    MSG_MAP_SCROLL_SUCCESS       = "[info]Map scroll succeeded!!"
    MSG_MAP_SCROLL_ERROR         = "[error]Map scroll failded!!"
    MSG_MAP_ZOOMCHG_SUCCESS      = "[info]Zoom level change succeeded!!"
    MSG_MAP_ZOOMCHG_ERROR        = "[error]Zoom level change failded!!"
    MSG_MAP_MAPCHG_SUCCESS       = "[info]Map change succeeded!!"
    MSG_MAP_MAPCHG_ERROR         = "[error]Map change failded!!"
    MSG_SLIDE_SUCCESS            = "[info]Slide change succeeded!!"
    MSG_SLIDE_ERROR              = "[error]Slide change failded!!"
    MSG_INIT_WARNING             = "[warning]This request can not be accepted because it is in the start process!!"
    MSG_RUN_WARNING              = "[warning]This request can not be accepted because it is in the process!!"
    MSG_ERROR                    = "[warning]This request can not be accepted because of an error accurred!!"

# ガードタイマ用
    PROC_TIMESET = 60                             # ガードタイマのマイムアウト時間

# フラグ制御マクロ
    BIT_FLAG_1 = 0x0001
    BIT_FLAG_2 = 0x0002
    BIT_FLAG_3 = 0x0004
    BIT_FLAG_4 = 0x0008

    MASK_FLAG_1 = 0xFFFE
    MASK_FLAG_2 = 0xFFFD
    MASK_FLAG_3 = 0xFFFB
    MASK_FLAG_4 = 0xFFF7

# 画像shape要素
    IMG_SHAPE_HEIGHT = 0                          # 高さ
    IMG_SHAPE_WIDTH = 1                           # 幅
    IMG_SHAPE_CHANNEL = 2                         # チャンネル数

# =============================================================================
#    変数 定義
# =============================================================================
# ===== プロセス実行関連 =====
    _proc_sts = PROC_STS_IDLE                     # 処理ステータス
    _proc_id = PROC_ID_IDLE                       # プロセスID
    _disp_update_req = DISPUPD_REQ_NON            # 表示更新要求
    _proc_st_time = 0                             # 応答なしガードタイマ計測用の開始時間
    _proc_ed_time = 0                             # 応答なしガードタイマ計測用の終了時間

# ===== サービスポートパラメータ =====
    #_GuiReqDBRegistKeyProv
    _param_sFolderPath = ""                                     # フォルダパス
    # _GuiReqTileGenerationKeyProv
    _param_ulGroupId = SystemMacro.GROUP_ID_NON                 # 撮影計画リストID
    _param_ulGenerateMode = SystemMacro.TILE_MODE_INIT          # タイル生成モード
    _param_ulRobotCategory = SystemMacro.ROBOT_CATEGORY_INIT    # ロボットカテゴリ
    _param_dStartLatitude = 0                                   # 起点緯度
    _param_dStartLongitude = 0                                  # 起点経度
    _param_dEndLatitude = 0                                     # 終点緯度
    _param_dEndLongitude = 0                                    # 終点経度
    _param_ulZoomlevel = SystemMacro.ZOOM_LEVEL_DEF             # ズームレベル
    _param_sSynthPlanName = ""                                  # 合成計画名称
    # _GuiReqDisplayUpdateKeyProv
    _param_ulMainViewGroupId = SystemMacro.GROUP_ID_NON         # メイン画面用の合成計画リストID

    _param_ulGpsDispControl = SystemMacro.GPS_DISP_OFF          # GPS表示On/Off制御
    _param_ulGpsRobotSelect = SystemMacro.ROBOT_SEL_BIT_OFF     # GPS表示対象ロボット選択

    #_GuiReqArrowKeyProv,GuiReq_ZoomKey,GuiReq_MapChangeKey
    _param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN            # 操作画面の選択
    _param_ulArrow = SystemMacro.ARROW_OFF                      # 十字キー
    _param_ulZoomAdj = SystemMacro.ZOOM_ADJ_OFF                 # ズームレベル調整
    _param_ulMapKind = SystemMacro.MAP_CHENGE_DEF               # 地図種別選択

    #_GuiReqMonitorUpdateKeyProv.usSetGuiReqSensorInfoUpdateKey
    _param_ulSensorRobotSel = SystemMacro.ROBOT_SEL_OFF         # センサ情報表示ロボット選択
    _senser_sel_robot_name = ""                                 # Key入力時に選択したロボット名称

# ===== データポート取得 =====
    _datap_DroneShootingPlanList = ""             # ドローン撮影計画リスト保持
    _datap_CrawlerShootingPlanList = ""           # クローラー撮影計画リスト保持
    _datap_SynthesisPlanList = ""                 # 合成計画リスト保持
    _datap_MapStartGps_Latitude = 0               # 写真地図起点緯度座標
    _datap_MapEndGps_Latitude = 0                 # 写真地図終点緯度座標
    _datap_MapStartGps_Longitude = 0              # 写真地図起点経度座標
    _datap_MapEndGps_Longitude = 0                # 写真地図終点経度座標

    _datap_gps_enryu_lat = 0                      # 援竜 GPS緯度
    _datap_gps_enryu_lon = 0                      # 援竜 GPS経度
    _datap_gps_spider_lat = 0                     # スパイダー GPS緯度
    _datap_gps_spider_lon = 0                     # スパイダー GPS緯度
    _datap_gps_drone_1_lat = 0                    # ドローン_1 GPS緯度
    _datap_gps_drone_1_lon = 0                    # ドローン_1 GPS経度
    _datap_gps_drone_2_lat = 0                    # ドローン_2 GPS緯度
    _datap_gps_drone_2_lon = 0                    # ドローン_2 GPS経度
    _datap_gps_drone_3_lat = 0                    # ドローン_3 GPS緯度
    _datap_gps_drone_3_lon = 0                    # ドローン_3 GPS経度
    _datap_gps_gorone_1_lat = 0                   # ゴローン_1 GPS緯度
    _datap_gps_gorone_1_lon = 0                   # ゴローン_1 GPS経度
    _datap_gps_gorone_2_lat = 0                   # ゴローン_2 GPS緯度
    _datap_gps_gorone_2_lon = 0                   # ゴローン_2 GPS経度
    _datap_gps_gorone_3_lat = 0                   # ゴローン_3 GPS緯度
    _datap_gps_gorone_3_lon = 0                   # ゴローン_3 GPS経度
    _datap_gps_gorone_4_lat = 0                   # ゴローン_4 GPS緯度
    _datap_gps_gorone_4_lon = 0                   # ゴローン_4 GPS経度

    _datap_gps_enryu_alt = 0                      # 援竜 GPS高度
    _datap_gps_spider_alt = 0                     # スパイダー GPS高度
    _datap_gps_drone_1_alt = 0                    # ドローン_1 GPS高度
    _datap_gps_drone_2_alt = 0                    # ドローン_2 GPS高度
    _datap_gps_drone_3_alt = 0                    # ドローン_3 GPS高度
    _datap_gps_gorone_1_alt = 0                   # ゴローン_1 GPS高度
    _datap_gps_gorone_2_alt = 0                   # ゴローン_2 GPS高度
    _datap_gps_gorone_3_alt = 0                   # ゴローン_3 GPS高度
    _datap_gps_gorone_4_alt = 0                   # ゴローン_4 GPS高度

    _datap_robot_name = ""                        # センサ情報：ロボット名
    _datap_gyro_roll = 0                          # センサ情報：ジャイロロール角
    _datap_gyro_pitch = 0                         # センサ情報：ジャイロピッチ角
    _datap_gyro_yaw = 0                           # センサ情報：ジャイロヨー角
    _datap_speed_x_axis = 0                       # センサ情報：X軸方向速度
    _datap_speed_y_axis = 0                       # センサ情報：Y軸方向速度
    _datap_speed_yaw = 0                          # センサ情報：回転速度
    _datap_speed_drone = 0                        # センサ情報：スピード
    _datap_temp = 0                               # センサ情報：温度
    _datap_compass = 0                            # センサ情報：方位
    _datap_windpress = 0                          # センサ情報：風圧

# ===== GPS/センサ表示更新要求 =====
    _req_enryu_gps_update = 0                     # 援竜GPS表示更新
    _req_spider_gps_update = 0                    # スパイダーGPS表示更新
    _req_gorone_gps_update = 0                    # ゴローンGPS表示更新
    _req_drone_gps_update = 0                     # ドローンGPS表示更新
    _req_sensor_info_update = False               # センサ情報表示更新

# ===== 画像データ =====
    _datap_MapImageData = ""                      # データポートから取得した地図画像データ
    _cv_MapImageData = ""                         # opencvの方に変換した地図画像データ(マークなし)
    _cv_MarkMapImageData = ""                     # opencvの方に変換した地図画像データ(マークあり)

# ===== 座標位置更新サイクル：タイマ時間 =====
    _mark_timeset = 0
    _mark_st_time = datetime.datetime.now()
    _mark_ed_time = 0

# ===== 画像 =====
    _img_height = 0
    _img_width = 0
    _img_dim = 0
    _imag_bytesPerLine = 0 

# ===== メッセージ =====
    _msg_text = ""

# ===== 写真地図上のGPS表示更新許可/禁止判断用 =====
    _gps_update_angle = SystemMacro.DIRECTION_STEP_MID    # アングルが0度の時のみ写真地図上のGPS表示許可にする
    _gps_update_scale = SystemMacro.SCALE_STEP_MIDDLE     # スケールがMIDの時のみ写真地図上のGPS表示許可にする

# =============================================================================
#  処  理：メンバ変数初期化処理
#  戻り値：なし
# =============================================================================
    def variable_Init(self):
        # ===== プロセス実行関連 =====
        self._proc_sts = self.PROC_STS_IDLE
        self._proc_id = self.PROC_ID_ALL_LIST_READ
        self._disp_update_req = self.DISPUPD_REQ_NON
        self._proc_st_time = 0
        self._proc_ed_time = 0

        # ===== サービスポートパラメータ =====
        self._param_sFolderPath = ""
        self._param_ulGroupId = SystemMacro.GROUP_ID_NON
        self._param_ulGenerateMode = SystemMacro.TILE_MODE_INIT
        self._param_ulRobotCategory = SystemMacro.ROBOT_CATEGORY_INIT
        self._param_dStartLatitude = 0 
        self._param_dStartLongitude = 0
        self._param_dEndLatitude = 0
        self._param_dEndLongitude = 0
        self._param_ulZoomlevel = SystemMacro.ZOOM_LEVEL_DEF
        self._param_sSynthPlanName = ""
        self._param_ulMainViewGroupId = SystemMacro.GROUP_ID_NON
        self._param_ulGpsDispControl = SystemMacro.GPS_DISP_OFF
        self._param_ulGpsRobotSelect = SystemMacro.ROBOT_SEL_BIT_OFF
        self._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._param_ulArrow = SystemMacro.ARROW_OFF
        self._param_ulZoomAdj = SystemMacro.ZOOM_ADJ_OFF
        self._param_ulMapKind = SystemMacro.MAP_CHENGE_DEF
        self._param_ulSensorRobotSel = SystemMacro.ROBOT_SEL_OFF
        self._senser_sel_robot_name = ""

        # ===== データポート取得 =====
        self._datap_DroneShootingPlanList = ""
        self._datap_CrawlerShootingPlanList = ""
        self._datap_SynthesisPlanList = ""
        self._datap_MapStartGps_Latitude = ""
        self._datap_MapEndGps_Latitude = ""
        self._datap_MapStartGps_Longitude = ""
        self._datap_MapEndGps_Longitude = ""
        self._datap_gps_enryu_lat = 0
        self._datap_gps_enryu_lon = 0
        self._datap_gps_spider_lat = 0
        self._datap_gps_spider_lon = 0
        self._datap_gps_drone_1_lat = 0
        self._datap_gps_drone_1_lon = 0
        self._datap_gps_drone_2_lat = 0
        self._datap_gps_drone_2_lon = 0
        self._datap_gps_drone_3_lat = 0
        self._datap_gps_drone_3_lon = 0
        self._datap_gps_gorone_1_lat = 0
        self._datap_gps_gorone_1_lon = 0
        self._datap_gps_gorone_2_lat = 0
        self._datap_gps_gorone_2_lon = 0
        self._datap_gps_gorone_3_lat = 0
        self._datap_gps_gorone_3_lon = 0
        self._datap_gps_gorone_4_lat = 0
        self._datap_gps_gorone_4_lon = 0

        self._datap_gps_enryu_alt = 0
        self._datap_gps_spider_alt = 0
        self._datap_gps_drone_1_alt = 0
        self._datap_gps_drone_2_alt = 0
        self._datap_gps_drone_3_alt = 0
        self._datap_gps_gorone_1_alt = 0
        self._datap_gps_gorone_2_alt = 0
        self._datap_gps_gorone_3_alt = 0
        self._datap_gps_gorone_4_alt = 0
        self._datap_robot_name = ""
        self._datap_gyro_roll = 0
        self._datap_gyro_pitch = 0
        self._datap_gyro_yaw = 0
        self._datap_speed_x_axis = 0
        self._datap_speed_y_axis = 0
        self._datap_speed_yaw = 0
        self._datap_speed_drone = 0
        self._datap_temp = 0
        self._datap_compass = 0
        self._datap_windpress = 0

        self._req_enryu_gps_update = 0
        self._req_spider_gps_update = 0
        self._req_gorone_gps_update = 0
        self._req_drone_gps_update = 0
        self._req_sensor_info_update = False

        # ===== 画像データ =====
        self._datap_MapImageData = ""
        self._cv_MapImageData = ""
        self._cv_MarkMapImageData = ""

        # ===== 座標位置更新サイクル：タイマ時間 =====
        self._mark_timeset = 0
        self._mark_st_time = datetime.datetime.now()
        self._mark_ed_time = 0
    
        # ===== 画像 =====
        self._img_height = 0
        self._img_width = 0
        self._img_dim = 0
        self._imag_bytesPerLine = 0 
    
        # ===== メッセージ =====
        self._msg_text = ""
    
        # ===== VIEW画面更新 =====
        self._gps_update_angle = SystemMacro.DIRECTION_STEP_MID
        self._gps_update_scale = SystemMacro.SCALE_STEP_MIDDLE

        # ===== IDLパラメータ初期化 =====
        self._GuiReqDBRegistKeyProv.clrGuiReqDBRegistKey()
        self._GuiReqSynthesisPlanListDelKeyProv.clrGuiReqSynthesisPlanListDelKey()
        self._GuiReqTileGenerationKeyProv.clrGuiReqTileGenerationKey()
        self._GuiReqDisplayUpdateKeyProv.clrGuiReqDisplayUpdateKey()
        self._GuiReqArrowKeyProv.clrGuiReqArrowKey()
        self._GuiReqZoomKeyProv.clrGuiReqZoomKey()
        self._GuiReqMapChangeKeyProv.clrGuiReqMapChangeKey()
        self._GuiReqMonitorUpdateKeyProv.clrGuiReqSensorInfoUpdateKey()

# =============================================================================
#  処  理：Key押下要求を通知
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了
#          RTN_VALUE_NONE：要求なし
# =============================================================================
    def SendRequest(self):
        ret = self.RTN_VALUE_NONE

        # ===== 全リスト読み込み =====
        if self._proc_id == self.PROC_ID_ALL_LIST_READ:
            ret = self.GuiReq_ListAll()
        # ===== 撮影計画リストDB登録　要求 =====
        elif self._proc_id == self.PROC_ID_DB_REGIST:
            ret = self.GuiReq_DBRegistKey()
        # ===== タイル分割確認画面表示　要求 =====
        elif self._proc_id == self.PROC_ID_TILE_SPLIT_DISP:
            ret = self.GuiReq_TileGenerationKey()
        # ===== タイル分割確認画面表示消去　要求 =====
        elif self._proc_id == self.PROC_ID_TILE_SPLIT_DISP_ERASE:
            ret = self.GuiReq_TileGenerationKey()
        # ===== タイル生成　要求 =====
        elif self._proc_id == self.PROC_ID_TILE_GENERATE:
            ret = self.GuiReq_TileGenerationKey()
        # ===== 合成画リスト削除　要求 =====
        elif self._proc_id == self.PROC_ID_SYNTHE_LIST_DEL:
            ret = self.GuiReq_SynthesisPlanListDelKey()
        # ===== メイン地図画像更新　要求 =====
        elif self._proc_id == self.PROC_ID_IMAGE_UPDATE:
            ret = self.GuiReq_DisplayUpdateKey()
        # ===== メイン地図画像スクロール（十字キー）要求 =====
        elif self._proc_id == self.PROC_ID_MAIN_SCROLL:
            ret = self.GuiReq_ArrowKey()
        # ===== メイン地図画像ズーム設定　要求 =====
        elif self._proc_id == self.PROC_ID_MAIN_ZOOMCHG:
            ret = self.GuiReq_ZoomKey()
        # ===== メイン地図画像地図切り替　要求 =====
        elif self._proc_id == self.PROC_ID_MAIN_MAPCHG:
           ret = self.GuiReq_MapChangeKey()
        # ===== センサ表示ロボット選択　要求 =====
        elif self._proc_id == self.PROC_ID_SENSOR_ROBOT_SELECT:
           ret = self.GuiReq_SensorRobotSelKey()

        # =====  処理結果 =====
        if ret == self.RTN_VALUE_SUCCESS:
            # センサ表示ロボット選択要求は完了通知がないため除外
            if self._proc_id != self.PROC_ID_SENSOR_ROBOT_SELECT:
                # ===== 処理ステータスセット ====
                self._proc_sts = self.PROC_STS_RUN
                # ===== 処理開始時間セット =====
                self._proc_st_time = datetime.datetime.now()
            else:
                self._proc_id = self.PROC_ID_IDLE

            # ===== 座標マーク表示サイクル：処理開始時間セット =====
            self._mark_st_time = datetime.datetime.now()

        return ret


# ============================================================================
#  処　理：処理実行
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# ============================================================================
    def procExe(self):
        ret = self.RTN_VALUE_NONE

        # ===== 全リスト読み込み　処理 =====
        if self._proc_id == self.PROC_ID_ALL_LIST_READ:
            ret = self.procListAll()
        # ===== 撮影計画リストDB登録　処理 =====
        elif self._proc_id == self.PROC_ID_DB_REGIST:
            ret = self.procDbRegist()
        # ===== タイル分割確認画面表示　処理 =====
        elif self._proc_id == self.PROC_ID_TILE_SPLIT_DISP:
            ret = self.procTileSplitDisp()
        # ===== タイル分割確認画面表示消去　処理 =====
        elif self._proc_id == self.PROC_ID_TILE_SPLIT_DISP_ERASE:
            ret = self.procTileSplitDispErase()
        # ===== タイル生成　処理 =====
        elif self._proc_id == self.PROC_ID_TILE_GENERATE:
            ret = self.procTileGenarate()
        # ===== 合成画リスト削除　処理 =====
        elif self._proc_id == self.PROC_ID_SYNTHE_LIST_DEL:
            ret = self.procSyntheListDel()
        # ===== メイン地図画像更新　処理 =====
        elif self._proc_id == self.PROC_ID_IMAGE_UPDATE:
            ret = self.procImageUpdate()
        # ===== メイン地図画像スクロール（十字キー）処理 =====
        elif self._proc_id == self.PROC_ID_MAIN_SCROLL:
            ret = self.procMainImageDisp()
        # ===== メイン地図画像ズーム設定　処理 =====
        elif self._proc_id == self.PROC_ID_MAIN_ZOOMCHG:
            ret = self.procMainImageDisp()
        # ===== メイン地図画像地図切り替　処理 =====
        elif self._proc_id == self.PROC_ID_MAIN_MAPCHG:
            ret = self.procMainImageDisp()

        # =====  処理結果 =====  
        if ret == self.RTN_VALUE_SUCCESS:
            # ===== 処理ステータス・処理ＩＤクリア =====
            self._proc_id = self.PROC_ID_IDLE
            self._proc_sts = self.PROC_STS_IDLE
            # ===== 処理開始時間リセット =====
            self._proc_st_time = 0

        return ret

# *****************************************************************************
#    マネージャへのKey押下要求発行関連の処理
# *****************************************************************************
# ============================================================================
#  処　理：全リスト作成
#  引　数：なし
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_ListAll(self):
        #self._gui_proc_id = self.PROC_ID_ALL_LIST_READ

        return self.RTN_VALUE_SUCCESS 

# ============================================================================
#  処　理：DB登録キー 要求
#  引　数：登録フォルダ
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_DBRegistKey(self):
        self._GuiReqDBRegistKeyProv.usSetGuiReqDBRegistKey(str(self._param_sFolderPath))
        print ("[debug]usSetGuiReqDBRegistKey():FolderPath = {}".format(self._param_sFolderPath))

        return self.RTN_VALUE_SUCCESS

# ============================================================================
#  処　理：タイル生成キー 要求
#  引　数：生成モード、ロボットカテゴリー、グループID、始点緯度、始点経度、
#        ：終点緯度、終点経度、ズームレベル、合成計画名
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_TileGenerationKey(self):
        self._GuiReqTileGenerationKeyProv.usSetGuiReqTileGenerationKey(long(self._param_ulGenerateMode),
                                                                       long(self._param_ulRobotCategory), 
                                                                       long(self._param_ulGroupId),
                                                                       float(self._param_dStartLatitude),
                                                                       float(self._param_dStartLongitude),
                                                                       float(self._param_dEndLatitude),
                                                                       float(self._param_dEndLongitude),
                                                                       long(self._param_ulZoomlevel),
                                                                       str(self._param_sSynthPlanName))

        print("""[debug]usSetGuiReqTileGenerationKey():GenerateMode = {0}, RobotCategory = {1},GroupId = {2},
                                      StartLat = {3}, StartLon = {4}, EndLat = {5}, EndLon = {6},
                                      Zoomlevel = {7}, SynthPlanName = {8}"""
            .format(self._param_ulGenerateMode,self._param_ulRobotCategory, self._param_ulGroupId,
            self._param_dStartLatitude, self._param_dStartLongitude, self._param_dEndLatitude,
            self._param_dEndLongitude, self._param_ulZoomlevel, self._param_sSynthPlanName))

        return self.RTN_VALUE_SUCCESS

# ============================================================================
#  処　理：表示画面更新キー 要求
#  引　数：写真地図選択リストID、GPS表示On/Off、GPS表示対象ロボット
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_DisplayUpdateKey(self):
        self._GuiReqDisplayUpdateKeyProv.usSetGuiReqDisplayUpdateKey(long(self._param_ulMainViewGroupId),
                                                                     long(self._param_ulGpsDispControl),
                                                                     long(self._param_ulGpsRobotSelect))

        print("""[debug]usSetGuiReqDisplayUpdateKey():MainViewGroupId = {0}, GpsDispControl = {1}, GpsRobotSelect = {2}"""
            .format(self._param_ulMainViewGroupId, self._param_ulGpsDispControl, self._param_ulGpsRobotSelect))

        return self.RTN_VALUE_SUCCESS 

# ============================================================================
#  処　理：合成計画リスト削除キー 要求
#  引　数：グループID
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_SynthesisPlanListDelKey(self):
        self._GuiReqSynthesisPlanListDelKeyProv.usSetGuiReqSynthesisPlanListDelKey(long(self._param_ulGroupId))

        print("[debug]usSetGuiReqSynthesisPlanListDelKey():GroupId = {}".format(self._param_ulGroupId))

        return self.RTN_VALUE_SUCCESS 

# ============================================================================
#  処　理：十字キー 要求
#  引　数：グループID
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_ArrowKey(self):
        self._GuiReqArrowKeyProv.usSetGuiReqArrowKey(long(self._param_ulOpeScreen ), long(self._param_ulArrow))

        print("""[debug]usSetGuiReqArrowKey():OpeScreen = {0}, Arrow = {1}"""
            .format(self._param_ulOpeScreen, self._param_ulArrow))

        return self.RTN_VALUE_SUCCESS 

# ============================================================================
#  処　理：ズーム変更キー 要求
#  引　数：画面種別、ズーム
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_ZoomKey(self):
        self._GuiReqZoomKeyProv.usSetGuiReqZoomKey(long(self._param_ulOpeScreen ), long(self._param_ulZoomAdj))

        print("""[debug]usSetGuiReqZoomKey():OpeScreen = {0}, ZoomAdj = {1}"""
            .format(self._param_ulOpeScreen, self._param_ulZoomAdj))

        return self.RTN_VALUE_SUCCESS 

# ============================================================================
#  処　理：地図切り替えキー 要求
#  引　数：画面種別、地図切り替え
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_MapChangeKey(self):
        self._GuiReqMapChangeKeyProv.usSetGuiReqMapChangeKey(long(self._param_ulOpeScreen), long(self._param_ulMapKind))

        print("""[debug]usSetGuiReqMapChangeKey():OpeScreen = {0}, MapKind = {1}"""
            .format(self._param_ulOpeScreen, self._param_ulMapKind))

        return self.RTN_VALUE_SUCCESS 

# ============================================================================
#  処　理：センサ情報表示ロボット選択キー 要求
#  引　数：対象ロボット
#  戻り値：RTN_VALUE_SUCCESS：正常終了
# ============================================================================
    def GuiReq_SensorRobotSelKey(self):
        self._GuiReqMonitorUpdateKeyProv.usSetGuiReqSensorInfoUpdateKey(self._param_ulSensorRobotSel)

        print("""[debug]usSetGuiReqSensorInfoUpdateKey():OpeScreen = {0}, RobotSel = {1}"""
            .format(self._param_ulOpeScreen, self._param_ulSensorRobotSel))

        return self.RTN_VALUE_SUCCESS 


# *****************************************************************************
#    マネージャからの完了通知受信後の処理
# *****************************************************************************
# ============================================================================
#  処　理：全リスト読み込み
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# ============================================================================
    def procListAll(self):
        ret = self.RTN_VALUE_NONE 

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}. Param = {1}".format(_ulNotice, _ulParam))

        if _ulNotice == SystemMacro.MGR_NOTICE_ALL_LIST_READ_SUCCESS:
            # データポートからドローン撮影計画リスト取得
            ret = self.GetDPort_DroneShootList()
            if (ret == self.RTN_VALUE_ERROR):
                return self.RTN_VALUE_ERROR

            # データポートから合成計画リスト取得
            ret = self.GetDPort_SynthPlanList()
            if (ret == self.RTN_VALUE_ERROR):
                return self.RTN_VALUE_ERROR

            # 撮影計画/合成計画リスト取得正常の場合
            self._disp_update_req = self.DISPUPD_REQ_ALL_LIST
            self._msg_text = self.MSG_ALL_LIST_READ_SUCCESS
            ret = self.RTN_VALUE_SUCCESS

        elif _ulNotice == SystemMacro.MGR_NOTICE_ALL_LIST_READ_ERROR:
            self._msg_text = self.MSG_ALL_LIST_READ_ERROR
            ret = self.RTN_VALUE_SUCCESS

        else:
            ret = self.RTN_VALUE_NONE 

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret

# =============================================================================
#  処　理：完了通知　DB登録
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# =============================================================================
    def procDbRegist(self):
        ret = self.RTN_VALUE_NONE 

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}. Param = {1}".format(_ulNotice, _ulParam))

        if _ulNotice == SystemMacro.MGR_NOTICE_DB_REGIST_SUCCESS:
            # データポートからドローン撮影計画リスト取得
            ret = self.GetDPort_DroneShootList()
            if (ret == self.RTN_VALUE_ERROR):
                return self.RTN_VALUE_ERROR

            elif (ret == self.RTN_VALUE_NONE):
                return self.RTN_VALUE_NONE

            else:
                self._disp_update_req = self.DISPUPD_REQ_SHOOT_LIST
                self._msg_text = self.MSG_DB_REGIST_SUCCESS

                ret = self.RTN_VALUE_SUCCESS

        elif _ulNotice == SystemMacro.MGR_NOTICE_DB_REGIST_ERROR:
            self._msg_text = self.MSG_DB_REGIST_ERROR
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF

            ret = self.RTN_VALUE_SUCCESS

        else:
            ret = self.RTN_VALUE_NONE

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret 

# =============================================================================
#  処　理：完了通知　タイル分割確認表示
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# =============================================================================
    def procTileSplitDisp(self):
        ret = self.RTN_VALUE_NONE

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}. Param = {1}".format(_ulNotice, _ulParam))

        # ===== 完了通知確認 =====
        if _ulNotice == SystemMacro.MGR_NOTICE_TILE_SPLIT_DISP_SUCCESS:
            self._msg_text = self.MSG_TILE_SPLIT_DISP_SUCCESS

            ret = self.RTN_VALUE_SUCCESS

        elif _ulNotice == SystemMacro.MGR_NOTICE_TILE_SPLIT_DISP_ERROR:
            self._msg_text = self.MSG_TILE_SPLIT_DISP_ERROR

            ret = self.RTN_VALUE_SUCCESS

        else:
            ret = self.RTN_VALUE_NONE

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret 

# =============================================================================
#  処　理：完了通知　タイル分割確認画面消去
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# =============================================================================
    def procTileSplitDispErase(self):
        ret = self.RTN_VALUE_NONE

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}. Param = {1}".format(_ulNotice, _ulParam))

        # ===== 完了通知確認 =====
        if _ulNotice == SystemMacro.MGR_NOTICE_SPLIT_DISP_ERASE_SUCCESS:
            self._msg_text = self.MSG_SPLIT_DISP_ERASE_SUCCESS

            ret = self.RTN_VALUE_SUCCESS

        elif _ulNotice == SystemMacro.MGR_NOTICE_SPLIT_DISP_ERASE_ERROR:
            self._msg_text = self.MSG_SPLIT_DISP_ERASE_ERROR

            ret = self.RTN_VALUE_SUCCESS

        else:
            ret = self.RTN_VALUE_NONE

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret 

# =============================================================================
#  処　理：完了通知　タイル生成
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# =============================================================================
    def procTileGenarate(self):
        ret = self.RTN_VALUE_NONE

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}. Param = {1}".format(_ulNotice, _ulParam))

        # ===== 完了通知確認 =====
        if _ulNotice == SystemMacro.MGR_NOTICE_TILE_GENERATE_SUCCESS:
            ret = self.GetDPort_SynthPlanList()
            if (ret == self.RTN_VALUE_ERROR):
                return self.RTN_VALUE_ERROR

            elif (ret == self.RTN_VALUE_NONE):
                return self.RTN_VALUE_NONE

            else:
                self._disp_update_req = self.DISPUPD_REQ_SYNTH_LIST
                self._msg_text = self.MSG_TILE_GENERATE_SUCCESS

                ret = self.RTN_VALUE_SUCCESS

        elif _ulNotice == SystemMacro.MGR_NOTICE_TILE_GENERATE_ERROR:
            self._msg_text = self.MSG_TILE_GENERATE_ERROR
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF
            
            ret = self.RTN_VALUE_SUCCESS

        else:
            ret = self.RTN_VALUE_NONE

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret 

# =============================================================================
#  処　理：完了通知　合成計画リスト削除
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# =============================================================================
    def procSyntheListDel(self):
        ret = self.RTN_VALUE_NONE
        _dataRcv = False

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}. Param = {1}".format(_ulNotice, _ulParam))

        # ===== 完了通知確認 =====
        if _ulNotice == SystemMacro.MGR_NOTICE_SYNTHE_LIST_DEL_SUCCESS:
            # ===== 完了通知＝OK　且つ　件数が0件の時
            if _ulParam == 0:
                self._disp_update_req = self.DISPUPD_REQ_SYNTH_LIST
                self._msg_text = self.MSG_SYNTHE_LIST_DEL_SUCCESS
                # ===== 件数が0件：リストに空データを設定 =====
                self._datap_SynthesisPlanList = ""

                ret = self.RTN_VALUE_SUCCESS

            else:
                ret = self.GetDPort_SynthPlanList()
                if (ret == self.RTN_VALUE_ERROR):
                    return self.RTN_VALUE_ERROR

                elif (ret == self.RTN_VALUE_NONE):
                    return self.RTN_VALUE_NONE
                else:
                    self._disp_update_req = self.DISPUPD_REQ_SYNTH_LIST
                    self._msg_text = self.MSG_SYNTHE_LIST_DEL_SUCCESS

                    ret = self.RTN_VALUE_SUCCESS


        elif _ulNotice == SystemMacro.MGR_NOTICE_SYNTHE_LIST_DEL_ERROR:
            # ===== 完了通知メッセージセット =====
            self._msg_text = self.MSG_SYNTHE_LIST_DEL_ERROR
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF

            ret = self.RTN_VALUE_SUCCESS

        else:
            ret = self.RTN_VALUE_NONE 

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret 

# =============================================================================
#  処　理：完了通知　地図画像更新
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# ============================================================================
    def procImageUpdate(self):
        ret = self.RTN_VALUE_NONE

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}, Param = {1}".format(_ulNotice, _ulParam))

        if (_ulNotice == SystemMacro.MGR_NOTICE_IMAGE_DISP_SUCCESS):
            # ===== データポート取得：地図画像データ =====
            ret = self.GetDPort_MainImage()
            if (ret == self.RTN_VALUE_SUCCESS):
                # ===== 表示、メッセージ更新要求設定 =====
                self._disp_update_req = self.DISPUPD_REQ_MAIN_SCREEN
                self._msg_text = self.MSG_DISPLAY_SUCCESS
                ret = self.RTN_VALUE_SUCCESS

            elif (ret == self.RTN_VALUE_ERROR):
                # データ破損
                return self.RTN_VALUE_ERROR

            else:
                # データポート変化なし（遅延することがあるため待機する）
                ret = self.RTN_VALUE_NONE

        elif _ulNotice == SystemMacro.MGR_NOTICE_IMAGE_DISP_ERROR:
            # ===== 表示、メッセージ更新要求設定 =====
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF
            self._msg_text = self.MSG_DISPLAY_ERROR
            ret = self.RTN_VALUE_SUCCESS

        else:
            ret = self.RTN_VALUE_NONE

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret 

# =============================================================================
#  処　理：完了通知　地図画像更新
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# ============================================================================
    def procMainImageDisp(self):
        ret = self.RTN_VALUE_NONE
        get_image = False

        # ===== サービスポート：完了通知取得  =====
        _ulNotice, _ulParam =  self._VersatileMgrCompNoticeCons._ptr().GetVersatileMgrCompNotice()
        print("[debug]VersatileMgrCompNotice():Notice = {0}. Param = {1}".format(_ulNotice, _ulParam))

        if ((_ulNotice == SystemMacro.MGR_NOTICE_MAIN_SCROLL_SUCCESS) or 
            (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_ZOOMCHG_SUCCESS) or 
            (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_MAPCHG_SUCCESS)):

            # ===== データポート取得：地図画像データ =====
            ret = self.GetDPort_MainImage()
            if (ret == self.RTN_VALUE_SUCCESS):
                # ===== 表示、メッセージ更新要求設定 =====
                self._disp_update_req = self.DISPUPD_REQ_MAIN_SCREEN
                if (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_SCROLL_SUCCESS):
                    self._msg_text = self.MSG_MAP_SCROLL_SUCCESS
                elif (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_ZOOMCHG_SUCCESS):
                    self._msg_text = self.MSG_MAP_ZOOMCHG_SUCCESS
                elif (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_MAPCHG_SUCCESS):
                    self._msg_text = self.MSG_MAP_MAPCHG_SUCCESS

                ret = self.RTN_VALUE_SUCCESS

            elif (ret == self.RTN_VALUE_ERROR):
                # データ破損
                return self.RTN_VALUE_ERROR

            else:
                # データポート変化なし（遅延することがあるため待機する）
                ret = self.RTN_VALUE_NONE

        elif (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_SCROLL_ERROR):
            self._msg_text = self.MSG_MAP_SCROLL_ERROR
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF

            # ===== 戻り値セット エラーでも正常を返す =====
            ret = self.RTN_VALUE_SUCCESS

        elif (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_ZOOMCHG_ERROR):
            self._msg_text = self.MSG_MAP_ZOOMCHG_ERROR
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF

            # ===== 戻り値セット エラーでも正常を返す =====
            ret = self.RTN_VALUE_SUCCESS

        elif (_ulNotice == SystemMacro.MGR_NOTICE_MAIN_MAPCHG_ERROR):
            self._msg_text = self.MSG_MAP_MAPCHG_ERROR
            self._disp_update_req = self.DISPUPD_REQ_TOUCH_GUARD_OFF

            # ===== 戻り値セット エラーでも正常を返す =====
            ret = self.RTN_VALUE_SUCCESS
        else:
            ret = self.RTN_VALUE_NONE

        # ===== マネージャー完了通知：初期化 =====
        if ret != self.RTN_VALUE_NONE:
            self._VersatileMgrCompNoticeCons._ptr().usSetVersatileMgrCompNotice(SystemMacro.NOTICE_INIT, SystemMacro.NOTICE_PARAM_INIT)

        return ret 


# *****************************************************************************
#    データポート取得関連処理
# *****************************************************************************
# =============================================================================
#  処　理：データポートから写真地図起点座標取得
#  戻り値：なし
# =============================================================================
    def GetDPort_MapStartGps(self):
        if self._inMapImageStartGpsDataIn.isNew():
            dResult =self._inMapImageStartGpsDataIn.read()
            if((dResult.latitude == 0) or (dResult.longitude == 0)):
                print("""[warning]Inport data port map start gps is invalid!!:lat = {0},lon = {1}"""
                    .format(dResult.latitude, dResult.longitude))
            else:
                print("""[debug]Inport data port map start gps:lat = {0},lon = {1}"""
                    .format(dResult.latitude, dResult.longitude))
                self._datap_MapStartGps_Latitude = dResult.latitude
                self._datap_MapStartGps_Longitude = dResult.longitude

# =============================================================================
#  処　理：データポートから写真地図終点座標取得
#  戻り値：なし
# =============================================================================
    def GetDPort_MapEndGps(self):
        if self._inMapImageEndGpsDataIn.isNew():
            dResult =self._inMapImageEndGpsDataIn.read()
            if((dResult.latitude == 0) or (dResult.longitude == 0)):
                print("""[warning]Inport data port map end gps is invalid!!:lat = {0},lon = {1}"""
                    .format(dResult.latitude, dResult.longitude))
            else:
                print("""[debug]Inport data port map end gps:lat = {0},lon = {1}"""
                    .format(dResult.latitude, dResult.longitude))
                self._datap_MapEndGps_Latitude = dResult.latitude
                self._datap_MapEndGps_Longitude = dResult.longitude

# =============================================================================
#  処　理：データポートからロボットGPSデータ取得
#  戻り値：なし
# =============================================================================
    def GetDPort_RobotGps(self):
        if self._inRobotGpsDataIn.isNew():
            _str_gpsdata = self._inRobotGpsDataIn.read()
            if len(_str_gpsdata.data) == 0:
                print("""[warning]Input data port robot gps json data is empty!!:str_gpsdata = {}"""
                    .format(_str_gpsdata.data))
            else:
#                print("""[debug]Input data port robot gps json data!!:str_gpsdata = {}"""
#                    .format(_str_gpsdata.data))

                _json_data = json.loads(_str_gpsdata.data)
                self.GetEnryuGpsData(_json_data)
                self.GetSpiderGpsData(_json_data)
                self.GetGoroneGpsData(_json_data)
                self.GetDroneGpsData(_json_data)

# =============================================================================
#  処　理：データポートから援竜GPSデータ取得
#  戻り値：なし
# =============================================================================
    def GetEnryuGpsData(self, _json_data):

        # 援竜GPSデータ取得
        _gps_enryu_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_ENRYU][SystemMacro.JSONKEY_LAT]))
        _gps_enryu_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_ENRYU][SystemMacro.JSONKEY_LON]))
        self._datap_gps_enryu_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_ENRYU][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if ((_gps_enryu_lat != 0) and (_gps_enryu_lon != 0)):
#            if ((self._datap_gps_enryu_lat != _gps_enryu_lat ) or (self._datap_gps_enryu_lon != _gps_enryu_lon)):
#                print("""[debug]Input enryu GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_enryu_lat, _gps_enryu_lon, self._datap_gps_enryu_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_enryu_lat = _gps_enryu_lat
            self._datap_gps_enryu_lon = _gps_enryu_lon
            self._req_enryu_gps_update = True
        elif ((_gps_enryu_lat == 0) and (_gps_enryu_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input enryu GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_enryu_lat, _gps_enryu_lon, self._datap_gps_enryu_alt))

# =============================================================================
#  処　理：データポートからスパイダーGPSデータ取得
#  戻り値：なし
# =============================================================================
    def GetSpiderGpsData(self, _json_data):

        # スパイダーGPSデータ取得
        _gps_spider_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_SPIDER][SystemMacro.JSONKEY_LAT]))
        _gps_spider_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_SPIDER][SystemMacro.JSONKEY_LON]))
        self._datap_gps_spider_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_SPIDER][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if ((_gps_spider_lat != 0) and (_gps_spider_lon != 0)):
#            if ((self._datap_gps_spider_lat != _gps_spider_lat ) or (self._datap_gps_spider_lon != _gps_spider_lon)):
#                print("""[debug]Input spider GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_spider_lat, _gps_spider_lon, self._datap_gps_spider_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_spider_lat = _gps_spider_lat
            self._datap_gps_spider_lon = _gps_spider_lon
            self._req_spider_gps_update = True
        elif ((_gps_spider_lat == 0) and (_gps_spider_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input spider GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_spider_lat, _gps_spider_lon, self._datap_gps_spider_alt))

# =============================================================================
#  処　理：データポートからゴローンGPSデータ取得
#  戻り値：なし
# =============================================================================
    def GetGoroneGpsData(self, _json_data):

        # ゴローン1GPSデータ取得
        _gps_gorone_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_1][SystemMacro.JSONKEY_LAT]))
        _gps_gorone_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_1][SystemMacro.JSONKEY_LON]))
        self._datap_gps_gorone_1_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_1][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if((_gps_gorone_lat != 0) and (_gps_gorone_lon != 0)):
#            if((self._datap_gps_gorone_1_lat != _gps_gorone_lat) or (self._datap_gps_gorone_1_lon != _gps_gorone_lon)):
#                print("""[debug]Input gorone_1 GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_1_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_gorone_1_lat = _gps_gorone_lat
            self._datap_gps_gorone_1_lon = _gps_gorone_lon
            self._req_gorone_gps_update = (self._req_gorone_gps_update | self.BIT_FLAG_1)
        elif ((_gps_gorone_lat == 0) and (_gps_gorone_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input gorone_1 GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_1_alt))

        # ゴローン2GPSデータ取得
        _gps_gorone_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_2][SystemMacro.JSONKEY_LAT]))
        _gps_gorone_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_2][SystemMacro.JSONKEY_LON]))
        self._datap_gps_gorone_2_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_2][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if((_gps_gorone_lat != 0) and (_gps_gorone_lon != 0)):
#            if((self._datap_gps_gorone_2_lat != _gps_gorone_lat) or (self._datap_gps_gorone_2_lon != _gps_gorone_lon)):
#                print("""[debug]Input gorone_2 GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_2_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_gorone_2_lat = _gps_gorone_lat
            self._datap_gps_gorone_2_lon = _gps_gorone_lon
            self._req_gorone_gps_update = (self._req_gorone_gps_update | self.BIT_FLAG_2)
        elif ((_gps_gorone_lat == 0) and (_gps_gorone_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input gorone_2 GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_2_alt))

        # ゴローン3GPSデータ取得
        _gps_gorone_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_3][SystemMacro.JSONKEY_LAT]))
        _gps_gorone_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_3][SystemMacro.JSONKEY_LON]))
        self._datap_gps_gorone_3_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_3][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if((_gps_gorone_lat != 0) and (_gps_gorone_lon != 0)):
#            if((self._datap_gps_gorone_3_lat != _gps_gorone_lat) or (self._datap_gps_gorone_3_lon != _gps_gorone_lon)):
#                print("""[debug]Input gorone_3 GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_3_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_gorone_3_lat = _gps_gorone_lat
            self._datap_gps_gorone_3_lon = _gps_gorone_lon
            self._req_gorone_gps_update = (self._req_gorone_gps_update | self.BIT_FLAG_3)
        elif ((_gps_gorone_lat == 0) and (_gps_gorone_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input gorone_3 GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_3_alt))

        # ゴローン4GPSデータ取得
        _gps_gorone_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_4][SystemMacro.JSONKEY_LAT]))
        _gps_gorone_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_4][SystemMacro.JSONKEY_LON]))
        self._datap_gps_gorone_4_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_GORONE_4][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if((_gps_gorone_lat != 0) and (_gps_gorone_lon != 0)):
#            if((self._datap_gps_gorone_4_lat != _gps_gorone_lat) or (self._datap_gps_gorone_4_lon != _gps_gorone_lon)):
#                print("""[debug]Input gorone_4 GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_4_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_gorone_4_lat = _gps_gorone_lat
            self._datap_gps_gorone_4_lon = _gps_gorone_lon
            self._req_gorone_gps_update = (self._req_gorone_gps_update | self.BIT_FLAG_4)
        elif ((_gps_gorone_lat == 0) and (_gps_gorone_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input gorone_4 GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_gorone_lat, _gps_gorone_lon, self._datap_gps_gorone_4_alt))

# =============================================================================
#  処　理：データポートからドローンGPSデータ取得
#  戻り値：なし
# =============================================================================
    def GetDroneGpsData(self, _json_data):

        # ドローン1GPSデータ取得
        _gps_drone_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_1][SystemMacro.JSONKEY_LAT]))
        _gps_drone_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_1][SystemMacro.JSONKEY_LON]))
        self._datap_gps_drone_1_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_1][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if((_gps_drone_lat != 0) and (_gps_drone_lon != 0)):
#            if((self._datap_gps_drone_1_lat != _gps_drone_lat) or (self._datap_gps_drone_1_lon != _gps_drone_lon)):
#                print("""[debug]Input drone_1 GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_drone_lat, _gps_drone_lon, self._datap_gps_drone_1_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_drone_1_lat = _gps_drone_lat
            self._datap_gps_drone_1_lon = _gps_drone_lon
            self._req_drone_gps_update = (self._req_drone_gps_update | self.BIT_FLAG_1)
        elif ((_gps_drone_lat == 0) and (_gps_drone_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input drone_1 GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_drone_lat, _gps_drone_lon, self._datap_gps_drone_1_alt))

        # ドローン2GPSデータ取得
        _gps_drone_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_2][SystemMacro.JSONKEY_LAT]))
        _gps_drone_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_2][SystemMacro.JSONKEY_LON]))
        self._datap_gps_drone_2_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_2][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if((_gps_drone_lat != 0) and (_gps_drone_lon != 0)):
#            if((self._datap_gps_drone_2_lat != _gps_drone_lat) or (self._datap_gps_drone_2_lon != _gps_drone_lon)):
#                print("""[debug]Input drone_2 GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_drone_lat, _gps_drone_lon, self._datap_gps_drone_2_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_drone_2_lat = _gps_drone_lat
            self._datap_gps_drone_2_lon = _gps_drone_lon
            self._req_drone_gps_update = (self._req_drone_gps_update | self.BIT_FLAG_2)
        elif ((_gps_drone_lat == 0) and (_gps_drone_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input drone_2 GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_drone_lat, _gps_drone_lon, self._datap_gps_drone_2_alt))

        # ドローン3GPSデータ取得
        _gps_drone_lat = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_3][SystemMacro.JSONKEY_LAT]))
        _gps_drone_lon = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_3][SystemMacro.JSONKEY_LON]))
        self._datap_gps_drone_3_alt = float(format(_json_data[SystemMacro.JSONKEY_ROBOT_DRONE_3][SystemMacro.JSONKEY_ALT]))
        # 入力GPSデータが0以外の場合、表示更新要求をセット
        if((_gps_drone_lat != 0) and (_gps_drone_lon != 0)):
#            if((self._datap_gps_drone_3_lat != _gps_drone_lat) or (self._datap_gps_drone_3_lon != _gps_drone_lon)):
#                print("""[debug]Input drone_3 GPS data:lat = {0},lon = {1},alt = {2}"""
#                    .format(_gps_drone_lat, _gps_drone_lon, self._datap_gps_drone_3_alt))
            # GPSデータ及び、表示更新要求を設定
            self._datap_gps_drone_3_lat = _gps_drone_lat
            self._datap_gps_drone_3_lon = _gps_drone_lon
            self._req_drone_gps_update = (self._req_drone_gps_update | self.BIT_FLAG_3)
        elif ((_gps_drone_lat == 0) and (_gps_drone_lon == 0)):
            # 未使用時は0がくるため何もしない
            pass
        else:
            print("""[warning]Input drone_3 GPS data is invalid:lat = {0},lon = {1},alt = {2}"""
                .format(_gps_drone_lat, _gps_drone_lon, self._datap_gps_drone_3_alt))

# ============================================================================
#  処　理：データポートからセンサデータを取得
#  戻り値：なし
# ============================================================================
    def GetDPort_SensorInfo(self):

        if self._inRobotSensorDataIn.isNew():
            _str_sensor = self._inRobotSensorDataIn.read()
            if len(_str_sensor.data) == 0:
                print("""[warning]Input data port robot sensor json data is empty!!:str_sensor = {}"""
                    .format(_str_sensor.data))
            else:

                print("""[debug]Input data port robot sensor json data!!!!!!!!!!!!!!!:str_sensor = {}"""
                    .format(_str_sensor.data))

                _json_data = json.loads(_str_sensor.data)

                _robot_name = format(_json_data[SystemMacro.JSONKEY_ROBOT_NAME])
                _gyro_roll = format(_json_data[SystemMacro.JSONKEY_SENSOR_GYRO][SystemMacro.JSONKEY_ROLL])
                _gyro_pitch = format(_json_data[SystemMacro.JSONKEY_SENSOR_GYRO][SystemMacro.JSONKEY_PITCH])
                _gyro_yaw = format(_json_data[SystemMacro.JSONKEY_SENSOR_GYRO][SystemMacro.JSONKEY_YAW])
                _speed_x_axis = format(_json_data[SystemMacro.JSONKEY_SENSOR_SPEED]
                                      [SystemMacro.JSONKEY_ROBOTTYPE_CRAWLER][SystemMacro.JSONKEY_X_AXIS])
                _speed_y_axis = format(_json_data[SystemMacro.JSONKEY_SENSOR_SPEED]
                                      [SystemMacro.JSONKEY_ROBOTTYPE_CRAWLER][SystemMacro.JSONKEY_Y_AXIS])
                _speed_yaw = format(_json_data[SystemMacro.JSONKEY_SENSOR_SPEED]
                                   [SystemMacro.JSONKEY_ROBOTTYPE_CRAWLER][SystemMacro.JSONKEY_YAW])
                _speed_drone = float(format(_json_data[SystemMacro.JSONKEY_SENSOR_SPEED][SystemMacro.JSONKEY_ROBOTTYPE_DRONE]))
                _temp = float(format(_json_data[SystemMacro.JSONKEY_SENSOR_TEMP]))
                _compass = float(format(_json_data[SystemMacro.JSONKEY_SENSOR_COMPASS]))
                _compass = math.floor(_compass)
                _compass_int = int(_compass)
                _windpress = float(format(_json_data[SystemMacro.JSONKEY_SENSOR_WINDPRESS]))

                if(_robot_name == ""):
                    print "[warning]robot sensor name data is empty = ", _robot_name
                elif((_compass_int > 360) or (_compass_int < -360)):
                    print "[warning]robot sensor compass data is invalid = ", _compass_int
                else:
                    if((_robot_name != self._datap_robot_name) or (_gyro_roll != self._datap_gyro_roll) or
                      (_gyro_pitch != self._datap_gyro_pitch) or (_gyro_yaw != self._datap_gyro_yaw) or
                      (_speed_x_axis != self._datap_speed_x_axis) or (_speed_y_axis != self._datap_speed_y_axis) or
                      (_speed_yaw != self._datap_speed_yaw) or (_speed_drone != self._datap_speed_drone) or
                      (_temp != self._datap_temp) or (_compass_int != self._datap_compass) or
                      (_windpress != self._datap_windpress)):
                        print("""[debug]robot sensor data:
          _robot_name = {0}, _gyro_roll = {1}, _gyro_pitch = {2}, _gyro_yaw = {3}, _speed_x_axis = {4}, _speed_y_axis = {5}, _speed_yaw = {6}, _speed_drone = {7}, _temp = {8}, _compass = {9}, _windpress = {10}"""
                        .format(_robot_name, _gyro_roll, _gyro_pitch, _gyro_yaw, _speed_x_axis, _speed_y_axis, _speed_yaw,
                        _speed_drone, _temp, _compass_int, _windpress))

                        self._datap_robot_name = _robot_name
                        self._datap_gyro_roll = _gyro_roll
                        self._datap_gyro_pitch = _gyro_pitch
                        self._datap_gyro_yaw = _gyro_yaw
                        self._datap_speed_x_axis = _speed_x_axis
                        self._datap_speed_y_axis = _speed_y_axis
                        self._datap_speed_yaw = _speed_yaw
                        self._datap_speed_drone = _speed_drone
                        self._datap_temp = _temp
                        self._datap_compass = _compass_int
                        self._datap_windpress = _windpress
                        self._req_sensor_info_update = True

# ============================================================================
#  処　理：データポートからドローン撮影計画リストデータ取得
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# ============================================================================
    def GetDPort_DroneShootList(self):
        # データポート取得：撮影計画リスト
        if self._inDroneShootingPlanListIn.isNew():
            dResult =self._inDroneShootingPlanListIn.read()
            if len(dResult.data) == 0:
                print "[error]Input data port DroneShootingPlanList is empty!!"
                return self.RTN_VALUE_ERROR

            # ダブルコーテーション→無しに変更
            _data = str(dResult.data).replace('"', "")
            self._datap_DroneShootingPlanList = _data

            # 文字列→リスト型に変換
            json_data = ast.literal_eval(_data)
            self._datap_DroneShootingPlanList = json_data

            ret = self.RTN_VALUE_SUCCESS

        else:
            print "[warning]Drone ShootingPlan No Data!!"
            ret = self.RTN_VALUE_NONE

        return ret

# ============================================================================
#  処　理：データポートから合成計画リストデータ取得
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# ============================================================================
    def GetDPort_SynthPlanList(self):
        # データポート取得：合成計画リスト
        if self._inSynthesisPlanListIn.isNew():
            dResult =self._inSynthesisPlanListIn.read()
            if len(dResult.data) == 0:
                print "[error]Input data port SynthesisPlanList is empty!!"
                return self.RTN_VALUE_ERROR

            # ダブルコーテーション→無しに変更
            _data = str(dResult.data).replace('"', "")

            # 文字列→リスト型に変換
            json_data = ast.literal_eval(_data)
            self._datap_SynthesisPlanList = json_data

            ret = self.RTN_VALUE_SUCCESS

        else:
            print "[warning]SynthesisPlanList No Data!!"
            ret = self.RTN_VALUE_NONE

        return ret

# ============================================================================
#  処　理：データポートから写真地図画像データ取得
#  戻り値：RTN_VALUE_SUCCESS：正常終了/RTN_VALUE_ERROR：異常終了/
#          RTN_VALUE_NONE：データ待ち中
# ============================================================================
    def GetDPort_MainImage(self):
        ret = self.RTN_VALUE_ERROR

        # ===== データポート取得：地図画像データ =====
        if self._inMapImageDataIn.isNew():
            dResult = self._inMapImageDataIn.read()
            if (dResult.width == 0) or (dResult.height == 0):
                print("""[error]Input data port MapImageData is invalid!!:width = {0}, height = {1}"""
                    .format(dResult.width, dResult.height))
                return self.RTN_VALUE_ERROR

            # ===== 地図画像データ 変数セット =====
            self._img_width  = dResult.width
            self._img_height  = dResult.height 
            self._img_pixels  = dResult.pixels

            # ===== RTC.CameraImageからCVへの変更 =====
            _img = np.fromstring( dResult.pixels, dtype=np.uint8 ).reshape( dResult.height, dResult.width, -1 )
            self._datap_MapImageData = _img

            # ===== 画像リサイズ =====
            _cv_img = cv2.resize(self._datap_MapImageData, (int(self._datap_MapImageData.shape[self.IMG_SHAPE_WIDTH] * 1), 
                                                            int(self._datap_MapImageData.shape[self.IMG_SHAPE_HEIGHT] * 1)))
            self._cv_MapImageData = _cv_img
            self._cv_MarkMapImageData = _cv_img

            ret = self.RTN_VALUE_SUCCESS

        else:
            print "[warning]MapImageData No Change!!"
            ret = self.RTN_VALUE_NONE

        return ret

# ============================================================================
#  処　理：センサ系データポート保持変数初期化
#  戻り値：なし
# ============================================================================
    def InitSensorDPort(self):
        self._datap_robot_name = ""
        self._datap_gyro_roll = 0
        self._datap_gyro_pitch = 0
        self._datap_gyro_yaw = 0
        self._datap_speed_x_axis = 0
        self._datap_speed_y_axis = 0
        self._datap_speed_yaw = 0
        self._datap_speed_drone = 0
        self._datap_temp = 0
        self._datap_compass = 0
        self._datap_windpress = 0

# *****************************************************************************
#    Compass Class
# *****************************************************************************
class CompassItem(QGraphicsItem):

    MARGIN = 10

    _pointText = {  0: "N",  45: "NE",  90: "E", 135: "SE",
                  180: "S", 225: "SW", 270: "W", 315: "NW" }

    def __init__(self, rect):
        QGraphicsItem.__init__(self)
        self._boundingRect = rect
        self._angle = 0.0

# ===================================================================
#  処　理：角度取得
#  戻り値：なし
# ===================================================================
    def angle(self):
        return self._angle

# ===================================================================
#  処　理：角度更新
#  戻り値：なし
# ===================================================================
    def setAngle(self, angle):

        if angle == float("inf") or math.isnan(angle):
            return

        if angle != self._angle:
            self._angle = angle
            self.update()

    def boundingRect(self):
        return self._boundingRect

# ===================================================================
#  処　理：コンパス描画更新処理
#  戻り値：なし
# ===================================================================
    def paint(self, painter, option, widget):
        self.drawBoard(painter)
        self.drawNeedle(painter)

# ===================================================================
#  処　理：コンパスベース描画
#  戻り値：なし
# ===================================================================
    def drawBoard(self, painter):

        painter.save()

        self._init_drawing(painter)

        #ペース描画
        painter.setPen(Qt.darkGray)
        painter.setBrush(Qt.white)
        painter.drawEllipse(QPoint(0, 0), 51, 51)
        painter.setPen(Qt.darkGray)

        #目盛り描画
        painter.setPen(Qt.darkGray)
        font = painter.font()
        font.setPixelSize(10)
        painter.setFont(font)
        metrics = QFontMetricsF(font)

        i = 0
        while i < 360:
            if i % 45 == 0:
                #方位+目盛りを描画
                painter.drawLine(0, -42, 0, -50)
                painter.drawText(-metrics.width(self._pointText[i]) / 2.0,
                                 -52,
                                 self._pointText[i])
            else:
                #目盛り描画
                painter.drawLine(0, -46, 0, -50)

            painter.rotate(15)
            i += 15

        painter.restore()

# ===================================================================
#  処　理：コンパス磁針描画
#  戻り値：なし
# ===================================================================
    def drawNeedle(self, painter):

        painter.save()

        self._init_drawing(painter)

        # 角度に合わせて時計周りに回転
        painter.rotate(self._angle)
        painter.setPen(QPen(Qt.NoPen))

        #磁針(グレー部分)
        painter.setBrush(Qt.lightGray)
        painter.drawPolygon(QPoint(-5,   0),
                            QPoint( 0, -40),
                            QPoint( 5,   0),
                            QPoint( 0,  40),
                            QPoint(-5,   0))

        #磁針(赤部分)
        painter.setBrush(Qt.red)
        painter.drawPolygon(QPoint(-3, -16),
                            QPoint( 0, -40),
                            QPoint( 3, -16),
                            QPoint(-3, -16))

        #磁針(中心部)
        painter.setPen(Qt.yellow)
        painter.setBrush(Qt.yellow)
        painter.drawEllipse(QPoint(0, 0), 1, 1)
        painter.setPen(Qt.darkGray)

        painter.restore()

    def _init_drawing(self, painter):
        painter.translate(self._boundingRect.center())
        scale = min((self._boundingRect.width() - CompassItem.MARGIN) / 120.0,
                    (self._boundingRect.height() - CompassItem.MARGIN) / 120.0)
        painter.scale(scale, scale)

# *****************************************************************************
#    Main Window Class
# *****************************************************************************
class MainWindow(QtGui.QMainWindow):
    # ===== シグナル生成 =====
    trigger = pyqtSignal()

    #　===== 画像関係 =====
    VIEW_SMALL_SIZE = 0.5
    VIEW_MIDDLE_SIZE = 1.0
    VIEW_LARGE_SIZE = 1.5

    # ===== GPSマーク：サイズ =====
    MARK_SIZE_S = "S"
    MARK_SIZE_M = "M"
    MARK_SIZE_L = "L"

    MARK_SIZE_10 = 10
    MARK_SIZE_15 = 15
    MARK_SIZE_20 = 20

    # ===== GPSマーク：色 =====
    MARK_COLOR_ENRYU = (2, 79, 255)               # オレンジ
    MARK_COLOR_SPIDER = (97, 4, 255)              # ピンク
    MARK_COLOR_DRONE_1 = (255, 236, 0)            # 水色
    MARK_COLOR_DRONE_2 = (255, 95, 0)             # 青色
    MARK_COLOR_DRONE_3 = (255, 7, 85)             # 紫
    MARK_COLOR_GORONE_1 = (0, 128, 0)             # 緑
    MARK_COLOR_GORONE_2 = (59, 255, 0)            # ライムグリーン
    MARK_COLOR_GORONE_3 = (169, 249, 0)           # ターコイズブルー
    MARK_COLOR_GORONE_4 = (1, 255, 182)           # 黄緑
    MARK_COLOR_FIRST_GPS = (0, 255, 255)          # 黄色

    # ===== マーク線の太さ =====
    MARK_THICKNESS_FILL = -1  # 塗潰し
    MARK_THICKNESS_LINE = 2

    # ==== 写真地図Viewerサイズ =====
    PHOTO_MAP_VIEWER_WIDTH = 1380
    PHOTO_MAP_VIEWER_HIGHT = 950

    def __init__(self, parent=None):
        super(MainWindow, self).__init__(parent)
        QtGui.QWidget.__init__(self, parent=parent)

        # GUi インスタンス生成
        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)
        # メイン画像スタイル
        self.ui.grap_PhotoMapView.setStyleSheet("background-color: rgb(150,150,150)")

        # 画像配置用ウィジェット生成
        self.scene = QtGui.QGraphicsScene()

        # コンパス初期表示
        self._compass_ins = CompassItem(self.ui.grap_CompassView.sceneRect())
        _scene = QtGui.QGraphicsScene()
        _scene.addItem(self._compass_ins)
        self.ui.grap_CompassView.setScene(_scene)

        # RTMクラス
        self._source = None
        self._compass_widget = None

        # 表示オブジェクトや変数の初期化
        self.MainViewCommonInit()

        # ===================================
        #    GUIイベント設定 
        # ===================================
        QtCore.QObject.connect(self.ui.btn_DBregist,QtCore.SIGNAL("clicked()"), self.btn_DBregist_clicked)

        # ==== Tile Genaration Tab ==== 
        QtCore.QObject.connect(self.ui.btn_Start,QtCore.SIGNAL("clicked()"), self.btn_Start_clicked)

        # ==== Image Select Tab ====
        QtCore.QObject.connect(self.ui.btn_Delete,QtCore.SIGNAL("clicked()"), self.btn_Delete_clicked)
        QtCore.QObject.connect(self.ui.btn_DrawingUpdate,QtCore.SIGNAL("clicked()"), self.btn_DrawingUpdate_clicked)

        # ==== Image Operation Tab ====
        # Image Operation Tab
        QtCore.QObject.connect(self.ui.tabWidget,QtCore.SIGNAL("currentChanged(int)"), self.tab_clicked)

        # Arrow
        QtCore.QObject.connect(self.ui.btn_ArrowUp,QtCore.SIGNAL("clicked()"), self.btn_ArrowUp_clicked)
        QtCore.QObject.connect(self.ui.btn_ArrowDown,QtCore.SIGNAL("clicked()"), self.btn_ArrowDown_clicked)
        QtCore.QObject.connect(self.ui.btn_ArrowLeft,QtCore.SIGNAL("clicked()"), self.btn_ArrowLeft_clicked)
        QtCore.QObject.connect(self.ui.btn_ArrowRight,QtCore.SIGNAL("clicked()"), self.btn_ArrowRight_clicked)

        # Direction
        QtCore.QObject.connect(self.ui.sid_Direction,QtCore.SIGNAL("valueChanged(int)"), self.sid_Direction_ValueChange)

        # Scale
        QtCore.QObject.connect(self.ui.btn_ScaleLarge,QtCore.SIGNAL("clicked()"), self.btn_ScaleLarge_clicked)
        QtCore.QObject.connect(self.ui.btn_ScaleMiddle,QtCore.SIGNAL("clicked()"), self.btn_ScaleMiddle_clicked)
        QtCore.QObject.connect(self.ui.btn_ScallSmall,QtCore.SIGNAL("clicked()"), self.btn_ScaleSmall_clicked)

        # Zoom
        QtCore.QObject.connect(self.ui.btn_ZoomUp,QtCore.SIGNAL("clicked()"), self.btn_ZoomUp_clicked)
        QtCore.QObject.connect(self.ui.btn_ZoomDown,QtCore.SIGNAL("clicked()"), self.btn_ZoomDown_clicked)

        # Map Change
        QtCore.QObject.connect(self.ui.btn_MapAerial,QtCore.SIGNAL("clicked()"), self.btn_MapAerial_clicked)
        QtCore.QObject.connect(self.ui.btn_MapBase,QtCore.SIGNAL("clicked()"), self.btn_MapBase_clicked)

        # ==== Robot Monitor Tab ====
        QtCore.QObject.connect(self.ui.btn_MoniUpdate,QtCore.SIGNAL("clicked()"), self.btn_MoniUpdate_clicked)

        # 写真地図表示領域のマウスリリースイベントハンドル
        self.ui.grap_PhotoMapView.release.connect(self.mouseRobotSelect)

# ===================================================================
#  処　理：表示オブジェクトや変数を初期化する
#  戻り値：なし
# ===================================================================
    def MainViewCommonInit(self):

        # ===================================
        # GUI表示オブジェクトの初期化 
        # ===================================
        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # タブ選択初期設定
        self.ui.tabWidget.setCurrentIndex(0)
        self.Gui_TileGeneration_init()
        self.Gui_ImageSelect_init()
        self.Gui_ImageOperation_init()
        self.Gui_SensorMonitor_init()

        # ボタン押下状態初期化
        self.ui.btn_ScaleLarge.setEnabled(True)
        self.ui.btn_ScaleMiddle.setEnabled(False)
        self.ui.btn_ScallSmall.setEnabled(True)

        self.ui.btn_MapAerial.setEnabled(True)
        self.ui.btn_MapBase.setEnabled(False)

        # 表示状態 
        self._Main_Screen_sts = False
        self._MapKind_sts = SystemMacro.MAP_KIND_DRONE

        # ===== GPS開始地点保持 =====
        self._first_pix_enryu_x = 0
        self._first_pix_enryu_y = 0
        self._first_pix_spider_x = 0
        self._first_pix_spider_y = 0
        self._first_pix_drone_1_x = 0
        self._first_pix_drone_1_y = 0
        self._first_pix_drone_2_x = 0
        self._first_pix_drone_2_y = 0
        self._first_pix_drone_3_x = 0
        self._first_pix_drone_3_y = 0
        self._first_pix_gorone_1_x = 0
        self._first_pix_gorone_1_y = 0
        self._first_pix_gorone_2_x = 0
        self._first_pix_gorone_2_y = 0
        self._first_pix_gorone_3_x = 0
        self._first_pix_gorone_3_y = 0
        self._first_pix_gorone_4_x = 0
        self._first_pix_gorone_4_y = 0

# ===================================================================
#  処　理：マウスによるセンサ情報表示対象ロボット選択
#  戻り値：なし
# ===================================================================
    def mouseRobotSelect(self, event):
        _str = ""
        _ret = False

        _first_pix_list = [[self._first_pix_enryu_x, self._first_pix_enryu_y],
                           [self._first_pix_spider_x, self._first_pix_spider_y],
                           [self._first_pix_drone_1_x, self._first_pix_drone_1_y],
                           [self._first_pix_drone_2_x, self._first_pix_drone_2_y],
                           [self._first_pix_drone_3_x, self._first_pix_drone_3_y],
                           [self._first_pix_gorone_1_x, self._first_pix_gorone_1_y],
                           [self._first_pix_gorone_2_x, self._first_pix_gorone_2_y],
                           [self._first_pix_gorone_3_x, self._first_pix_gorone_3_y],
                           [self._first_pix_gorone_4_x, self._first_pix_gorone_4_y]]

        _robot_name_list = ["Enryu", "Spider", "Drone_1", "Drone_2", "Drone_3",
                            "Gorone_1", "Gorone_2", "Gorone_3", "Gorone_4"]

        if(self._Main_Screen_sts == True):
            """重なってGPS表示をしている場合、
               援竜→スパイダー→ドローン→ゴローンの優先順位でセンサ表示を行う"""
            for _roop in range(9):
                if((_first_pix_list[_roop][0] != 0) and (_first_pix_list[_roop][1] != 0)):
                    # 対象ロボットの範囲チェック
                    _ret = self.mouseRobotSelectChk(event, _first_pix_list[_roop][0], _first_pix_list[_roop][1])
                    if(_ret == True):
                        _str = _robot_name_list[_roop]
                        break

            if(_str != ""):
                # 対象ロボットに合わせてコンボボックスの表示内容を変更
                _index = self.ui.cmb_MoniRobotSel.findText(_str, QtCore.Qt.MatchFixedString)
                if _index >= 0:
                    print("""[debug]Robot selection by mouse:x = {0}, y = {1}, robot name = {2}"""
                        , event.pos().x(), event.pos().y(), _str)
                    self.ui.cmb_MoniRobotSel.setCurrentIndex(_index)
                    # モニタアップデータボタン押下処理を実行
                    self.btn_MoniUpdate_clicked()

# ===================================================================
#  処　理：マウス座標が対象ロボット座標範囲内か判定
#  戻り値：True :範囲内/False :範囲外
# ===================================================================
    def mouseRobotSelectChk(self, event, _pix_x, _pix_y):

        _ret = False
        _Mouse_x = event.pos().x()
        _Mouse_y = event.pos().y()

        _gps_width_offset, _gps_height_offset = self.GpsPixCorrection()
        # 入力pix値をGUIのViewサイズに合わせてオフセットする
        _correct_pix_x = _pix_x + _gps_width_offset
        _correct_pix_y = _pix_y + _gps_height_offset

        # 実際のGPS表示よりマウス反応領域にマージンを持たせる
        _start_pix_x = _correct_pix_x - self.MARK_SIZE_20
        _start_pix_y = _correct_pix_y - self.MARK_SIZE_20
        _End_pix_x = _correct_pix_x + self.MARK_SIZE_20
        _End_pix_y = _correct_pix_y + self.MARK_SIZE_20

        if((_start_pix_x <= _Mouse_x) and (_End_pix_x >= _Mouse_x)):
            if((_start_pix_y <= _Mouse_y) and (_End_pix_y >= _Mouse_y)):
                _ret = True

        return _ret

# ===================================================================
#  処　理：写真地図上に表示しているGPSピクセル座標をビューアサイズに合わせる
#  戻り値：_pix_width_offset：オフセット幅/_pix_height_offset：オフセット高さ
# ===================================================================
    def GpsPixCorrection(self):
        _pix_width_offset = 0
        _pix_height_offset = 0

        _imageData = self._source._datap_MapImageData
        _img_pix_height = _imageData.shape[self._source.IMG_SHAPE_HEIGHT]
        _img_pix_width = _imageData.shape[self._source.IMG_SHAPE_WIDTH]

        if (_img_pix_width < self.PHOTO_MAP_VIEWER_WIDTH):
            _pix_width_offset = self.PHOTO_MAP_VIEWER_WIDTH - _img_pix_width
            _pix_width_offset = _pix_width_offset / 2

        if (_img_pix_height < self.PHOTO_MAP_VIEWER_HIGHT):
            _pix_height_offset = self.PHOTO_MAP_VIEWER_HIGHT - _img_pix_height
            _pix_height_offset = _pix_height_offset / 2

        return (_pix_width_offset, _pix_height_offset)

# ===================================================================
#  処　理：GPS選択表示更新
#  戻り値：True :選択表示更新可/False :選択表示更新不可
# ===================================================================
    def Draw_Robot_Mark_Select(self, _robot_sel):

        _robot_mark_sel_list = [[SystemMacro.ROBOT_SEL_ENRYU, self._first_pix_enryu_x, self._first_pix_enryu_y],
                                [SystemMacro.ROBOT_SEL_SPIDER, self._first_pix_spider_x, self._first_pix_spider_y],
                                [SystemMacro.ROBOT_SEL_DRONE_1, self._first_pix_drone_1_x, self._first_pix_drone_1_y],
                                [SystemMacro.ROBOT_SEL_DRONE_2, self._first_pix_drone_2_x, self._first_pix_drone_2_y],
                                [SystemMacro.ROBOT_SEL_DRONE_3, self._first_pix_drone_3_x, self._first_pix_drone_3_y],
                                [SystemMacro.ROBOT_SEL_GORONE_1, self._first_pix_gorone_1_x, self._first_pix_gorone_1_y],
                                [SystemMacro.ROBOT_SEL_GORONE_2, self._first_pix_gorone_2_x, self._first_pix_gorone_2_y],
                                [SystemMacro.ROBOT_SEL_GORONE_3, self._first_pix_gorone_3_x, self._first_pix_gorone_3_y],
                                [SystemMacro.ROBOT_SEL_GORONE_4, self._first_pix_gorone_4_x, self._first_pix_gorone_4_y]]

        if((_robot_sel == SystemMacro.ROBOT_SEL_OFF) and (SystemMacro <= SystemMacro.ROBOT_SEL_MAX)):
            return False


        for _roop in range(9):
            if _robot_sel == _robot_mark_sel_list[_roop][0]:
                _ret_pix_x = _robot_mark_sel_list[_roop][1]
                _ret_pix_y = _robot_mark_sel_list[_roop][2]
                pass

        _mark_image = self.Robot_Mark(True,
                                      _mark_image, 
                                      int(_ret_pix_x), 
                                      int(_ret_pix_y), 
                                      _marksize, 
                                      _Mark_Color, 
                                      self.MARK_THICKNESS_FILL)

        # ===== QImageをQPixmapに変換 =====
        _pic_Item_Mark = self.Robot_Mark_View(_mark_image)
        # ===== 画像を追加 =====
        self.scene.addItem(_pic_Item_Mark)
        # ===== 画像を描画 =====
        self.ui.grap_PhotoMapView.setScene(self.scene)

        return True

# ===================================================================
#  処　理：Tile Generation Tab内のオブジェクト初期化
#  戻り値：なし
# ===================================================================
    def Gui_TileGeneration_init(self):

        # ===== ラジオボタン設定 =====
        self.ui.rdo_SplitOn.setChecked(True)

        # ===== テーブルの初期化 =====
        self.ui.tbl_InputImage.clear()

        # コンボボックス選択状態を初期化
        self.ui.cmb_ZoomLevel.setCurrentIndex(0)

# ===================================================================
#  処　理：Image Select Tab内のオブジェクト初期化
#  戻り値：なし
# ===================================================================
    def Gui_ImageSelect_init(self):
        # ===== テーブルの初期化 =====
        self.ui.tbl_MainView.clear()
        # ===== ラジオボタンをGPS OFFに設定 =====
        self.ui.rdo_GpsOff.setChecked(True)
        # ===== チェックボックスをOFFに設定 =====
        self.ui.chk_GpsSelEnryu.setChecked(False)
        self.ui.chk_GpsSelSpider.setChecked(False)
        self.ui.chk_GpsSelDrone_1.setChecked(False)
        self.ui.chk_GpsSelDrone_2.setChecked(False)
        self.ui.chk_GpsSelDrone_3.setChecked(False)
        self.ui.chk_GpsSelGorone_1.setChecked(False)
        self.ui.chk_GpsSelGorone_2.setChecked(False)
        self.ui.chk_GpsSelGorone_3.setChecked(False)
        self.ui.chk_GpsSelGorone_4.setChecked(False)

# ===================================================================
#  処　理：Image Operation Tab内のオブジェクト初期化
#  戻り値：なし
# ===================================================================
    def Gui_ImageOperation_init(self):
        # スライダー初期化
        self.ui.sid_Direction.setSliderPosition(0)

# ===================================================================
#  処　理：センサモニター Tab内のオブジェクト初期化
#  戻り値：なし
# ===================================================================
    def Gui_SensorMonitor_init(self):

        # コンボボックス選択状態を初期化
        self.ui.cmb_MoniRobotSel.setCurrentIndex(0)

        # センサ表示の初期化
        self.Robot_SensorInfoInit()

# *****************************************************************************
#    RTM Classからの指示により動作する処理関連
#    画面更新や、初期化など
# *****************************************************************************
# ===================================================================
#    画面更新処理
# ===================================================================
    # ===== 画面更新 =====
    def connect_and_emit_trigger(self):
        #triggerをスロットと繋げる
        self.trigger.connect(self.Disp_Update)
        #スロットにシグナルを送信する。
        self.trigger.emit()

    # ===== 画面初期設定 =====
    def connect_and_emit_init_trigger(self):
        #triggerをスロットと繋げる
        self.trigger.connect(self.Disp_Init)
        #スロットにシグナルを送信する。
        self.trigger.emit()

    # ===== disp_Deactivated：Deactivated設定 =====
    def connect_and_emit_Deactivated(self):
        #triggerをスロットと繋げる
        self.trigger.connect(self.disp_Deactivated)
        #スロットにシグナルを送信する。
        self.trigger.emit()

# ===================================================================
#  処　理：GUIをDisable状態にする
#  戻り値：なし
# ===================================================================
    def Disp_Init(self):
#        self.scene.clear()
        self.ui.setDisableUi(self)

# ===================================================================
#        disp_Deactivated：Deactivated設定
# ===================================================================
    def disp_Deactivated(self):
        self._Main_Screen_sts = False
        self.scene = QtGui.QGraphicsScene()
        self.scene.clear()
        self.ui.grap_PhotoMapView.setScene(self.scene)

        self.MainViewCommonInit()

        # ===== スロットとの繋がりを切断 =====
        self.trigger.disconnect()

# ===================================================================
#  処　理：画面を更新する
#  戻り値：なし
# ===================================================================
    def Disp_Update(self):
        ret = False

        # 全リスト表示更新
        if self._source._disp_update_req == self._source.DISPUPD_REQ_ALL_LIST:
            self.Disp_Upd_AllList()
            ret = True

        # 撮影計画リスト表示更新
        elif self._source._disp_update_req == self._source.DISPUPD_REQ_SHOOT_LIST:
            self.Disp_Upd_ShootingList()
            ret = True

        # 合成計画リスト表示更新
        elif self._source._disp_update_req == self._source.DISPUPD_REQ_SYNTH_LIST:
            self.Disp_Upd_SynthList()
            ret = True

        # メイン地図画像更新　処理
        elif self._source._disp_update_req == self._source.DISPUPD_REQ_MAIN_SCREEN:
            self.Disp_Upd_Screen()
            ret = True

        # 周期更新　処理
        elif (self._source._disp_update_req == self._source.DISPUPD_REQ_CYCLE):
            # GPS周期更新タイマ設定
            self._source._mark_timeset = self._source._01_GPSDispCycle[0]
            _st_time = self._source._mark_st_time
            _ed_time = datetime.datetime.now()

            # GPS表示更新
            if self._source._mark_st_time != 0 :
                _mark_time = _ed_time - _st_time
                if _mark_time.total_seconds() >= self._source._mark_timeset:
                    if ((self._source._gps_update_angle == SystemMacro.DIRECTION_STEP_MID) and
                        (self._source._gps_update_scale == SystemMacro.SCALE_STEP_MIDDLE)):
                        if ((self._Main_Screen_sts == True) and (self._source._param_ulGpsDispControl == SystemMacro.GPS_DISP_ON)):
                            self.Robot_PositionMark()
                            print "[debug]gps time out = ", self._source._mark_timeset

            # センサ表示更新
            if(self._source._param_ulSensorRobotSel == SystemMacro.ROBOT_SEL_ENRYU):
                self.Enryu_SensorInfoUpdate()
                ret = True
            elif(self._source._req_sensor_info_update):
                self.Robot_SensorInfoUpdate()
                self._source._req_sensor_info_update = False
                ret = True

        # タッチガード解除 処理
        elif (self._source._disp_update_req == self._source.DISPUPD_REQ_TOUCH_GUARD_OFF):
            ret = True

        if ret == True:
            if len(self._source._msg_text) > 0:
                self.ui.txt_Msg.setText(self._source._msg_text)
            self._source._disp_update_req = self._source.DISPUPD_REQ_NON
            self.ui.setEnableUi(self)

# ===================================================================
#  処　理：全リスト表示を更新する
#  戻り値：なし
# ===================================================================
    def Disp_Upd_AllList(self):
        if len(self._source._datap_SynthesisPlanList) > 0:
            # 合成計画リスト表示更新
            self.UpDate_SyntesisList(self._source._datap_SynthesisPlanList)
            self.ui.btn_Delete.setEnabled(True)
            self.ui.btn_DrawingUpdate.setEnabled(True)
        else:
            self.ui.btn_DrawingUpdate.setEnabled(False)
            self.ui.btn_Delete.setEnabled(False)

        if len(self._source._datap_DroneShootingPlanList) > 0:
            # 撮影計画リスト表示更新
            self.UpDate_ShootingList(self._source._datap_DroneShootingPlanList)
            self.ui.btn_Start.setEnabled(True)
        else:
            self.ui.btn_Start.setEnabled(False)

# ===================================================================
#  処　理：撮影計画リスト表示を更新する
#  戻り値：なし
# ===================================================================
    def Disp_Upd_ShootingList(self):
        if len(self._source._datap_DroneShootingPlanList) > 0:
            self.UpDate_ShootingList(self._source._datap_DroneShootingPlanList)
            self.ui.btn_Start.setEnabled(True)
        else:
            self.ui.btn_Start.setEnabled(False)

# ===================================================================
#  処　理：合成計画リスト表示を更新する
#  戻り値：なし
# ===================================================================
    def Disp_Upd_SynthList(self):
        if len(self._source._datap_SynthesisPlanList) > 0:
            self.UpDate_SyntesisList(self._source._datap_SynthesisPlanList)
            self.ui.btn_Delete.setEnabled(True)
            self.ui.btn_DrawingUpdate.setEnabled(True)
        else:
            self.UpDate_SyntesisList(self._source._datap_SynthesisPlanList)
            self.ui.btn_DrawingUpdate.setEnabled(False)
            self.ui.btn_Delete.setEnabled(False)

# ===================================================================
#  処　理：撮影計画リスト更新処理
#  戻り値：なし
# ===================================================================
    def UpDate_ShootingList(self, sList):
        # リスト表示クリア
        self.ui.tbl_InputImage.clear()

        # 行数の設定
        self.ui.tbl_InputImage.setRowCount(len(sList))

        # ヘッダー：列数設定
        self.ui.tbl_InputImage.setColumnCount(3)

        # ヘッダー：タイトル設定
        self.ui.tbl_InputImage.setHorizontalHeaderLabels([u"Group_ID", u"Shooting Date", u"Shooting Plan"])

        # カラム幅設定
        self.ui.tbl_InputImage.setColumnWidth(0,120)
        self.ui.tbl_InputImage.setColumnWidth(1,140)
        self.ui.tbl_InputImage.setColumnWidth(2,200)

        # テーブル：要素設定
        r = 0
        for item in sList:
            self.ui.tbl_InputImage.setItem(r, 0 , QtGui.QTableWidgetItem(str(item["group_id"])))
            self.ui.tbl_InputImage.setItem(r, 1 , QtGui.QTableWidgetItem(str(item["date"])))
            self.ui.tbl_InputImage.setItem(r, 2 , QtGui.QTableWidgetItem(str(item["plan_name"])))

            r += 1

# ===================================================================
#  処　理：合成計画リスト更新処理
#  戻り値：なし
# ===================================================================
    def UpDate_SyntesisList(self, sList):

        # ===== テーブルクリア =====
        self.ui.tbl_MainView.clear()

        # ===== 行数の設定 =====
        self.ui.tbl_MainView.setRowCount(len(sList))

        # ===== 行数の設定
        self.ui.tbl_MainView.setRowCount(len(sList))

        # ===== ヘッダー：列数設定
        self.ui.tbl_MainView.setColumnCount(3)

        # ===== ヘッダー：タイトル設定
        self.ui.tbl_MainView.setHorizontalHeaderLabels([u"Group_ID", u"Created Date", u"Create Plan"])

        # ===== カラム幅設定 =====
        self.ui.tbl_MainView.setColumnWidth(0,120)
        self.ui.tbl_MainView.setColumnWidth(1,140)
        self.ui.tbl_MainView.setColumnWidth(2,200)

        # ===== テーブル：要素の追加 =====
        r = 0
        for item in sList:
            self.ui.tbl_MainView.setItem(r, 0 , QtGui.QTableWidgetItem(str(item[SystemMacro.MAPDATA_GROUP_ID])))
            self.ui.tbl_MainView.setItem(r, 1 , QtGui.QTableWidgetItem(str(item[SystemMacro.MAPDATA_CREATE_DATE])))
            self.ui.tbl_MainView.setItem(r, 2 , QtGui.QTableWidgetItem(str(item[SystemMacro.MAPDATA_PLAN_NAME])))

            r += 1

# ===================================================================
#  処　理：写真地図表示を更新する
#  戻り値：なし
# ===================================================================
    def Disp_Upd_Screen(self):

        self.sid_Direction_ValueChange()


# *****************************************************************************
#    Gui キーイベント処理関連
# *****************************************************************************
# ===================================================================
#  処　理：DB登録ボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_DBregist_clicked(self):
        print "[input key]DB regist key push!!"

        # ===== フォルダダイアログ表示 =====
        _sFolderPath = self.FolderDialog()

        if len(_sFolderPath) > 0:

            # ===== タブ： [Tile Generation]に設定=====
            self.ui.tabWidget.setCurrentIndex(0)

            # ===== ボタン：使用不可 =====
            self.ui.setDisableUi(self)

            # ===== 処理IDセット =====
            self._source._proc_id = self._source.PROC_ID_DB_REGIST

            # ===== DB登録要求：パラメータセット =====
            self._source._param_sFolderPath = _sFolderPath

            # ===== 処理開始メッセージ =====
            self.ui.txt_Msg.setText(self._source.MSG_DATA_REGIST_IN_DB)

# ===================================================================
#  処　理：Tile Generation Tab内のStartボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_Start_clicked(self):
        print "[input key]Tile Generate key push!!:"

        _txt_msg = ""
        _ShootingPlan = 0
        _SynthesisPlanNm = ""

        _txt_StartLat = self.ui.txt_StartLat.toPlainText()
        _txt_StartLon = self.ui.txt_StartLon.toPlainText()
        _txt_EndLat = self.ui.txt_EndLat.toPlainText()
        _txt_EndLon = self.ui.txt_EndLon.toPlainText()

        # ===== 項目チェック：緯度・経度 =====
        if (len(str(_txt_StartLat)) == 0):
            print "[warning]Start latitude are not input!!"
            return
        if (len(str(_txt_StartLon)) == 0):
            print "[warning]Start longitude are not input!!"
            return
        if (len(str(_txt_EndLat)) == 0):
            print "[warning]End latitude are not input!!"
            return
        if (len(str(_txt_EndLon)) == 0):
            print "[warning]End longitude are not input!!"
            return

        # ===== 数値チェック =====
        if (str(_txt_StartLat).replace(".","").isdigit() == False):
            print "[warning]Start latitude is not a numerical value!!"
            return
        if (str(_txt_StartLon).replace(".","").isdigit() == False):
            print "[warning]Start longitude is not a numerical value!!"
            return
        if (str(_txt_EndLat).replace(".","").isdigit() == False):
            print "[warning]End latitude is not a numerical value!!"
            return
        if (str(_txt_EndLon).replace(".","").isdigit() == False):
            print "[warning]End longitude is not a numerical value!!"
            return

        # ===== Generation Mode =====
        if self.ui.rdo_SplitOn.isChecked() == True:
            _GenerateMode = SystemMacro.TILE_MODE_SPLIT_DISP_ON
            # ===== 処理IDセット：分割画面確認 =====
            self._source._proc_id = self._source.PROC_ID_TILE_SPLIT_DISP

            # ===== 処理開始メッセージ =====
            _txt_msg = self._source.MSG_TILE_SPLIT_IN_PEAPAR

        elif self.ui.rdo_SplitOff.isChecked() == True:
            _GenerateMode = SystemMacro.TILE_MODE_SPLIT_DISP_OFF
            # ===== 処理IDセット:分割画面確認消去 =====
            self._source._proc_id = self._source.PROC_ID_TILE_SPLIT_DISP_ERASE

        elif self.ui.rdo_TileCreate.isChecked() == True:
            _GenerateMode = SystemMacro.TILE_MODE_GENERATE
            # ===== 処理IDセット：タイル生成 =====
            self._source._proc_id = self._source.PROC_ID_TILE_GENERATE

             # ===== 処理開始メッセージ =====
            _txt_msg = self._source.MSG_TILE_GENERATING

        # ===== Input Image Select =====
        curIndex = self.ui.tbl_InputImage.currentIndex()
        rowIndex = curIndex.row()
        if rowIndex >= 0:
            _ShootingPlan = self.ui.tbl_InputImage.item(rowIndex, 0).text()
        else:
           print "[warning]Shooting plan list no select!!" 
           self._source._proc_id = self._source.PROC_STS_IDLE
           return

        # ===== Synthesis Plan Name =====
        _txt_SynthesisPlanNm = str(self.ui.txt_SynthesisPlanNm.toPlainText())
        #print "_txt_SynthesisPlanNm" ,_txt_SynthesisPlanNm

        if self.HalfSizeCheck(_txt_SynthesisPlanNm) == False:
            print "[warning]Double-byte characters are used for synthesis plan name!!" 
            self._source._proc_id = self._source.PROC_STS_IDLE
            return

        if ((len(_txt_SynthesisPlanNm) < 0) or 
            (len(_txt_SynthesisPlanNm) > SystemMacro.CSV_SYNTHESIS_PLANNAME_LENGTH)): 
            print "[warning]Number of characters in synthesis plan name is out of range!!" 
            self._source._proc_id = self._source.PROC_STS_IDLE
            return

        _SynthesisPlanNm = _txt_SynthesisPlanNm

        # ===== Coordinates =====
        _Start_Lat = float(_txt_StartLat)
        _Start_Lon = float(_txt_StartLon)
        _End_Lat = float(_txt_EndLat)
        _End_Lon = float(_txt_EndLon)

        # ===== ZoomLevel =====
        _txt_ZoomLevel = self.ui.cmb_ZoomLevel.currentText()
        _ZoomLevel = long(_txt_ZoomLevel)

        # ===== パラメータセット =====
        self._source._param_ulGenerateMode = _GenerateMode
        self._source._param_ulRobotCategory = SystemMacro.ROBOT_CATEGORY_DRONE
        self._source._param_ulGroupId = _ShootingPlan
        self._source._param_dStartLatitude = _Start_Lat
        self._source._param_dStartLongitude = _Start_Lon
        self._source._param_dEndLatitude = _End_Lat
        self._source._param_dEndLongitude = _End_Lon
        self._source._param_ulZoomlevel = _ZoomLevel
        self._source._param_sSynthPlanName = _SynthesisPlanNm

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== メッセージセット =====
        self.ui.txt_Msg.setText(_txt_msg)

# ===================================================================
#  処　理：Image Select Tab内のDeleteボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_Delete_clicked(self):

         # ===== Main Viewer Displayed Object List =====
        _MainView_GroupId = 0
        curIndex = self.ui.tbl_MainView.currentIndex()
        rowIndex = curIndex.row()

        if rowIndex >= 0:
            _MainView_GroupId = self.ui.tbl_MainView.item(rowIndex, 0).text()
        else:
            print "[warning]Delete list no select!!"
            return

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット=====
        self._source._proc_id = self._source.PROC_ID_SYNTHE_LIST_DEL

        # ===== パラメータセット =====
        self._source._param_ulGroupId = _MainView_GroupId

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_SYNTHE_LIST_DELETING)

        print("""[input key]Synthesis list delete key push!!:MainViewGroupId = {0}"""
            .format(self._source._param_ulGroupId))

# ===================================================================
#  処　理：Image Select Tab内の描画更新ボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_DrawingUpdate_clicked(self):

        self._Main_Screen_sts = False
        self.scene = QtGui.QGraphicsScene()
        self.scene.clear()
        self.ui.grap_PhotoMapView.setScene(self.scene)

        # 写真地図選択リストからリストIDを取得
        _curIndex = self.ui.tbl_MainView.currentIndex()
        _rowIndex = _curIndex.row()

        if _rowIndex >= 0:
            _MainView_GroupId = self.ui.tbl_MainView.item(_rowIndex, 0).text()
        else:
            print "[warning]Photo map select list no select!!"
            return

        # GPS表示設定ボタン状態を取得
        _gps_disp_cnt , _gps_robot_sel = self.GetGpsDispSetBtnSts()

        if ((_gps_disp_cnt == SystemMacro.GPS_DISP_ON) and (_gps_robot_sel == SystemMacro.ROBOT_SEL_BIT_OFF)):
            print "[warning]A robot for GPS display is not selected!!"
            return

        # キーの選択状態に問題が無ければパラメータを設定
        self._source._param_ulMainViewGroupId = _MainView_GroupId
        self._source._param_ulGpsDispControl = _gps_disp_cnt
        self._source._param_ulGpsRobotSelect = _gps_robot_sel

        # 要求を出力
        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット=====
        self._source._proc_id = self._source.PROC_ID_IMAGE_UPDATE

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)
        print("""[input key]Drawing Update key push!!:MainViewGroupId = {0}, GpsDispControl = {1}, GpsRobotSelect = {2}"""
            .format(self._source._param_ulMainViewGroupId, self._source._param_ulGpsDispControl, self._source._param_ulGpsRobotSelect))

# ===================================================================
#  処　理：GPS表示制御ボタンの選択状態を取得する
#  戻り値：GPS表示On/Off、ロボット選択ボタンの状態
# ===================================================================
    def GetGpsDispSetBtnSts(self):

        # GPS表示OFF
        if self.ui.rdo_GpsOff.isChecked() == True:
            _gps_disp_cnt = SystemMacro.GPS_DISP_OFF
            _gps_robot_sel = SystemMacro.ROBOT_SEL_BIT_OFF

            self.ui.chk_GpsSelEnryu.setChecked(False)
            self.ui.chk_GpsSelSpider.setChecked(False)
            self.ui.chk_GpsSelDrone_1.setChecked(False)
            self.ui.chk_GpsSelDrone_2.setChecked(False)
            self.ui.chk_GpsSelDrone_3.setChecked(False)
            self.ui.chk_GpsSelGorone_1.setChecked(False)
            self.ui.chk_GpsSelGorone_2.setChecked(False)
            self.ui.chk_GpsSelGorone_3.setChecked(False)
            self.ui.chk_GpsSelGorone_4.setChecked(False)

        # GPS表示ON
        elif self.ui.rdo_GpsOn.isChecked() == True:
            _gps_disp_cnt = SystemMacro.GPS_DISP_ON
            _gps_robot_sel = SystemMacro.ROBOT_SEL_BIT_OFF

            if self.ui.chk_GpsSelEnryu.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_ENRYU)

            if self.ui.chk_GpsSelSpider.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_SPIDER)

            if self.ui.chk_GpsSelDrone_1.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_DRONE_1)

            if self.ui.chk_GpsSelDrone_2.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_DRONE_2)

            if self.ui.chk_GpsSelDrone_3.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_DRONE_3)

            if self.ui.chk_GpsSelGorone_1.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_GORONE_1)

            if self.ui.chk_GpsSelGorone_2.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_GORONE_2)

            if self.ui.chk_GpsSelGorone_3.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_GORONE_3)

            if self.ui.chk_GpsSelGorone_4.isChecked() == True:
                _gps_robot_sel = (_gps_robot_sel | SystemMacro.ROBOT_SEL_BIT_GORONE_4)

        print("""[debug]GetGpsDispSetBtnSts:_gps_disp_cnt = {0}, _gps_robot_sel = {1}"""
            .format(_gps_disp_cnt, _gps_robot_sel))

        return(_gps_disp_cnt , _gps_robot_sel)

# ===================================================================
#  処　理：Image Operation Tab内の十字Upボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ArrowUp_clicked(self):
        print "[input key]Up key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_SCROLL

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulArrow = SystemMacro.ARROW_UP

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：Image Operation Tab内の十字Downボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ArrowDown_clicked(self):
        print "[input key]Down key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_SCROLL

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulArrow = SystemMacro.ARROW_DOWN

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：Image Operation Tab内の十字Rightボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ArrowRight_clicked(self):
        print "[input key]Right key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_SCROLL

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulArrow = SystemMacro.ARROW_RIGHT

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：Image Operation Tab内の十字Leftボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ArrowLeft_clicked(self):
        print "[input key]Left key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_SCROLL

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulArrow = SystemMacro.ARROW_LEFT

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：Image Operation Tab内のズームUpボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ZoomUp_clicked(self):
        print "[input key]Zoom Up key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_ZOOMCHG

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulZoomAdj = SystemMacro.ZOOM_ADJ_UP

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：Image Operation Tab内のズームDownボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ZoomDown_clicked(self):
        print "[input key]Zoom Down key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_ZOOMCHG

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulZoomAdj = SystemMacro.ZOOM_ADJ_DOWN

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：Image Operation Tab内の写真地図切り替えボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_MapAerial_clicked(self):
        print "[input key]Photo map change key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)
        self.ui.btn_MapAerial.setEnabled(False)
        self.ui.btn_MapBase.setEnabled(True)
        self._MapKind_sts == SystemMacro.MAP_KIND_DRONE

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_MAPCHG

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulMapKind = SystemMacro.MAP_KIND_DRONE

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：Image Operation Tab内の基準地図切り替えボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_MapBase_clicked(self):
        print "[input key]Base map change key push!!"

        # ===== ボタン設定 =====
        self.ui.setDisableUi(self)
        self.ui.btn_MapAerial.setEnabled(True)
        self.ui.btn_MapBase.setEnabled(False)
        self._MapKind_sts == SystemMacro.MAP_KIND_BASIC

        # ===== 処理IDセット =====
        self._source._proc_id = self._source.PROC_ID_MAIN_MAPCHG

        # ===== パラメータセット =====
        self._source._param_ulOpeScreen = SystemMacro.OPE_SCREEN_MAIN
        self._source._param_ulMapKind = SystemMacro.MAP_KIND_BASIC

        # ===== 処理開始メッセージ =====
        self.ui.txt_Msg.setText(self._source.MSG_DISPLAY_PERPAR)

# ===================================================================
#  処　理：タブクリック時の処理
#  戻り値：なし
# ===================================================================
    def tab_clicked(self,arg=None):
        print "[input key]Tab key push!! = ", arg

        #ImageOperation Tab操作
        if arg == 2:
            # 写真地図を表示している場合は、操作キーを有効に設定
            if (self._Main_Screen_sts == True):
                self.ui.btn_ArrowUp.setEnabled(True)
                self.ui.btn_ArrowDown.setEnabled(True)
                self.ui.btn_ArrowLeft.setEnabled(True)
                self.ui.btn_ArrowRight.setEnabled(True)
                self.ui.grp_Direction.setEnabled(True)
                self.ui.grp_Scale.setEnabled(True)
                self.ui.grp_Zoom.setEnabled(True)
                if (self._MapKind_sts == SystemMacro.MAP_KIND_DRONE):
                    self.ui.btn_MapAerial.setEnabled(False)
                else:
                    self.ui.btn_MapAerial.setEnabled(True)
                self.ui.btn_MapBase.setEnabled(True)

            # 写真地図を表示していない場合は、操作キーを無効に設定
            else:
                self.ui.btn_ArrowUp.setEnabled(False)
                self.ui.btn_ArrowDown.setEnabled(False)
                self.ui.btn_ArrowLeft.setEnabled(False)
                self.ui.btn_ArrowRight.setEnabled(False)
                self.ui.grp_Direction.setEnabled(False)
                self.ui.grp_Scale.setEnabled(False)
                self.ui.grp_Zoom.setEnabled(False)
                self.ui.btn_MapAerial.setEnabled(False)
                self.ui.btn_MapBase.setEnabled(False)
        # Robot Monitor Tab
        elif arg == 3:
            if(self._Main_Screen_sts == True):
                self.ui.grp_RobotSel.setEnabled(True)
            else:
                self.ui.grp_RobotSel.setEnabled(False)

# ===================================================================
#  処　理：Robot Monitor Tab内のモニタ表示更新ボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_MoniUpdate_clicked(self):
        print "btn_MoniUpdate_clicked"

        _str = self.ui.cmb_MoniRobotSel.currentText()

        if(_str == "Enryu"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_ENRYU

        elif(_str == "Spider"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_SPIDER

        elif(_str == "Drone_1"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_DRONE_1

        elif(_str == "Drone_2"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_DRONE_2

        elif(_str == "Drone_3"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_DRONE_3

        elif(_str == "Gorone_1"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_GORONE_1

        elif(_str == "Gorone_2"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_GORONE_2

        elif(_str == "Gorone_3"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_GORONE_3

        elif(_str == "Gorone_4"):
            _robot_sel_param = SystemMacro.ROBOT_SEL_GORONE_4

        else:
            _robot_sel_param = SystemMacro.ROBOT_SEL_OFF
            _str = ""

#        if(_robot_sel_param == SystemMacro.ROBOT_SEL_ENRYU):
#            print "[warning]Enryu does not support sensors!!"

        if(self._source._param_ulSensorRobotSel != _robot_sel_param):
            print "[input key]Monitor update key push!!:select robot = " , _str

            self._source._param_ulSensorRobotSel = _robot_sel_param
            self._source._senser_sel_robot_name = _str

            # 援竜はセンサデータがない為、センサデータ管理RTCへ要求をださない
            if(_robot_sel_param != SystemMacro.ROBOT_SEL_ENRYU):
                self._source._proc_id = self._source.PROC_ID_SENSOR_ROBOT_SELECT

            if(_robot_sel_param != SystemMacro.ROBOT_SEL_OFF):
                self._source.InitSensorDPort()
                self.Robot_SensorInfoInit()
                self.ui.setDisableUi(self)
            else:
                """ 対象ロボットOFFの場合、センサ情報データが更新されないため
                    このタイミングで表示を初期化し、Key操作は有効のままとする"""
                self.Robot_SensorInfoInit()

        else:
            print "[warning]Parameters when displaying sensors are the same!!"

# ===================================================================
#  処　理：Image Operation Tab内の角度調整ボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def sid_Direction_ValueChange(self):
        print "[input key]Angle adjust key push!!"

        # ===== 画像配置用ウィジェット生成 =====
        self.scene = QtGui.QGraphicsScene()

        self.scene.clear()

        # ===== 画像取込 =====
        _imageData = self._source._datap_MapImageData

        height , width, dim = _imageData.shape
        bytesPerLine = dim * width

        # ===== スケール設定に合わせて画像をリサイズ
        if (self._source._gps_update_scale == SystemMacro.SCALE_STEP_LARGE):
            _scale_val = self.VIEW_LARGE_SIZE
        elif (self._source._gps_update_scale == SystemMacro.SCALE_STEP_SMALL):
            _scale_val = self.VIEW_SMALL_SIZE
        else:
            _scale_val = self.VIEW_MIDDLE_SIZE
        _resize_imgdata = cv2.resize(_imageData, (int(width * _scale_val), int(height * _scale_val)))

        _resize_height , _resize_width, _resize_dim = _resize_imgdata.shape
        _resize_bytesPerLine = _resize_dim * _resize_width

        # ===== 今回は画像サイズの中心をとっている =====
        center = tuple(np.array([_resize_width * 0.5,  _resize_height * 0.5]))

        # ===== 画像サイズの取得(横, 縦) =====
        size = tuple(np.array([_resize_width, _resize_height]))

        # ===== 回転させたい角度 =====
        angle = float(self.ui.sid_Direction.value())

        # ===== 拡大比率 =====
        scale = 1.0

        # ===== 回転変換行列の算出 =====
        rotation_matrix = cv2.getRotationMatrix2D(center, angle, scale)

        # ===== アフィン変換（図形を回転させたり引き延ばしたりする変換）=====
        img_rot = cv2.warpAffine(_resize_imgdata, rotation_matrix, size, flags=cv2.INTER_CUBIC)

        _color_imgdata = cv2.cvtColor(img_rot, cv2.COLOR_BGR2RGB)

        # ===== Opencv（numpy）画像をQtのQImageに変換 =====
        qt_img = QtGui.QImage(_color_imgdata.data, _resize_width, _resize_height, _resize_bytesPerLine, QtGui.QImage.Format_RGB888)
        # ===== QImageをQPixmapに変換し、アイテムとして読み込む
        pic_Item = QtGui.QGraphicsPixmapItem(QtGui.QPixmap.fromImage(qt_img))
        # ===== 画像を追加 =====
        self.scene.addItem(pic_Item)
        # ===== 画像を描画 =====
        self.ui.grap_PhotoMapView.setScene(self.scene)

        # ===== 回転済データセット =====
        self._source._cv_MapImageData = img_rot

        # ===== ステータスセット =====
        self._Main_Screen_sts = True

        # ===== GPS画面更新 =====
        self._source._gps_update_angle = angle

        # 起点となるGPSピクセル情報初期化
        self.FirstGpsPixDataInit()

# ===================================================================
#  処　理：Image Operation Tab内の縮尺調整(大)ボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ScaleLarge_clicked(self):
        print "[input key]Scale large key push!!"

        # ===== 画像配置用ウィジェット生成 =====
        self.scene = QtGui.QGraphicsScene()

        self.scene.clear()

        self.ui.btn_ScaleLarge.setEnabled(False)
        self.ui.btn_ScaleMiddle.setEnabled(True)
        self.ui.btn_ScallSmall.setEnabled(True)

        # ===== 画像情報取得 ===== 
        _imageData = self._source._datap_MapImageData
        height , width, dim = _imageData.shape
        bytesPerLine = dim * width

        # ===== 画像リサイズ =====
        _resize_image = cv2.resize(_imageData, (int(width * self.VIEW_LARGE_SIZE), 
                                                int(height * self.VIEW_LARGE_SIZE)))
        # ===== リザイズ後画像情報取得 ====
        height , width, dim = _resize_image.shape
        bytesPerLine = dim * width

        # ===== 画像カラーの変更 =====
        color_image = cv2.cvtColor(_resize_image, cv2.COLOR_BGR2RGB)

        # ===== Opencv（numpy）画像をQtのQImageに変換 =====
        qt_img = QtGui.QImage(color_image.data, width, height, bytesPerLine, QtGui.QImage.Format_RGB888)
        # ===== QImageをQPixmapに変換し、アイテムとして読み込む =====
        pic_Item = QtGui.QGraphicsPixmapItem(QtGui.QPixmap.fromImage(qt_img))
        # ===== 画像を追加 =====
        self.scene.addItem(pic_Item)
        # ===== 画像を描画 =====
        self.ui.grap_PhotoMapView.setScene(self.scene)

        # ===== リサイズデータセット =====
        self._source._cv_MapImageData = _resize_image

        # ===== スライダー初期化 =====
        self.ui.sid_Direction.setSliderPosition(0)

        # ===== GPS画面更新OFF =====
        self._source._gps_update_scale = SystemMacro.SCALE_STEP_LARGE
        
        # 起点となるGPSピクセル情報初期化
        self.FirstGpsPixDataInit()

# ===================================================================
#  処　理：Image Operation Tab内の縮尺調整(中)ボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ScaleMiddle_clicked(self):
        print "[input key]Scale middle key push!!"

        # ===== 画像配置用ウィジェット生成 =====
        self.scene = QtGui.QGraphicsScene()

        self.scene.clear()

        self.ui.btn_ScaleLarge.setEnabled(True)
        self.ui.btn_ScaleMiddle.setEnabled(False)
        self.ui.btn_ScallSmall.setEnabled(True)

        # ===== 画像情報取得 =====
        _imageData = self._source._datap_MapImageData
        height , width, dim = _imageData.shape
        bytesPerLine = dim * width

        # ===== 画像リサイズ =====
        _resize_image = cv2.resize(_imageData, (int(width * 1), int(height * 1)))

        # ===== リザイズ後画像情報取得 ====
        height , width, dim = _resize_image.shape
        bytesPerLine = dim * width

        # ===== 画像カラーの変更 =====
        color_image = cv2.cvtColor(_resize_image, cv2.COLOR_BGR2RGB)

        # ===== Opencv（numpy）画像をQtのQImageに変換 =====
        qt_img = QtGui.QImage(color_image.data, width, height, bytesPerLine, QtGui.QImage.Format_RGB888)
        # ===== QImageをQPixmapに変換し、アイテムとして読み込む =====
        pic_Item = QtGui.QGraphicsPixmapItem(QtGui.QPixmap.fromImage(qt_img))
        # ===== 画像を追加 =====
        self.scene.addItem(pic_Item)
        # ===== 画像を描画 =====
        self.ui.grap_PhotoMapView.setScene(self.scene)

        # ===== リサイズデータセット =====
        self._source._cv_MapImageData = _resize_image

        # ===== スライダー初期化 =====
        self.ui.sid_Direction.setSliderPosition(0)

        # ===== GPS画面更新OFF =====
        self._source._gps_update_scale = SystemMacro.SCALE_STEP_MIDDLE
        
        # 起点となるGPSピクセル情報初期化
        self.FirstGpsPixDataInit()

# ===================================================================
#  処　理：Image Operation Tab内の縮尺調整(小)ボタン押下時の処理
#  戻り値：なし
# ===================================================================
    def btn_ScaleSmall_clicked(self):
        print "[input key]Scale small key push!!"

        # ===== 画像配置用ウィジェット生成 =====
        self.scene = QtGui.QGraphicsScene()

        self.scene.clear()

        self.ui.btn_ScaleLarge.setEnabled(True)
        self.ui.btn_ScaleMiddle.setEnabled(True)
        self.ui.btn_ScallSmall.setEnabled(False)

        # ===== 画像情報取得 ===== 
        _imageData = self._source._datap_MapImageData
        height , width, dim = _imageData.shape
        bytesPerLine = dim * width

        # ===== 画像リサイズ ===== 
        _resize_image = cv2.resize(_imageData, (int(width * self.VIEW_SMALL_SIZE), 
                                                int(height * self.VIEW_SMALL_SIZE)))
        # ===== リザイズ後画像情報取得 ====
        height , width, dim = _resize_image.shape
        bytesPerLine = dim * width

        # ===== 画像カラーの変更 =====
        color_image = cv2.cvtColor(_resize_image, cv2.COLOR_BGR2RGB)

        # ===== Opencv（numpy）画像をQtのQImageに変換 =====
        qt_img = QtGui.QImage(color_image.data, width, height, bytesPerLine, QtGui.QImage.Format_RGB888)
        # ===== QImageをQPixmapに変換し、アイテムとして読み込む =====
        pic_Item = QtGui.QGraphicsPixmapItem(QtGui.QPixmap.fromImage(qt_img))
        # ===== 画像を追加 =====
        self.scene.addItem(pic_Item)
        # ===== 画像を描画 =====
        self.ui.grap_PhotoMapView.setScene(self.scene)

        # ===== リサイズデータセット =====
        self._source._cv_MapImageData = _resize_image

        # ===== スライダー初期化 =====
        self.ui.sid_Direction.setSliderPosition(0)

        # ===== GPS画面更新OFF =====
        self._source._gps_update_scale = SystemMacro.SCALE_STEP_SMALL

        # 起点となるGPSピクセル情報初期化
        self.FirstGpsPixDataInit()


# *****************************************************************************
#    ロボットGPS表示関連
# *****************************************************************************
# ===================================================================
#  処　理：ロボットGPS表示更新処理
#  戻り値：なし
# ===================================================================
    def Robot_PositionMark(self):
        # 画像配置用ウィジェット生成
        self.scene = QtGui.QGraphicsScene()
        #self.scene.clear()

        # 画像情報取得
        _mark_image = self._source._cv_MarkMapImageData
        if (_mark_image.shape[self._source.IMG_SHAPE_HEIGHT] == 0) or (_mark_image.shape[self._source.IMG_SHAPE_WIDTH] == 0):
            return

        # 援竜のGPS表示更新
        _mark_image = self.Enryu_Gps_Update(_mark_image)

        # スパイダーのGPS表示更新
        _mark_image = self.Spider_Gps_Update(_mark_image)

        # ゴローンのGPS表示更新
        _mark_image = self.Gorone_Gps_Update(_mark_image)

        # ドローンのGPS表示更新
        _mark_image = self.Drone_Gps_Update(_mark_image)

        # 外枠なしの状態でバックアップ
        self._source._cv_MarkMapImageData = _mark_image

        # QImageをQPixmapに変換
        _pic_Item_Mark = self.Robot_Mark_View(_mark_image)
        # 画像を追加
        self.scene.addItem(_pic_Item_Mark)
        # 画像を描画
        self.ui.grap_PhotoMapView.setScene(self.scene)

        # タイマセット
        self._source._mark_st_time = datetime.datetime.now()

# ===================================================================
#  処　理：援竜用のGPS表示更新処理
#  戻り値：援竜のGPS表示を追加した写真地図画像データ
# ===================================================================
    def Enryu_Gps_Update(self, _mark_image):

        if self._source._req_enryu_gps_update == True:
            # 初期ピクセル値が0の場合、初期GPS表示と判定
            print "Enryu_Gps_Update", self._first_pix_enryu_x, self._first_pix_enryu_y
            if(self._first_pix_enryu_x == 0 or self._first_pix_enryu_y == 0):
                _first_gps_draw = True
            else:
                _first_gps_draw = False

            # GPSマークサイズの設定(configで設定)
            _marksize = self.GetEnryuGpsMarkSize()

            # GPS補正
            ret_Latitude, ret_Longitude = self.GPS_Correction(self._source._datap_gps_enryu_lat,
                                                              self._source._datap_gps_enryu_lon,
                                                              self._source._06_Enryu_Correct_Lat[0], 
                                                              self._source._07_Enryu_Correct_Lon[0])
            # ロボット位置設定
            ret, ret_gps_pix_x, ret_gps_pix_y = self.Robot_Position(ret_Latitude, 
                                                                    ret_Longitude, 
                                                                    "Enryu")

            # マーク設定
            if ret == self._source.RTN_VALUE_SUCCESS:
                _mark_image = self.Robot_Mark(_first_gps_draw,
                                              _mark_image, 
                                              int(ret_gps_pix_x), 
                                              int(ret_gps_pix_y), 
                                              _marksize, 
                                              self.MARK_COLOR_ENRYU, 
                                              self.MARK_THICKNESS_FILL)

                # 写真地図を更新して最初に表示するGPS表示ピクセル値を保存
                if(_first_gps_draw == True):
                    self._first_pix_enryu_x = ret_gps_pix_x
                    self._first_pix_enryu_y = ret_gps_pix_y

            self._source._req_enryu_gps_update = False

        return _mark_image

# ===================================================================
#  処　理：スパイダー用のGPS表示更新処理
#  戻り値：スパイダーのGPS表示を追加した写真地図画像データ
# ===================================================================
    def Spider_Gps_Update(self, _mark_image):

        if (self._source._req_spider_gps_update == True):
            # 初期ピクセル値が0の場合、初期GPS表示と判定
            if(self._first_pix_spider_x == 0 or self._first_pix_spider_y == 0):
                _first_gps_draw = True
            else:
                _first_gps_draw = False

            # GPSマークサイズの設定(configで設定)
            _marksize = self.GetSpiderGpsMarkSize()

            # GPS補正
            ret_Latitude, ret_Longitude = self.GPS_Correction(self._source._datap_gps_spider_lat,
                                                              self._source._datap_gps_spider_lon,
                                                              self._source._08_Spider_Correct_Lat[0], 
                                                              self._source._09_Spider_Correct_Lon[0])
            # ロボット位置設定
            ret, ret_gps_pix_x, ret_gps_pix_y = self.Robot_Position(ret_Latitude, 
                                                                    ret_Longitude, 
                                                                    "Spider")

            # マーク設定
            if ret == self._source.RTN_VALUE_SUCCESS:
                _mark_image = self.Robot_Mark(_first_gps_draw,
                                              _mark_image, 
                                              int(ret_gps_pix_x), 
                                              int(ret_gps_pix_y), 
                                              _marksize, 
                                              self.MARK_COLOR_SPIDER, 
                                              self.MARK_THICKNESS_FILL)

                # 最初に表示するGPS表示ピクセル値を保存
                if(_first_gps_draw == True):
                    self._first_pix_spider_x = ret_gps_pix_x
                    self._first_pix_spider_y = ret_gps_pix_y

        self._source._req_spider_gps_update = False

        return _mark_image

# ===================================================================
#  処　理：ゴローン用のGPS表示更新処理
#  戻り値：ゴローンのGPS表示を追加した写真地図画像データ
# ===================================================================
    def Gorone_Gps_Update(self, _mark_image):

        # GPSマークサイズの設定(configで設定)
        _marksize = self.GetGoroneGpsMarkSize()
        _run = False

        while(self._source._req_gorone_gps_update != 0):
            if(self._source._req_gorone_gps_update & self._source.BIT_FLAG_1):
                if(self._first_pix_gorone_1_x == 0 or self._first_pix_gorone_1_y == 0):
                    _first_gps_draw = True
                else:
                    _first_gps_draw = False
                _gorone_gps_lat = self._source._datap_gps_gorone_1_lat
                _gorone_gps_lon = self._source._datap_gps_gorone_1_lon
                _robot_name = "Gorone_1"
                _mark_color = self.MARK_COLOR_GORONE_1
                self._source._req_gorone_gps_update = (self._source._req_gorone_gps_update & self._source.MASK_FLAG_1)
                _run = True
            elif((_run == False) and (self._source._req_gorone_gps_update & self._source.BIT_FLAG_2)):
                if(self._first_pix_gorone_2_x == 0 or self._first_pix_gorone_2_y == 0):
                    _first_gps_draw = True
                else:
                    _first_gps_draw = False
                _gorone_gps_lat = self._source._datap_gps_gorone_2_lat
                _gorone_gps_lon = self._source._datap_gps_gorone_2_lon
                _robot_name = "Gorone_2"
                _mark_color = self.MARK_COLOR_GORONE_2
                self._source._req_gorone_gps_update = (self._source._req_gorone_gps_update & self._source.MASK_FLAG_2)
                _run = True
            elif((_run == False) and (self._source._req_gorone_gps_update & self._source.BIT_FLAG_3)):
                if(self._first_pix_gorone_3_x == 0 or self._first_pix_gorone_3_y == 0):
                    _first_gps_draw = True
                else:
                    _first_gps_draw = False
                _gorone_gps_lat = self._source._datap_gps_gorone_3_lat
                _gorone_gps_lon = self._source._datap_gps_gorone_3_lon
                _robot_name = "Gorone_3"
                _mark_color = self.MARK_COLOR_GORONE_3
                self._source._req_gorone_gps_update = (self._source._req_gorone_gps_update & self._source.MASK_FLAG_3)
                _run = True
            elif((_run == False) and (self._source._req_gorone_gps_update & self._source.BIT_FLAG_4)):
                print "Gorone_Gps_Update", self._first_pix_gorone_4_x, self._first_pix_gorone_4_y
                if(self._first_pix_gorone_4_x == 0 or self._first_pix_gorone_4_y == 0):
                    _first_gps_draw = True
                else:
                    _first_gps_draw = False
                _gorone_gps_lat = self._source._datap_gps_gorone_4_lat
                _gorone_gps_lon = self._source._datap_gps_gorone_4_lon
                _robot_name = "Gorone_4"
                _mark_color = self.MARK_COLOR_GORONE_4
                self._source._req_gorone_gps_update = (self._source._req_gorone_gps_update & self._source.MASK_FLAG_4)
                _run = True
            else:
                return _mark_image

            # GPS補正
            ret_Latitude, ret_Longitude = self.GPS_Correction(_gorone_gps_lat,
                                                              _gorone_gps_lon,
                                                              self._source._10_Gorone_Correct_Lat[0], 
                                                              self._source._11_Gorone_Correct_Lon[0])
            # ロボット位置設定
            ret_Gorone, ret_gps_pix_x, ret_gps_pix_y = self.Robot_Position(ret_Latitude, 
                                                                           ret_Longitude, 
                                                                           _robot_name) 

            # マーク設定
            if ret_Gorone == self._source.RTN_VALUE_SUCCESS:
                _mark_image = self.Robot_Mark(_first_gps_draw,
                                              _mark_image, 
                                              int(ret_gps_pix_x), 
                                              int(ret_gps_pix_y), 
                                              _marksize, 
                                              _mark_color, 
                                              self.MARK_THICKNESS_FILL)

                # 最初に表示するGPS表示ピクセル値を保存
                if(_first_gps_draw == True):
                    self.SetGoroneFirstPix(_robot_name, ret_gps_pix_x, ret_gps_pix_y)

            _run = False

        return _mark_image

# ===================================================================
#  処　理：ドローン用のGPS表示更新処理
#  戻り値：ドローンのGPS表示を追加した写真地図画像データ
# ===================================================================
    def Drone_Gps_Update(self, _mark_image):

        # ===== GPSマークサイズの設定(configで設定) ===== 
        _marksize = self.GetDroneGpsMarkSize()
        _run = False

        while(self._source._req_drone_gps_update != 0):
            if((_run == False) and (self._source._req_drone_gps_update & self._source.BIT_FLAG_1)):
                if(self._first_pix_drone_1_x == 0 or self._first_pix_drone_1_y == 0):
                    _first_gps_draw = True
                else:
                    _first_gps_draw = False
                _DroneGps_Lat = self._source._datap_gps_drone_1_lat
                _DroneGps_Lon = self._source._datap_gps_drone_1_lon
                _robot_name = "Drone_1"
                _Mark_Color = self.MARK_COLOR_DRONE_1
                self._source._req_drone_gps_update = (self._source._req_drone_gps_update & self._source.MASK_FLAG_1)
                _run = True
            elif((_run == False) and (self._source._req_drone_gps_update & self._source.BIT_FLAG_2)):
                if(self._first_pix_drone_2_x == 0 or self._first_pix_drone_2_y == 0):
                    _first_gps_draw = True
                else:
                    _first_gps_draw = False
                _DroneGps_Lat = self._source._datap_gps_drone_2_lat
                _DroneGps_Lon = self._source._datap_gps_drone_2_lon
                _robot_name = "Drone_2"
                _Mark_Color = self.MARK_COLOR_DRONE_2
                self._source._req_drone_gps_update = (self._source._req_drone_gps_update & self._source.MASK_FLAG_2)
                _run = True
            elif((_run == False) and (self._source._req_drone_gps_update & self._source.BIT_FLAG_3)):
                if(self._first_pix_drone_3_x == 0 or self._first_pix_drone_3_y == 0):
                    _first_gps_draw = True
                else:
                    _first_gps_draw = False
                _DroneGps_Lat = self._source._datap_gps_drone_3_lat
                _DroneGps_Lon = self._source._datap_gps_drone_3_lon
                _robot_name = "Drone_3"
                _Mark_Color = self.MARK_COLOR_DRONE_3
                self._source._req_drone_gps_update = (self._source._req_drone_gps_update & self._source.MASK_FLAG_3)
                _run = True

            else:
                return _mark_image

            # GPS補正
            ret_Latitude, ret_Longitude = self.GPS_Correction(_DroneGps_Lat,
                                                              _DroneGps_Lon,
                                                              self._source._12_Drone_Correct_Lat[0], 
                                                              self._source._13_Drone_Correct_Lon[0])

            # ロボット位置設定
            ret, ret_gps_pix_x, ret_gps_pix_y = self.Robot_Position(ret_Latitude, 
                                                                    ret_Longitude, 
                                                                    _robot_name) 

            # マーク設定
            if ret == self._source.RTN_VALUE_SUCCESS:
                _mark_image = self.Robot_Mark(_first_gps_draw,
                                              _mark_image, 
                                              int(ret_gps_pix_x), 
                                              int(ret_gps_pix_y), 
                                              _marksize, 
                                              _Mark_Color, 
                                              self.MARK_THICKNESS_FILL)

                # 最初に表示するGPS表示ピクセル値を保存
                if(_first_gps_draw == True):
                    self.SetDroneFirstPix(_robot_name, ret_gps_pix_x, ret_gps_pix_y)

            _run = False

        return _mark_image

# ===================================================================
#  処　理：コンフィギュによる援竜用GPS表示サイズ取得
#  戻り値：表示サイズ
# ===================================================================
    def GetEnryuGpsMarkSize(self):

        if self._source._02_EnryuMarkSize[0] == self.MARK_SIZE_S:
            _marksize = self.MARK_SIZE_10
        elif self._source._02_EnryuMarkSize[0] == self.MARK_SIZE_M:
            _marksize = self.MARK_SIZE_15
        elif self._source._02_EnryuMarkSize[0] == self.MARK_SIZE_L:
            _marksize = self.MARK_SIZE_20
        else:
            _marksize = self.MARK_SIZE_10

        return _marksize

# ===================================================================
#  処　理：コンフィギュによるスパイダー用GPS表示サイズ取得
#  戻り値：表示サイズ
# ===================================================================
    def GetSpiderGpsMarkSize(self):

        if self._source._03_SpiderMarkSize[0] == self.MARK_SIZE_S:
            _marksize = self.MARK_SIZE_10
        elif self._source._03_SpiderMarkSize[0] == self.MARK_SIZE_M:
            _marksize = self.MARK_SIZE_15
        elif self._source._03_SpiderMarkSize[0] == self.MARK_SIZE_L:
            _marksize = self.MARK_SIZE_20
        else:
            _marksize = self.MARK_SIZE_10

        return _marksize

# ===================================================================
#  処　理：コンフィギュによるゴローン用GPS表示サイズ取得
#  戻り値：表示サイズ
# ===================================================================
    def GetGoroneGpsMarkSize(self):

        if self._source._04_GoroneMarkSize[0] == self.MARK_SIZE_S:
            _marksize = self.MARK_SIZE_10
        elif self._source._04_GoroneMarkSize[0] == self.MARK_SIZE_M:
            _marksize = self.MARK_SIZE_15
        elif self._source._04_GoroneMarkSize[0] == self.MARK_SIZE_L:
            _marksize = self.MARK_SIZE_20
        else:
            _marksize = self.MARK_SIZE_10

        return _marksize

# ===================================================================
#  処　理：コンフィギュによるゴローン用GPS表示サイズ取得
#  戻り値：表示サイズ
# ===================================================================
    def GetDroneGpsMarkSize(self):

        if self._source._05_DroneMarkSize[0] == self.MARK_SIZE_S:
            _marksize = self.MARK_SIZE_10
        elif self._source._05_DroneMarkSize[0] == self.MARK_SIZE_M:
            _marksize = self.MARK_SIZE_15
        elif self._source._05_DroneMarkSize[0] == self.MARK_SIZE_L:
            _marksize = self.MARK_SIZE_20
        else:
            _marksize = self.MARK_SIZE_10

        return _marksize

# ===================================================================
#  処　理：写真地図を更新して最初に表示するゴローンGpsピクセル値を保存
#  戻り値：なし
# ===================================================================
    def SetGoroneFirstPix(self, _robot_name, gps_pix_x, gps_pix_y):
        if(_robot_name == "Gorone_1"):
            self._first_pix_gorone_1_x = gps_pix_x
            self._first_pix_gorone_1_y = gps_pix_y
        elif(_robot_name == "Gorone_2"):
            self._first_pix_gorone_2_x = gps_pix_x
            self._first_pix_gorone_2_y = gps_pix_y
        elif(_robot_name == "Gorone_3"):
            self._first_pix_gorone_3_x = gps_pix_x
            self._first_pix_gorone_3_y = gps_pix_y
        else:
            self._first_pix_gorone_4_x = gps_pix_x
            self._first_pix_gorone_4_y = gps_pix_y

# ===================================================================
#  処　理：写真地図を更新して最初に表示するドローンGpsピクセル値を保存
#  戻り値：なし
# ===================================================================
    def SetDroneFirstPix(self, _robot_name, gps_pix_x, gps_pix_y):
        if(_robot_name == "Drone_1"):
            self._first_pix_drone_1_x = gps_pix_x
            self._first_pix_drone_1_y = gps_pix_y
        elif(_robot_name == "Drone_2"):
            self._first_pix_drone_2_x = gps_pix_x
            self._first_pix_drone_2_y = gps_pix_y
        else:
            self._first_pix_drone_3_x = gps_pix_x
            self._first_pix_drone_3_y = gps_pix_y

# ===================================================================
#       Robot_Mark_View：ロボットマーク表示
# ===================================================================
    def Robot_Mark_View(self, arg_imgdata):
        self.scene = QtGui.QGraphicsScene()
        self.scene.clear()

        _img_pix_height = arg_imgdata.shape[self._source.IMG_SHAPE_HEIGHT]
        _img_pix_width = arg_imgdata.shape[self._source.IMG_SHAPE_WIDTH]
        _img_pix_dim = arg_imgdata.shape[self._source.IMG_SHAPE_CHANNEL]
        # ===== 地図画像情報：#全ピクセル数 =====
        _img_pix_bytesPerLine = _img_pix_width * _img_pix_dim 

        if (_img_pix_height == 0) or (_img_pix_width == 0):
            return

        if isinstance(arg_imgdata, np.ndarray):
            # ===== カラー変更 =====
            _color_image = cv2.cvtColor(arg_imgdata, cv2.COLOR_BGR2RGB)

            # ===== Opencv（numpy）画像をQtのQImageに変換
            qt_img = QtGui.QImage(_color_image.data, 
                                  int(_img_pix_width), 
                                  int(_img_pix_height), 
                                  _img_pix_bytesPerLine, 
                                  QtGui.QImage.Format_RGB888)
            # ===== QImageをQPixmapに変換し、アイテムとして読み込む
            pic_Item = QtGui.QGraphicsPixmapItem(QtGui.QPixmap.fromImage(qt_img))

        return pic_Item

# ===================================================================
#       Robot_Position：ロボット位置設定
#       引　数：（GPS緯度、GPS経度、GPSロボット名）
#       戻り値：（結果、GPS地図画像：幅、GPS地図画像：高さ）
# ===================================================================
    def Robot_Position(self, gpsLatitude, gpsLongitude, gpsRobot):
        # ===== 画像情報取得 =====
        _imageData = self._source._datap_MapImageData

        # ===== 画像データ（画像データは配列）のタイプ判断　データ取得前はSTRタイプのため =====
        if isinstance(_imageData, str):
            # 画像データのタイプがSTRの場合は処理を抜ける
            return (self._source.RTN_VALUE_NONE ,0, 0)

        _img_pix_height = _imageData.shape[self._source.IMG_SHAPE_HEIGHT]
        _img_pix_width = _imageData.shape[self._source.IMG_SHAPE_WIDTH]
        # ===== 画像情報チェック =====
        if (_img_pix_height == 0 or _img_pix_width == 0):
            return (self._source.RTN_VALUE_NONE ,0, 0)

        # ===== 数値チェック =====
        if self.NumericalCheck(gpsLatitude) == False:
            print "[error]Robot Position:gps latitude is not a numerical value!!"
            return (self._source.RTN_VALUE_NONE ,0, 0)
        if self.NumericalCheck(gpsLongitude) == False:
            print "[error]Robot Position:gps longitude is not a numerical value!!"
            return (self._source.RTN_VALUE_NONE ,0, 0)

        # ===== 0 チェック =====
        if self._source._datap_MapStartGps_Latitude == 0 or self._source._datap_MapEndGps_Latitude == 0:
            return (self._source.RTN_VALUE_NONE ,0, 0)
        if self._source._datap_MapStartGps_Longitude == 0 or self._source._datap_MapEndGps_Longitude == 0:
            return (self._source.RTN_VALUE_NONE ,0, 0)
        if gpsLatitude == 0 or gpsLongitude == 0:
            return (self._source.RTN_VALUE_NONE ,0, 0)

        # ===== 範囲チェック：緯度 =====
        if (self._source._datap_MapStartGps_Latitude < gpsLatitude or 
            self._source._datap_MapEndGps_Latitude > gpsLatitude):
            # GPS座標が地図画像の始点、終点の範囲外は処理を抜ける
            print("""[warning]Robot position:latitude is out of range!!:
          Robot name = {0}, robot gps lat = {1},Map Start lat = {2}, Map end lat = {3}"""
                .format(gpsRobot, gpsLatitude, self._source._datap_MapStartGps_Latitude, self._source._datap_MapEndGps_Latitude))

            return (self._source.RTN_VALUE_NONE, 0, 0)

        # ===== 範囲チェック：経度 =====
        if (self._source._datap_MapStartGps_Longitude > gpsLongitude  or 
            self._source._datap_MapEndGps_Longitude < gpsLongitude):
            # GPS座標が地図画像の始点、終点の範囲外は処理を抜ける
            print("""[warning]Robot position:longitude is out of range!!:
          Robot name = {0}, robot gps lon = {1},Map Start lon = {2}, Map end lon = [3]"""
                .format(gpsRobot, gpsLongitude, self._source._datap_MapStartGps_Longitude, self._source._datap_MapEndGps_Longitude))

            return (self._source.RTN_VALUE_NONE, 0, 0)

        # ===== 始点画像GPSデータ：緯度 経度 =====
        _start_map_latitude_second = self._source._datap_MapStartGps_Latitude
        _start_map_longitude_second = self._source._datap_MapStartGps_Longitude
        # ===== 終了画像GPSデータ：緯度 経度 =====
        _end_map_latitude_second = self._source._datap_MapEndGps_Latitude
        _end_map_longitude_second = self._source._datap_MapEndGps_Longitude
        # ===== GPSデータ：緯度 経度 =====
        _gps_latitude_second = gpsLatitude
        _gps_longitude_second = gpsLongitude

        # ===== 地図秒数：緯度 =====
        _map_latitude_numsecond = (_start_map_latitude_second - _end_map_latitude_second)
        # ===== 地図秒数：経度 =====
        _map_longitude_numsecond = (_end_map_longitude_second - _start_map_longitude_second)

        # ===== GPS秒数：緯度 =====
        _gsp_latitude_numsecond = (_start_map_latitude_second - _gps_latitude_second)
        # ===== GPS秒数：経度  ====
        _gsp_longitude_numsecond = (_gps_longitude_second - _start_map_longitude_second)

        # ===== 秒数：緯度,経度チェック =====
        if (_map_latitude_numsecond == 0 or _map_longitude_numsecond == 0):
            return (self._source.RTN_VALUE_NONE, 0, 0)

        # ===== 地図画像 GPS位置：縦 =====
        _gps_pix_height = (_img_pix_height * _gsp_latitude_numsecond) / _map_latitude_numsecond
        # ===== 地図画像 GPS位置：横 =====
        _gps_pix_width = (_img_pix_width * _gsp_longitude_numsecond) / _map_longitude_numsecond

        print "===== Robot_Position [%s] ===========================================" %(gpsRobot)
        print u"[debug]画像情報   ：幅、高さ  =",_img_pix_width, _img_pix_height
        print u"[debug]始点地図GPS：緯度、経度=",self._source._datap_MapStartGps_Latitude, self._source._datap_MapStartGps_Longitude
        print u"[debug]終点地図GPS：緯度、経度=",self._source._datap_MapEndGps_Latitude, self._source._datap_MapEndGps_Longitude
        print u"[debug]ROBOT GPS  ：緯度、経度=", gpsLatitude, gpsLongitude
        print u"[debug]GPS表示Pix ：幅、高さ  =", _gps_pix_width, _gps_pix_height

        return (self._source.RTN_VALUE_SUCCESS, _gps_pix_width, _gps_pix_height)

# ===================================================================
#       Robot_Mark：ロボットマーク設定
#       引　数：（地図データ、地図GPS緯度、地図GPS経度、円の大きさ、マークカラー、円の太さ）
#       戻り値：（マークGPS地図画像）
# ===================================================================
    def Robot_Mark(self, _first_gps_draw, arg_imgdata, arg_gps_width, arg_gps_height, arg_size, arg_color, arg_thickness):
        _circle_img = arg_imgdata

        # 起点となるGPS表示の場合黄色枠を付ける
        if(_first_gps_draw == True):
            _circle_img = cv2.circle(_circle_img, 
                                    (int(arg_gps_width), 
                                     int(arg_gps_height)), 
                                     arg_size + 3, 
                                     self.MARK_COLOR_FIRST_GPS,
                                     arg_thickness)

        # ==== マーク表示：（円）=====
        _circle_img = cv2.circle(_circle_img, 
                                (int(arg_gps_width), 
                                 int(arg_gps_height)), 
                                 arg_size, 
                                 arg_color,
                                 arg_thickness)

        return _circle_img

# ===================================================================
#  Robot_Mark：ロボットGPS補正
#  引　数：（GPS緯度、GPS経度、補正緯度、補正経度）
#  戻り値：（補正後GPS緯度、補正後GPS経度）
# ===================================================================
    def GPS_Correction(self, arg_gps_latitude, arg_gps_longitude, arg_corrected_latitude, arg_corrected_longitude):
        _corrected_latitude = 0
        _corrected_longitude = 0

        # ===== GPS補正：経度 =====
        _corrected_latitude = arg_gps_latitude + arg_corrected_latitude
        # ===== GPS補正：経度 =====
        _corrected_longitude = arg_gps_longitude + arg_corrected_longitude

        return (_corrected_latitude, _corrected_longitude)

# ===================================================================
#  処　理：起点GPS pixelデータ初期化
#  戻り値：なし
# ===================================================================
    def FirstGpsPixDataInit(self):
        self._first_pix_enryu_x = 0
        self._first_pix_enryu_y = 0
        self._first_pix_spider_x = 0
        self._first_pix_spider_y = 0
        self._first_pix_drone_1_x = 0
        self._first_pix_drone_1_y = 0
        self._first_pix_drone_2_x = 0
        self._first_pix_drone_2_y = 0
        self._first_pix_drone_3_x = 0
        self._first_pix_drone_3_y = 0
        self._first_pix_gorone_1_x = 0
        self._first_pix_gorone_1_y = 0
        self._first_pix_gorone_2_x = 0
        self._first_pix_gorone_2_y = 0
        self._first_pix_gorone_3_x = 0
        self._first_pix_gorone_3_y = 0
        self._first_pix_gorone_4_x = 0
        self._first_pix_gorone_4_y = 0


# *****************************************************************************
#    センサ情報表示関連
# *****************************************************************************
# ====================================================================
#  処　理：援竜センサ情報表示更新
#  戻り値：なし
# ====================================================================
    def Enryu_SensorInfoUpdate(self):
        _gps_lat, _gps_lon, _gps_alt = self.GetRobotSelGpsData("Enryu")
        # text box更新
        self.ui.line_GpsLat.setText(str(_gps_lat))
        self.ui.line_GpsLon.setText(str(_gps_lon))
        self.ui.line_GpsAlt.setText(str(_gps_alt))
        self.ui.line_GyroRoll.setText(str(0.0))
        self.ui.line_GyroPitch.setText(str(0.0))
        self.ui.line_GyroYaw.setText(str(0.0))
        self.ui.line_CrawSp_X.setText(str(0.0))
        self.ui.line_CrawSp_Y.setText(str(0.0))
        self.ui.line_CrawSp_Yaw.setText(str(0.0))
        self.ui.line_DroneSp.setText(str(0.0))
        self.ui.line_Temp.setText(str(0.0))
        self.ui.line_Windpress.setText(str(0.0))

# ====================================================================
#  処　理：センサ情報表示更新
#  戻り値：なし
# ====================================================================
    def Robot_SensorInfoUpdate(self):

        if(self._source._senser_sel_robot_name == self._source._datap_robot_name):
            _gps_lat, _gps_lon, _gps_alt = self.GetRobotSelGpsData(self._source._datap_robot_name)
            # text box更新
            self.ui.line_GpsLat.setText(str(_gps_lat))
            self.ui.line_GpsLon.setText(str(_gps_lon))
            self.ui.line_GpsAlt.setText(str(_gps_alt))
            self.ui.line_GyroRoll.setText(str(self._source._datap_gyro_roll))
            self.ui.line_GyroPitch.setText(str(self._source._datap_gyro_pitch))
            self.ui.line_GyroYaw.setText(str(self._source._datap_gyro_yaw))
            self.ui.line_CrawSp_X.setText(str(self._source._datap_speed_x_axis))
            self.ui.line_CrawSp_Y.setText(str(self._source._datap_speed_y_axis))
            self.ui.line_CrawSp_Yaw.setText(str(self._source._datap_speed_yaw))
            self.ui.line_DroneSp.setText(str(round(self._source._datap_speed_drone, 4)))
            self.ui.line_Temp.setText(str(round(self._source._datap_temp, 4)))
            self.ui.line_Windpress.setText(str(round(self._source._datap_windpress, 4)))

            # コンパス表示更新
            _scene = QtGui.QGraphicsScene()
            self._compass_ins.setAngle(self._source._datap_compass)
            _scene.addItem(self._compass_ins)
            self.ui.grap_CompassView.setScene(_scene)

# ====================================================================
#  処　理：対象ロボットGPSデータ取得
#  戻り値：_gps_lat：緯度、_gps_lon：経度、_gps_alt：高度
# ====================================================================
    def GetRobotSelGpsData(self, _robot_name):

        if(_robot_name == "Enryu"):
            _gps_lat = self._source._datap_gps_enryu_lat
            _gps_lon = self._source._datap_gps_enryu_lon
            _gps_alt = self._source._datap_gps_enryu_alt

        elif(_robot_name == "Spider"):
            _gps_lat = self._source._datap_gps_spider_lat
            _gps_lon = self._source._datap_gps_spider_lon
            _gps_alt = self._source._datap_gps_spider_alt

        elif(_robot_name == "Drone_1"):
            _gps_lat = self._source._datap_gps_drone_1_lat
            _gps_lon = self._source._datap_gps_drone_1_lon
            _gps_alt = self._source._datap_gps_drone_1_alt

        elif(_robot_name == "Drone_2"):
            _gps_lat = self._source._datap_gps_drone_2_lat
            _gps_lon = self._source._datap_gps_drone_2_lon
            _gps_alt = self._source._datap_gps_drone_2_alt

        elif(_robot_name == "Drone_3"):
            _gps_lat = self._source._datap_gps_drone_3_lat
            _gps_lon = self._source._datap_gps_drone_3_lon
            _gps_alt = self._source._datap_gps_drone_3_alt

        elif(_robot_name == "Gorone_1"):
            _gps_lat = self._source._datap_gps_gorone_1_lat
            _gps_lon = self._source._datap_gps_gorone_1_lon
            _gps_alt = self._source._datap_gps_gorone_1_alt

        elif(_robot_name == "Gorone_2"):
            _gps_lat = self._source._datap_gps_gorone_2_lat
            _gps_lon = self._source._datap_gps_gorone_2_lon
            _gps_alt = self._source._datap_gps_gorone_2_alt

        elif(_robot_name == "Gorone_3"):
            _gps_lat = self._source._datap_gps_gorone_3_lat
            _gps_lon = self._source._datap_gps_gorone_3_lon
            _gps_alt = self._source._datap_gps_gorone_3_alt

        elif(_robot_name == "Gorone_4"):
            _gps_lat = self._source._datap_gps_gorone_4_lat
            _gps_lon = self._source._datap_gps_gorone_4_lon
            _gps_alt = self._source._datap_gps_gorone_4_alt

        else:
            _gps_lat = 0
            _gps_lon = 0
            _gps_alt = 0

        return (_gps_lat, _gps_lon, _gps_alt)

# ====================================================================
#  処　理：センサ表示初期化
#  戻り値：なし
# ====================================================================
    def Robot_SensorInfoInit(self):
        # text box更新
        self.ui.line_GpsLat.setText("")
        self.ui.line_GpsLon.setText("")
        self.ui.line_GpsAlt.setText("")
        self.ui.line_GyroRoll.setText("")
        self.ui.line_GyroPitch.setText("")
        self.ui.line_GyroYaw.setText("")
        self.ui.line_CrawSp_X.setText("")
        self.ui.line_CrawSp_Y.setText("")
        self.ui.line_CrawSp_Yaw.setText("")
        self.ui.line_DroneSp.setText("")
        self.ui.line_Temp.setText("")
        self.ui.line_Windpress.setText("")

        # コンパス表示更新
        _scene = QtGui.QGraphicsScene()
        self._compass_ins.setAngle(0)
        _scene.addItem(self._compass_ins)
        self.ui.grap_CompassView.setScene(_scene)

# *****************************************************************************
#    共通処理
# *****************************************************************************
# ====================================================================
#       フォルダ指定　ダイアログ
#       戻り値：フォルダ名
# ====================================================================
    def FolderDialog(self):
        # ダイアログ表示
        _foldername = QtGui.QFileDialog.getExistingDirectory(self, 'Open Directory', 
                                                             os.path.expanduser(SystemMacro.ROBOT_BASE_FOLDER_PATH))

        return _foldername

# ====================================================================
#       数値チェック
#       引　数：（文字列）
#       戻り値：結果（OK：True　NG：False）
# ====================================================================
    def NumericalCheck(self, coordinate):
        ret = False
        # ===== 座標 =====
        if str(coordinate).replace(".","").isdigit():
            ret = True
        else:
            # ===== チェックNG =====
            ret  = False

        return ret

# ====================================================================
#       半角チェック(UTF8)
#       引　数：（文字列）
#       戻り値：結果（OK：True　NG：False）
# ====================================================================
    def HalfSizeCheck(self, chkstring):
        regexp = re.compile(r'^[0-9A-Za-z_ ]+$')
        ret = False

        result = regexp.search(chkstring)
        #===== チェック =====
        if result != None :
            ret = True
        else:
            # ===== チェックNG =====
            ret  = False

        return ret

# ====================================================================
#       コンポーネントクラス設定
# ====================================================================
    def set_data_source(self, source):
        self._source = source
        return


#def TwoDRobotInfoMonitorGuiInit(manager):
#    profile = OpenRTM_aist.Properties(defaults_str=twodrobotinfomonitorgui_spec)
#    manager.registerFactory(profile,
#                            TwoDRobotInfoMonitorGui,
#                            OpenRTM_aist.Delete)

#def MyModuleInit(manager):
#    TwoDRobotInfoMonitorGuiInit(manager)
#
#    # Create a component
#    comp = manager.createComponent("TwoDRobotInfoMonitorGui")

def main():
    mgr = OpenRTM_aist.Manager.init(sys.argv)
#    mgr.setModuleInitProc(MyModuleInit)
    mgr.activateManager()

    profile = OpenRTM_aist.Properties(defaults_str=twodrobotinfomonitorgui_spec)
    mgr.registerFactory(profile,
                            TwoDRobotInfoMonitorGui,
                            OpenRTM_aist.Delete)

    # Create a component
    comp = mgr.createComponent("TwoDRobotInfoMonitorGui")
    mgr.runManager(True)
    app = QtGui.QApplication(sys.argv)

    # GUIクラス 設定
    global g_form
    g_form = MainWindow()
    g_form.set_data_source(comp)
    g_form.show()

    sys.exit(app.exec_())
    mgr.shutdown()

if __name__ == "__main__":
    main()

